/* machine-thumbnailer.c generated by valac 0.30.0.37-86f3c, the Vala compiler
 * generated from machine-thumbnailer.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gdk/gdk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtk.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_MACHINE_THUMBNAILER (boxes_machine_thumbnailer_get_type ())
#define BOXES_MACHINE_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailer))
#define BOXES_MACHINE_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailerClass))
#define BOXES_IS_MACHINE_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_THUMBNAILER))
#define BOXES_IS_MACHINE_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_THUMBNAILER))
#define BOXES_MACHINE_THUMBNAILER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailerClass))

typedef struct _BoxesMachineThumbnailer BoxesMachineThumbnailer;
typedef struct _BoxesMachineThumbnailerClass BoxesMachineThumbnailerClass;
typedef struct _BoxesMachineThumbnailerPrivate BoxesMachineThumbnailerPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _BoxesMachineThumbnailer {
	GObject parent_instance;
	BoxesMachineThumbnailerPrivate * priv;
};

struct _BoxesMachineThumbnailerClass {
	GObjectClass parent_class;
};

struct _BoxesMachineThumbnailerPrivate {
	BoxesMachine* _machine;
	gint _width;
	gint _height;
	gint _centred_emblem_size;
	gint _emblem_size;
	GdkRGBA _border_color;
	GdkRGBA _background_color;
	GdkPixbuf* _thumbnail;
	gboolean _favorite_emblem_enabled;
	GdkPixbuf* empty_thumbnail;
	GdkPixbuf* default_thumbnail;
	GdkPixbuf* stopped_thumbnail;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};


static gpointer boxes_machine_thumbnailer_parent_class = NULL;

GType boxes_machine_thumbnailer_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
#define BOXES_MACHINE_THUMBNAILER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailerPrivate))
enum  {
	BOXES_MACHINE_THUMBNAILER_DUMMY_PROPERTY,
	BOXES_MACHINE_THUMBNAILER_MACHINE,
	BOXES_MACHINE_THUMBNAILER_WIDTH,
	BOXES_MACHINE_THUMBNAILER_HEIGHT,
	BOXES_MACHINE_THUMBNAILER_CENTRED_EMBLEM_SIZE,
	BOXES_MACHINE_THUMBNAILER_EMBLEM_SIZE,
	BOXES_MACHINE_THUMBNAILER_BORDER_COLOR,
	BOXES_MACHINE_THUMBNAILER_BACKGROUND_COLOR,
	BOXES_MACHINE_THUMBNAILER_THUMBNAIL,
	BOXES_MACHINE_THUMBNAILER_FAVORITE_EMBLEM_ENABLED
};
#define BOXES_MACHINE_THUMBNAILER_FRAME_RADIUS 2.0
#define BOXES_MACHINE_THUMBNAILER_EMBLEM_PADDING 8
BoxesMachineThumbnailer* boxes_machine_thumbnailer_new (BoxesMachine* machine, gint width, gint height, gint centred_emblem_size, gint emblem_size, GdkRGBA* border_color, GdkRGBA* background_color);
BoxesMachineThumbnailer* boxes_machine_thumbnailer_construct (GType object_type, BoxesMachine* machine, gint width, gint height, gint centred_emblem_size, gint emblem_size, GdkRGBA* border_color, GdkRGBA* background_color);
static void boxes_machine_thumbnailer_set_machine (BoxesMachineThumbnailer* self, BoxesMachine* value);
void boxes_machine_thumbnailer_set_width (BoxesMachineThumbnailer* self, gint value);
void boxes_machine_thumbnailer_set_height (BoxesMachineThumbnailer* self, gint value);
void boxes_machine_thumbnailer_set_centred_emblem_size (BoxesMachineThumbnailer* self, gint value);
void boxes_machine_thumbnailer_set_emblem_size (BoxesMachineThumbnailer* self, gint value);
void boxes_machine_thumbnailer_set_border_color (BoxesMachineThumbnailer* self, GdkRGBA* value);
void boxes_machine_thumbnailer_set_background_color (BoxesMachineThumbnailer* self, GdkRGBA* value);
static void __lambda7_ (BoxesMachineThumbnailer* self);
static void boxes_machine_thumbnailer_update_thumbnail (BoxesMachineThumbnailer* self);
static void ___lambda7__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda227_ (BoxesMachineThumbnailer* self);
static void ___lambda227__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void __lambda228_ (BoxesMachineThumbnailer* self);
static void ___lambda228__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_machine_thumbnailer_update_thumbnail_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
BoxesMachine* boxes_machine_thumbnailer_get_machine (BoxesMachineThumbnailer* self);
gboolean boxes_machine_get_is_stopped (BoxesMachine* self);
gboolean boxes_machine_get_under_construction (BoxesMachine* self);
static GdkPixbuf* boxes_machine_thumbnailer_get_under_construction_thumbnail (BoxesMachineThumbnailer* self);
static GdkPixbuf* boxes_machine_thumbnailer_get_stopped_thumbnail (BoxesMachineThumbnailer* self);
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
gint boxes_machine_thumbnailer_get_width (BoxesMachineThumbnailer* self);
gint boxes_machine_thumbnailer_get_height (BoxesMachineThumbnailer* self);
static GdkPixbuf* boxes_machine_thumbnailer_get_default_thumbnail (BoxesMachineThumbnailer* self);
gboolean boxes_machine_thumbnailer_get_favorite_emblem_enabled (BoxesMachineThumbnailer* self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static GdkPixbuf* boxes_machine_thumbnailer_add_emblem_icon (BoxesMachineThumbnailer* self, GdkPixbuf* pixbuf, const gchar* icon_name, GtkCornerType corner_type);
static void boxes_machine_thumbnailer_set_thumbnail (BoxesMachineThumbnailer* self, GdkPixbuf* value);
static GdkPixbuf* boxes_machine_thumbnailer_get_empty_thumbnail (BoxesMachineThumbnailer* self);
GdkPixbuf* boxes_paint_empty_frame (gint width, gint height, gdouble radius, GdkRGBA* border_color, GdkRGBA* bg_color);
void boxes_machine_thumbnailer_get_border_color (BoxesMachineThumbnailer* self, GdkRGBA* result);
void boxes_machine_thumbnailer_get_background_color (BoxesMachineThumbnailer* self, GdkRGBA* result);
static GdkPixbuf* boxes_machine_thumbnailer_add_centered_emblem_icon (BoxesMachineThumbnailer* self, GdkPixbuf* pixbuf, const gchar* icon_name, gint size);
gint boxes_machine_thumbnailer_get_centred_emblem_size (BoxesMachineThumbnailer* self);
gint boxes_machine_thumbnailer_get_emblem_size (BoxesMachineThumbnailer* self);
static gboolean _vala_gtk_corner_type_array_contains (GtkCornerType* stack, int stack_length, GtkCornerType needle);
GdkPixbuf* boxes_machine_thumbnailer_get_thumbnail (BoxesMachineThumbnailer* self);
void boxes_machine_thumbnailer_set_favorite_emblem_enabled (BoxesMachineThumbnailer* self, gboolean value);
static void boxes_machine_thumbnailer_finalize (GObject* obj);
static void _vala_boxes_machine_thumbnailer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_machine_thumbnailer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GtkCornerType BOXES_MACHINE_THUMBNAILER_right_corners[2] = {GTK_CORNER_TOP_RIGHT, GTK_CORNER_BOTTOM_RIGHT};
static const GtkCornerType BOXES_MACHINE_THUMBNAILER_bottom_corners[2] = {GTK_CORNER_BOTTOM_LEFT, GTK_CORNER_BOTTOM_RIGHT};
const GdkRGBA BOXES_MACHINE_THUMBNAILER_CENTERED_EMBLEM_COLOR = {0xbe / 255.0, 0xbe / 255.0, 0xbe / 255.0, 1.0};
const GdkRGBA BOXES_MACHINE_THUMBNAILER_SMALL_EMBLEM_COLOR = {1.0, 1.0, 1.0, 1.0};

static void __lambda7_ (BoxesMachineThumbnailer* self) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_update_thumbnail (self);
#line 274 "machine-thumbnailer.c"
}


static void ___lambda7__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	__lambda7_ ((BoxesMachineThumbnailer*) self);
#line 281 "machine-thumbnailer.c"
}


static void __lambda227_ (BoxesMachineThumbnailer* self) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_update_thumbnail (self);
#line 288 "machine-thumbnailer.c"
}


static void ___lambda227__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	__lambda227_ ((BoxesMachineThumbnailer*) self);
#line 295 "machine-thumbnailer.c"
}


static void __lambda228_ (BoxesMachineThumbnailer* self) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_update_thumbnail (self);
#line 302 "machine-thumbnailer.c"
}


static void ___lambda228__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	__lambda228_ ((BoxesMachineThumbnailer*) self);
#line 309 "machine-thumbnailer.c"
}


static void _boxes_machine_thumbnailer_update_thumbnail_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_update_thumbnail ((BoxesMachineThumbnailer*) self);
#line 316 "machine-thumbnailer.c"
}


BoxesMachineThumbnailer* boxes_machine_thumbnailer_construct (GType object_type, BoxesMachine* machine, gint width, gint height, gint centred_emblem_size, gint emblem_size, GdkRGBA* border_color, GdkRGBA* background_color) {
	BoxesMachineThumbnailer * self = NULL;
	BoxesMachine* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	GdkRGBA _tmp5_ = {0};
	GdkRGBA _tmp6_ = {0};
	BoxesMachine* _tmp7_ = NULL;
	BoxesMachine* _tmp8_ = NULL;
	BoxesMachine* _tmp9_ = NULL;
	BoxesBoxConfig* _tmp10_ = NULL;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (border_color != NULL, NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (background_color != NULL, NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self = (BoxesMachineThumbnailer*) g_object_new (object_type, NULL);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = machine;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_machine (self, _tmp0_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp1_ = width;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_width (self, _tmp1_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp2_ = height;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_height (self, _tmp2_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp3_ = centred_emblem_size;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_centred_emblem_size (self, _tmp3_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp4_ = emblem_size;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_emblem_size (self, _tmp4_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp5_ = *border_color;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_border_color (self, &_tmp5_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp6_ = *background_color;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_background_color (self, &_tmp6_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp7_ = machine;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) _tmp7_, "notify::pixbuf", (GCallback) ___lambda7__g_object_notify, self, 0);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp8_ = machine;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) _tmp8_, "notify::under-construction", (GCallback) ___lambda227__g_object_notify, self, 0);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp9_ = machine;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp10_ = _tmp9_->config;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) _tmp10_, "notify::categories", (GCallback) ___lambda228__g_object_notify, self, 0);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) self, "notify::width", (GCallback) _boxes_machine_thumbnailer_update_thumbnail_g_object_notify, self, 0);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) self, "notify::height", (GCallback) _boxes_machine_thumbnailer_update_thumbnail_g_object_notify, self, 0);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) self, "notify::border-color", (GCallback) _boxes_machine_thumbnailer_update_thumbnail_g_object_notify, self, 0);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) self, "notify::favorite-emblem-enabled", (GCallback) _boxes_machine_thumbnailer_update_thumbnail_g_object_notify, self, 0);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_signal_connect_object ((GObject*) self, "notify::construction-spinner-enabled", (GCallback) _boxes_machine_thumbnailer_update_thumbnail_g_object_notify, self, 0);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_update_thumbnail (self);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return self;
#line 397 "machine-thumbnailer.c"
}


BoxesMachineThumbnailer* boxes_machine_thumbnailer_new (BoxesMachine* machine, gint width, gint height, gint centred_emblem_size, gint emblem_size, GdkRGBA* border_color, GdkRGBA* background_color) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return boxes_machine_thumbnailer_construct (BOXES_TYPE_MACHINE_THUMBNAILER, machine, width, height, centred_emblem_size, emblem_size, border_color, background_color);
#line 404 "machine-thumbnailer.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return self ? g_object_ref (self) : NULL;
#line 411 "machine-thumbnailer.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	for (i = 0; i < stack_length; i++) {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			return TRUE;
#line 423 "machine-thumbnailer.c"
		}
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return FALSE;
#line 428 "machine-thumbnailer.c"
}


static void boxes_machine_thumbnailer_update_thumbnail (BoxesMachineThumbnailer* self) {
	GdkPixbuf* new_thumbnail = NULL;
	BoxesMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	GdkPixbuf* _tmp19_ = NULL;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	GdkPixbuf* _tmp30_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	new_thumbnail = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp1_ = boxes_machine_get_is_stopped (_tmp0_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp2_ = _tmp1_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp2_) {
#line 453 "machine-thumbnailer.c"
		GdkPixbuf* _tmp3_ = NULL;
		BoxesMachine* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gboolean _tmp6_ = FALSE;
		GdkPixbuf* _tmp9_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp4_ = self->priv->_machine;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp5_ = boxes_machine_get_under_construction (_tmp4_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp6_ = _tmp5_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		if (_tmp6_) {
#line 467 "machine-thumbnailer.c"
			GdkPixbuf* _tmp7_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp7_ = boxes_machine_thumbnailer_get_under_construction_thumbnail (self);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_g_object_unref0 (_tmp3_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp3_ = _tmp7_;
#line 475 "machine-thumbnailer.c"
		} else {
			GdkPixbuf* _tmp8_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp8_ = boxes_machine_thumbnailer_get_stopped_thumbnail (self);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_g_object_unref0 (_tmp3_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp3_ = _tmp8_;
#line 484 "machine-thumbnailer.c"
		}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp9_ = _g_object_ref0 (_tmp3_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (new_thumbnail);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		new_thumbnail = _tmp9_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (_tmp3_);
#line 494 "machine-thumbnailer.c"
	} else {
		BoxesMachine* _tmp10_ = NULL;
		GdkPixbuf* _tmp11_ = NULL;
		GdkPixbuf* _tmp12_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp10_ = self->priv->_machine;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp11_ = boxes_machine_get_pixbuf (_tmp10_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp12_ = _tmp11_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		if (_tmp12_ != NULL) {
#line 507 "machine-thumbnailer.c"
			BoxesMachine* _tmp13_ = NULL;
			GdkPixbuf* _tmp14_ = NULL;
			GdkPixbuf* _tmp15_ = NULL;
			gint _tmp16_ = 0;
			gint _tmp17_ = 0;
			GdkPixbuf* _tmp18_ = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp13_ = self->priv->_machine;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp14_ = boxes_machine_get_pixbuf (_tmp13_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp15_ = _tmp14_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp16_ = self->priv->_width;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp17_ = self->priv->_height;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_tmp18_ = gdk_pixbuf_scale_simple (_tmp15_, _tmp16_, _tmp17_, GDK_INTERP_BILINEAR);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_g_object_unref0 (new_thumbnail);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			new_thumbnail = _tmp18_;
#line 530 "machine-thumbnailer.c"
		}
	}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp19_ = new_thumbnail;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp19_ == NULL) {
#line 537 "machine-thumbnailer.c"
		GdkPixbuf* _tmp20_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp20_ = boxes_machine_thumbnailer_get_default_thumbnail (self);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (new_thumbnail);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		new_thumbnail = _tmp20_;
#line 545 "machine-thumbnailer.c"
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp22_ = self->priv->_favorite_emblem_enabled;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp22_) {
#line 551 "machine-thumbnailer.c"
		BoxesMachine* _tmp23_ = NULL;
		BoxesBoxConfig* _tmp24_ = NULL;
		gchar** _tmp25_ = NULL;
		gint _tmp25__length1 = 0;
		gchar** _tmp26_ = NULL;
		gint _tmp26__length1 = 0;
		gchar** _tmp27_ = NULL;
		gint _tmp27__length1 = 0;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp23_ = self->priv->_machine;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp24_ = _tmp23_->config;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp25_ = boxes_box_config_get_categories (_tmp24_, &_tmp25__length1);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp26_ = _tmp25_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp26__length1 = _tmp25__length1;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp27_ = _tmp26_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp27__length1 = _tmp26__length1;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp21_ = _vala_string_array_contains (_tmp27_, _tmp26__length1, "favorite");
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp27_ = (_vala_array_free (_tmp27_, _tmp27__length1, (GDestroyNotify) g_free), NULL);
#line 578 "machine-thumbnailer.c"
	} else {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp21_ = FALSE;
#line 582 "machine-thumbnailer.c"
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp21_) {
#line 586 "machine-thumbnailer.c"
		GdkPixbuf* _tmp28_ = NULL;
		GdkPixbuf* _tmp29_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp28_ = new_thumbnail;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp29_ = boxes_machine_thumbnailer_add_emblem_icon (self, _tmp28_, "starred-symbolic", GTK_CORNER_BOTTOM_LEFT);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (new_thumbnail);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		new_thumbnail = _tmp29_;
#line 597 "machine-thumbnailer.c"
	}
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp30_ = new_thumbnail;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_set_thumbnail (self, _tmp30_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (new_thumbnail);
#line 605 "machine-thumbnailer.c"
}


static GdkPixbuf* boxes_machine_thumbnailer_get_empty_thumbnail (BoxesMachineThumbnailer* self) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	GdkRGBA _tmp5_ = {0};
	GdkRGBA _tmp6_ = {0};
	GdkPixbuf* _tmp7_ = NULL;
	GdkPixbuf* _tmp8_ = NULL;
	GdkPixbuf* _tmp9_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->empty_thumbnail;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp0_ != NULL) {
#line 625 "machine-thumbnailer.c"
		GdkPixbuf* _tmp1_ = NULL;
		GdkPixbuf* _tmp2_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp1_ = self->priv->empty_thumbnail;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		result = _tmp2_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return result;
#line 636 "machine-thumbnailer.c"
	}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp3_ = self->priv->_width;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp4_ = self->priv->_height;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp5_ = self->priv->_border_color;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp6_ = self->priv->_background_color;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp7_ = boxes_paint_empty_frame (_tmp3_, _tmp4_, BOXES_MACHINE_THUMBNAILER_FRAME_RADIUS, &_tmp5_, &_tmp6_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->empty_thumbnail);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->empty_thumbnail = _tmp7_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp8_ = self->priv->empty_thumbnail;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp9_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 660 "machine-thumbnailer.c"
}


static GdkPixbuf* boxes_machine_thumbnailer_get_default_thumbnail (BoxesMachineThumbnailer* self) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* frame = NULL;
	GdkPixbuf* _tmp3_ = NULL;
	GdkPixbuf* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GdkPixbuf* _tmp6_ = NULL;
	GdkPixbuf* _tmp7_ = NULL;
	GdkPixbuf* _tmp8_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->default_thumbnail;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp0_ != NULL) {
#line 680 "machine-thumbnailer.c"
		GdkPixbuf* _tmp1_ = NULL;
		GdkPixbuf* _tmp2_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp1_ = self->priv->default_thumbnail;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		result = _tmp2_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return result;
#line 691 "machine-thumbnailer.c"
	}
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp3_ = boxes_machine_thumbnailer_get_empty_thumbnail (self);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	frame = _tmp3_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp4_ = frame;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp5_ = self->priv->_centred_emblem_size;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp6_ = boxes_machine_thumbnailer_add_centered_emblem_icon (self, _tmp4_, "computer-symbolic", _tmp5_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->default_thumbnail);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->default_thumbnail = _tmp6_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp7_ = self->priv->default_thumbnail;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp8_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (frame);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 717 "machine-thumbnailer.c"
}


static GdkPixbuf* boxes_machine_thumbnailer_get_stopped_thumbnail (BoxesMachineThumbnailer* self) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* frame = NULL;
	GdkPixbuf* _tmp3_ = NULL;
	GdkPixbuf* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GdkPixbuf* _tmp6_ = NULL;
	GdkPixbuf* _tmp7_ = NULL;
	GdkPixbuf* _tmp8_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->stopped_thumbnail;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp0_ != NULL) {
#line 737 "machine-thumbnailer.c"
		GdkPixbuf* _tmp1_ = NULL;
		GdkPixbuf* _tmp2_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp1_ = self->priv->stopped_thumbnail;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		result = _tmp2_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return result;
#line 748 "machine-thumbnailer.c"
	}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp3_ = boxes_machine_thumbnailer_get_empty_thumbnail (self);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	frame = _tmp3_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp4_ = frame;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp5_ = self->priv->_centred_emblem_size;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp6_ = boxes_machine_thumbnailer_add_centered_emblem_icon (self, _tmp4_, "system-shutdown-symbolic", _tmp5_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->stopped_thumbnail);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->stopped_thumbnail = _tmp6_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp7_ = self->priv->stopped_thumbnail;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp8_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (frame);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 774 "machine-thumbnailer.c"
}


static GdkPixbuf* boxes_machine_thumbnailer_get_under_construction_thumbnail (BoxesMachineThumbnailer* self) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = boxes_machine_thumbnailer_get_empty_thumbnail (self);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 789 "machine-thumbnailer.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1314 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1315 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	result = self;
#line 1315 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 801 "machine-thumbnailer.c"
}


static GdkPixbuf* boxes_machine_thumbnailer_add_centered_emblem_icon (BoxesMachineThumbnailer* self, GdkPixbuf* pixbuf, const gchar* icon_name, gint size) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* emblem = NULL;
	GtkIconTheme* theme = NULL;
	GtkIconTheme* _tmp0_ = NULL;
	GtkIconTheme* _tmp1_ = NULL;
	GdkPixbuf* _tmp19_ = NULL;
	gdouble offset_x = 0.0;
	GdkPixbuf* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	gint _tmp24_ = 0;
	GdkPixbuf* _tmp25_ = NULL;
	gint _tmp26_ = 0;
	gint _tmp27_ = 0;
	gdouble offset_y = 0.0;
	GdkPixbuf* _tmp28_ = NULL;
	gint _tmp29_ = 0;
	gint _tmp30_ = 0;
	GdkPixbuf* _tmp31_ = NULL;
	gint _tmp32_ = 0;
	gint _tmp33_ = 0;
	GdkPixbuf* emblemed = NULL;
	GdkPixbuf* _tmp34_ = NULL;
	GdkPixbuf* _tmp35_ = NULL;
	GdkPixbuf* _tmp36_ = NULL;
	GdkPixbuf* _tmp37_ = NULL;
	gdouble _tmp38_ = 0.0;
	gdouble _tmp39_ = 0.0;
	gint _tmp40_ = 0;
	gint _tmp41_ = 0;
	gdouble _tmp42_ = 0.0;
	gdouble _tmp43_ = 0.0;
	GError * _inner_error_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (icon_name != NULL, NULL);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	emblem = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = gtk_icon_theme_get_default ();
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	theme = _tmp1_;
#line 852 "machine-thumbnailer.c"
	{
		GtkIconInfo* icon_info = NULL;
		GtkIconTheme* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		GtkIconInfo* _tmp5_ = NULL;
		GdkPixbuf* _tmp6_ = NULL;
		GtkIconInfo* _tmp7_ = NULL;
		GdkPixbuf* _tmp8_ = NULL;
		GdkPixbuf* _tmp9_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp2_ = theme;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp3_ = icon_name;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp4_ = size;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp5_ = gtk_icon_theme_lookup_icon (_tmp2_, _tmp3_, _tmp4_, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		icon_info = _tmp5_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp7_ = icon_info;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp8_ = gtk_icon_info_load_symbolic (_tmp7_, &BOXES_MACHINE_THUMBNAILER_CENTERED_EMBLEM_COLOR, NULL, NULL, NULL, NULL, &_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp6_ = _tmp8_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_gtk_icon_info_free0 (icon_info);
#line 883 "machine-thumbnailer.c"
			goto __catch59_g_error;
		}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp9_ = _tmp6_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp6_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		emblem = _tmp9_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (_tmp6_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_gtk_icon_info_free0 (icon_info);
#line 898 "machine-thumbnailer.c"
	}
	goto __finally59;
	__catch59_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		GdkPixbuf* _tmp17_ = NULL;
		GdkPixbuf* _tmp18_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_error_ = _inner_error_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_inner_error_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp10_ = icon_name;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp11_ = string_to_string (_tmp10_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp12_ = _error_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp13_ = _tmp12_->message;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp14_ = string_to_string (_tmp13_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp15_ = g_strconcat ("Unable to get icon '", _tmp11_, "': ", _tmp14_, NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp16_ = _tmp15_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_warning ("machine-thumbnailer.vala:121: %s", _tmp16_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_free0 (_tmp16_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp17_ = pixbuf;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp18_ = _g_object_ref0 (_tmp17_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		result = _tmp18_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_error_free0 (_error_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (theme);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return result;
#line 949 "machine-thumbnailer.c"
	}
	__finally59:
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (theme);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_clear_error (&_inner_error_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return NULL;
#line 964 "machine-thumbnailer.c"
	}
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp19_ = emblem;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp19_ == NULL) {
#line 970 "machine-thumbnailer.c"
		GdkPixbuf* _tmp20_ = NULL;
		GdkPixbuf* _tmp21_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp20_ = pixbuf;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		result = _tmp21_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (theme);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return result;
#line 985 "machine-thumbnailer.c"
	}
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp22_ = pixbuf;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp23_ = gdk_pixbuf_get_width (_tmp22_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp24_ = _tmp23_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp25_ = emblem;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp26_ = gdk_pixbuf_get_width (_tmp25_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp27_ = _tmp26_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	offset_x = (_tmp24_ / 2.0) - (_tmp27_ / 2.0);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp28_ = pixbuf;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp29_ = gdk_pixbuf_get_height (_tmp28_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp30_ = _tmp29_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp31_ = emblem;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp32_ = gdk_pixbuf_get_height (_tmp31_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp33_ = _tmp32_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	offset_y = (_tmp30_ / 2.0) - (_tmp33_ / 2.0);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp34_ = pixbuf;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp35_ = gdk_pixbuf_copy (_tmp34_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	emblemed = _tmp35_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp36_ = emblem;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp37_ = emblemed;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp38_ = offset_x;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp39_ = offset_y;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp40_ = size;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp41_ = size;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp42_ = offset_x;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp43_ = offset_y;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	gdk_pixbuf_composite (_tmp36_, _tmp37_, (gint) _tmp38_, (gint) _tmp39_, _tmp40_, _tmp41_, _tmp42_, _tmp43_, 1.0, 1.0, GDK_INTERP_BILINEAR, 255);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = emblemed;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (theme);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (emblem);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1047 "machine-thumbnailer.c"
}


static gboolean _vala_gtk_corner_type_array_contains (GtkCornerType* stack, int stack_length, GtkCornerType needle) {
	int i;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	for (i = 0; i < stack_length; i++) {
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		if (needle == stack[i]) {
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			return TRUE;
#line 1059 "machine-thumbnailer.c"
		}
	}
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return FALSE;
#line 1064 "machine-thumbnailer.c"
}


static GdkPixbuf* boxes_machine_thumbnailer_add_emblem_icon (BoxesMachineThumbnailer* self, GdkPixbuf* pixbuf, const gchar* icon_name, GtkCornerType corner_type) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* emblem = NULL;
	GtkIconTheme* theme = NULL;
	GtkIconTheme* _tmp0_ = NULL;
	GtkIconTheme* _tmp1_ = NULL;
	GdkPixbuf* _tmp19_ = NULL;
	gint _tmp22_ = 0;
	GtkCornerType _tmp23_ = 0;
	gint offset_x = 0;
	gint _tmp30_ = 0;
	GtkCornerType _tmp31_ = 0;
	gint offset_y = 0;
	GdkPixbuf* emblemed = NULL;
	GdkPixbuf* _tmp38_ = NULL;
	GdkPixbuf* _tmp39_ = NULL;
	GdkPixbuf* _tmp40_ = NULL;
	GdkPixbuf* _tmp41_ = NULL;
	gint _tmp42_ = 0;
	gint _tmp43_ = 0;
	gint _tmp44_ = 0;
	gint _tmp45_ = 0;
	gint _tmp46_ = 0;
	gint _tmp47_ = 0;
	GError * _inner_error_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (icon_name != NULL, NULL);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	emblem = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = gtk_icon_theme_get_default ();
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	theme = _tmp1_;
#line 1107 "machine-thumbnailer.c"
	{
		GtkIconInfo* icon_info = NULL;
		GtkIconTheme* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		GtkIconInfo* _tmp5_ = NULL;
		GdkPixbuf* _tmp6_ = NULL;
		GtkIconInfo* _tmp7_ = NULL;
		GdkPixbuf* _tmp8_ = NULL;
		GdkPixbuf* _tmp9_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp2_ = theme;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp3_ = icon_name;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp4_ = self->priv->_emblem_size;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp5_ = gtk_icon_theme_lookup_icon (_tmp2_, _tmp3_, _tmp4_, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		icon_info = _tmp5_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp7_ = icon_info;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp8_ = gtk_icon_info_load_symbolic (_tmp7_, &BOXES_MACHINE_THUMBNAILER_SMALL_EMBLEM_COLOR, NULL, NULL, NULL, NULL, &_inner_error_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp6_ = _tmp8_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			_gtk_icon_info_free0 (icon_info);
#line 1138 "machine-thumbnailer.c"
			goto __catch60_g_error;
		}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp9_ = _tmp6_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp6_ = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		emblem = _tmp9_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (_tmp6_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_gtk_icon_info_free0 (icon_info);
#line 1153 "machine-thumbnailer.c"
	}
	goto __finally60;
	__catch60_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		GdkPixbuf* _tmp17_ = NULL;
		GdkPixbuf* _tmp18_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_error_ = _inner_error_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_inner_error_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp10_ = icon_name;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp11_ = string_to_string (_tmp10_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp12_ = _error_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp13_ = _tmp12_->message;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp14_ = string_to_string (_tmp13_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp15_ = g_strconcat ("Unable to get icon '", _tmp11_, "': ", _tmp14_, NULL);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp16_ = _tmp15_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_warning ("machine-thumbnailer.vala:147: %s", _tmp16_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_free0 (_tmp16_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp17_ = pixbuf;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp18_ = _g_object_ref0 (_tmp17_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		result = _tmp18_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_error_free0 (_error_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (theme);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return result;
#line 1204 "machine-thumbnailer.c"
	}
	__finally60:
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (theme);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_clear_error (&_inner_error_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return NULL;
#line 1219 "machine-thumbnailer.c"
	}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp19_ = emblem;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_tmp19_ == NULL) {
#line 1225 "machine-thumbnailer.c"
		GdkPixbuf* _tmp20_ = NULL;
		GdkPixbuf* _tmp21_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp20_ = pixbuf;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		result = _tmp21_;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (theme);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_g_object_unref0 (emblem);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		return result;
#line 1240 "machine-thumbnailer.c"
	}
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp23_ = corner_type;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_vala_gtk_corner_type_array_contains (BOXES_MACHINE_THUMBNAILER_right_corners, G_N_ELEMENTS (BOXES_MACHINE_THUMBNAILER_right_corners), _tmp23_)) {
#line 1246 "machine-thumbnailer.c"
		GdkPixbuf* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		gint _tmp26_ = 0;
		GdkPixbuf* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp24_ = pixbuf;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp25_ = gdk_pixbuf_get_width (_tmp24_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp26_ = _tmp25_;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp27_ = emblem;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp28_ = gdk_pixbuf_get_width (_tmp27_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp29_ = _tmp28_;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp22_ = (_tmp26_ - _tmp29_) - BOXES_MACHINE_THUMBNAILER_EMBLEM_PADDING;
#line 1267 "machine-thumbnailer.c"
	} else {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp22_ = BOXES_MACHINE_THUMBNAILER_EMBLEM_PADDING;
#line 1271 "machine-thumbnailer.c"
	}
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	offset_x = _tmp22_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp31_ = corner_type;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	if (_vala_gtk_corner_type_array_contains (BOXES_MACHINE_THUMBNAILER_bottom_corners, G_N_ELEMENTS (BOXES_MACHINE_THUMBNAILER_bottom_corners), _tmp31_)) {
#line 1279 "machine-thumbnailer.c"
		GdkPixbuf* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		GdkPixbuf* _tmp35_ = NULL;
		gint _tmp36_ = 0;
		gint _tmp37_ = 0;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp32_ = pixbuf;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp33_ = gdk_pixbuf_get_height (_tmp32_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp34_ = _tmp33_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp35_ = emblem;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp36_ = gdk_pixbuf_get_height (_tmp35_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp37_ = _tmp36_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp30_ = (_tmp34_ - _tmp37_) - BOXES_MACHINE_THUMBNAILER_EMBLEM_PADDING;
#line 1300 "machine-thumbnailer.c"
	} else {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		_tmp30_ = BOXES_MACHINE_THUMBNAILER_EMBLEM_PADDING;
#line 1304 "machine-thumbnailer.c"
	}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	offset_y = _tmp30_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp38_ = pixbuf;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp39_ = gdk_pixbuf_copy (_tmp38_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	emblemed = _tmp39_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp40_ = emblem;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp41_ = emblemed;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp42_ = offset_x;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp43_ = offset_y;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp44_ = self->priv->_emblem_size;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp45_ = self->priv->_emblem_size;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp46_ = offset_x;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp47_ = offset_y;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	gdk_pixbuf_composite (_tmp40_, _tmp41_, _tmp42_, _tmp43_, _tmp44_, _tmp45_, (gdouble) _tmp46_, (gdouble) _tmp47_, 1.0, 1.0, GDK_INTERP_BILINEAR, 255);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = emblemed;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (theme);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (emblem);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1340 "machine-thumbnailer.c"
}


BoxesMachine* boxes_machine_thumbnailer_get_machine (BoxesMachineThumbnailer* self) {
	BoxesMachine* result;
	BoxesMachine* _tmp0_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_machine;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1355 "machine-thumbnailer.c"
}


static void boxes_machine_thumbnailer_set_machine (BoxesMachineThumbnailer* self, BoxesMachine* value) {
	BoxesMachine* _tmp0_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = value;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_machine = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "machine");
#line 1369 "machine-thumbnailer.c"
}


gint boxes_machine_thumbnailer_get_width (BoxesMachineThumbnailer* self) {
	gint result;
	gint _tmp0_ = 0;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_width;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1384 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_set_width (BoxesMachineThumbnailer* self, gint value) {
	gint _tmp0_ = 0;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = value;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_width = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "width");
#line 1398 "machine-thumbnailer.c"
}


gint boxes_machine_thumbnailer_get_height (BoxesMachineThumbnailer* self) {
	gint result;
	gint _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_height;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1413 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_set_height (BoxesMachineThumbnailer* self, gint value) {
	gint _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = value;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_height = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "height");
#line 1427 "machine-thumbnailer.c"
}


gint boxes_machine_thumbnailer_get_centred_emblem_size (BoxesMachineThumbnailer* self) {
	gint result;
	gint _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_centred_emblem_size;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1442 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_set_centred_emblem_size (BoxesMachineThumbnailer* self, gint value) {
	gint _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = value;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_centred_emblem_size = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "centred-emblem-size");
#line 1456 "machine-thumbnailer.c"
}


gint boxes_machine_thumbnailer_get_emblem_size (BoxesMachineThumbnailer* self) {
	gint result;
	gint _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_emblem_size;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1471 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_set_emblem_size (BoxesMachineThumbnailer* self, gint value) {
	gint _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = value;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_emblem_size = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "emblem-size");
#line 1485 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_get_border_color (BoxesMachineThumbnailer* self, GdkRGBA* result) {
	GdkRGBA _tmp0_ = {0};
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_border_color;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	*result = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return;
#line 1499 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_set_border_color (BoxesMachineThumbnailer* self, GdkRGBA* value) {
	GdkRGBA _tmp0_ = {0};
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = *value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_border_color = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "border-color");
#line 1513 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_get_background_color (BoxesMachineThumbnailer* self, GdkRGBA* result) {
	GdkRGBA _tmp0_ = {0};
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_background_color;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	*result = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return;
#line 1527 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_set_background_color (BoxesMachineThumbnailer* self, GdkRGBA* value) {
	GdkRGBA _tmp0_ = {0};
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = *value;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_background_color = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "background-color");
#line 1541 "machine-thumbnailer.c"
}


GdkPixbuf* boxes_machine_thumbnailer_get_thumbnail (BoxesMachineThumbnailer* self) {
	GdkPixbuf* result;
	GdkPixbuf* _tmp0_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_thumbnail;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1556 "machine-thumbnailer.c"
}


static void boxes_machine_thumbnailer_set_thumbnail (BoxesMachineThumbnailer* self, GdkPixbuf* value) {
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = value;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->_thumbnail);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_thumbnail = _tmp1_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "thumbnail");
#line 1575 "machine-thumbnailer.c"
}


gboolean boxes_machine_thumbnailer_get_favorite_emblem_enabled (BoxesMachineThumbnailer* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = self->priv->_favorite_emblem_enabled;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	result = _tmp0_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	return result;
#line 1590 "machine-thumbnailer.c"
}


void boxes_machine_thumbnailer_set_favorite_emblem_enabled (BoxesMachineThumbnailer* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_return_if_fail (self != NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_tmp0_ = value;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_favorite_emblem_enabled = _tmp0_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_notify ((GObject *) self, "favorite-emblem-enabled");
#line 1604 "machine-thumbnailer.c"
}


static void boxes_machine_thumbnailer_class_init (BoxesMachineThumbnailerClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	boxes_machine_thumbnailer_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_type_class_add_private (klass, sizeof (BoxesMachineThumbnailerPrivate));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_machine_thumbnailer_get_property;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_machine_thumbnailer_set_property;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_machine_thumbnailer_finalize;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_MACHINE, g_param_spec_object ("machine", "machine", "machine", BOXES_TYPE_MACHINE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_WIDTH, g_param_spec_int ("width", "width", "width", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_HEIGHT, g_param_spec_int ("height", "height", "height", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_CENTRED_EMBLEM_SIZE, g_param_spec_int ("centred-emblem-size", "centred-emblem-size", "centred-emblem-size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_EMBLEM_SIZE, g_param_spec_int ("emblem-size", "emblem-size", "emblem-size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_BORDER_COLOR, g_param_spec_boxed ("border-color", "border-color", "border-color", gdk_rgba_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_BACKGROUND_COLOR, g_param_spec_boxed ("background-color", "background-color", "background-color", gdk_rgba_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_THUMBNAIL, g_param_spec_object ("thumbnail", "thumbnail", "thumbnail", GDK_TYPE_PIXBUF, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_THUMBNAILER_FAVORITE_EMBLEM_ENABLED, g_param_spec_boolean ("favorite-emblem-enabled", "favorite-emblem-enabled", "favorite-emblem-enabled", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1637 "machine-thumbnailer.c"
}


static void boxes_machine_thumbnailer_instance_init (BoxesMachineThumbnailer * self) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv = BOXES_MACHINE_THUMBNAILER_GET_PRIVATE (self);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self->priv->_favorite_emblem_enabled = TRUE;
#line 1646 "machine-thumbnailer.c"
}


static void boxes_machine_thumbnailer_finalize (GObject* obj) {
	BoxesMachineThumbnailer * self;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailer);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->_thumbnail);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->empty_thumbnail);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->default_thumbnail);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	_g_object_unref0 (self->priv->stopped_thumbnail);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	G_OBJECT_CLASS (boxes_machine_thumbnailer_parent_class)->finalize (obj);
#line 1664 "machine-thumbnailer.c"
}


GType boxes_machine_thumbnailer_get_type (void) {
	static volatile gsize boxes_machine_thumbnailer_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_thumbnailer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMachineThumbnailerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_machine_thumbnailer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMachineThumbnailer), 0, (GInstanceInitFunc) boxes_machine_thumbnailer_instance_init, NULL };
		GType boxes_machine_thumbnailer_type_id;
		boxes_machine_thumbnailer_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesMachineThumbnailer", &g_define_type_info, 0);
		g_once_init_leave (&boxes_machine_thumbnailer_type_id__volatile, boxes_machine_thumbnailer_type_id);
	}
	return boxes_machine_thumbnailer_type_id__volatile;
}


static void _vala_boxes_machine_thumbnailer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMachineThumbnailer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailer);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	switch (property_id) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_MACHINE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_value_set_object (value, boxes_machine_thumbnailer_get_machine (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_WIDTH:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_value_set_int (value, boxes_machine_thumbnailer_get_width (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_HEIGHT:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_value_set_int (value, boxes_machine_thumbnailer_get_height (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_CENTRED_EMBLEM_SIZE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_value_set_int (value, boxes_machine_thumbnailer_get_centred_emblem_size (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_EMBLEM_SIZE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_value_set_int (value, boxes_machine_thumbnailer_get_emblem_size (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_BORDER_COLOR:
#line 1717 "machine-thumbnailer.c"
		{
			GdkRGBA boxed;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			boxes_machine_thumbnailer_get_border_color (self, &boxed);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			g_value_set_boxed (value, &boxed);
#line 1724 "machine-thumbnailer.c"
		}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_BACKGROUND_COLOR:
#line 1730 "machine-thumbnailer.c"
		{
			GdkRGBA boxed;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			boxes_machine_thumbnailer_get_background_color (self, &boxed);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
			g_value_set_boxed (value, &boxed);
#line 1737 "machine-thumbnailer.c"
		}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_THUMBNAIL:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_value_set_object (value, boxes_machine_thumbnailer_get_thumbnail (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_FAVORITE_EMBLEM_ENABLED:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		g_value_set_boolean (value, boxes_machine_thumbnailer_get_favorite_emblem_enabled (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 1753 "machine-thumbnailer.c"
		default:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 1759 "machine-thumbnailer.c"
	}
}


static void _vala_boxes_machine_thumbnailer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMachineThumbnailer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailer);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
	switch (property_id) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_MACHINE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_machine (self, g_value_get_object (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_WIDTH:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_width (self, g_value_get_int (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_HEIGHT:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_height (self, g_value_get_int (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_CENTRED_EMBLEM_SIZE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_centred_emblem_size (self, g_value_get_int (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_EMBLEM_SIZE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_emblem_size (self, g_value_get_int (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_BORDER_COLOR:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_border_color (self, g_value_get_boxed (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_BACKGROUND_COLOR:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_background_color (self, g_value_get_boxed (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_THUMBNAIL:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_thumbnail (self, g_value_get_object (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		case BOXES_MACHINE_THUMBNAILER_FAVORITE_EMBLEM_ENABLED:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		boxes_machine_thumbnailer_set_favorite_emblem_enabled (self, g_value_get_boolean (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 1823 "machine-thumbnailer.c"
		default:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine-thumbnailer.vala"
		break;
#line 1829 "machine-thumbnailer.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 1837 "machine-thumbnailer.c"
		int i;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 1845 "machine-thumbnailer.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1857 "machine-thumbnailer.c"
}



