/* util-app.c generated by valac 0.30.0.37-86f3c, the Vala compiler
 * generated from util-app.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk/gdk.h>
#include <libcommon.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>
#include <osinfo/osinfo.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <config.h>
#include <sys/socket.h>
#include <errno.h>
#include <netinet/in.h>
#include <linux/if.h>
#include <sys/ioctl.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <unistd.h>
#include <cairo.h>
#include <float.h>
#include <math.h>
#include <libgd/gd.h>

#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _xmlFreeParserCtxt0(var) ((var == NULL) ? NULL : (var = (xmlFreeParserCtxt (var), NULL)))
#define _xmlXPathFreeContext0(var) ((var == NULL) ? NULL : (var = (xmlXPathFreeContext (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _BoxesEnsureStoragePoolData BoxesEnsureStoragePoolData;
typedef struct _BoxesGetSystemVirtConnectionData BoxesGetSystemVirtConnectionData;
typedef struct _BoxesCheckSelinuxContextDefaultData BoxesCheckSelinuxContextDefaultData;
typedef struct _BoxesCheckLibvirtKvmData BoxesCheckLibvirtKvmData;
typedef struct _BoxesCheckCpuVtCapabilityData BoxesCheckCpuVtCapabilityData;
typedef struct _BoxesCheckModuleKvmLoadedData BoxesCheckModuleKvmLoadedData;
typedef struct _BoxesCheckStoragePoolData BoxesCheckStoragePoolData;
typedef struct _Block85Data Block85Data;

#define BOXES_TYPE_CPU_ARCH_COMPATIBILITY (boxes_cpu_arch_compatibility_get_type ())

#define BOXES_FDO_TYPE_TIMEDATE1 (boxes_fdo_timedate1_get_type ())
#define BOXES_FDO_TIMEDATE1(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_FDO_TYPE_TIMEDATE1, BoxesFdotimedate1))
#define BOXES_FDO_IS_TIMEDATE1(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_FDO_TYPE_TIMEDATE1))
#define BOXES_FDO_TIMEDATE1_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_FDO_TYPE_TIMEDATE1, BoxesFdotimedate1Iface))

typedef struct _BoxesFdotimedate1 BoxesFdotimedate1;
typedef struct _BoxesFdotimedate1Iface BoxesFdotimedate1Iface;

#define BOXES_FDO_TYPE_TIMEDATE1_PROXY (boxes_fdo_timedate1_proxy_get_type ())
typedef GDBusProxy BoxesFdotimedate1Proxy;
typedef GDBusProxyClass BoxesFdotimedate1ProxyClass;
#define _cairo_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_destroy (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))

struct _BoxesEnsureStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GVirConnection* connection;
	GVirStoragePool* result;
	GVirStoragePool* pool;
	GVirConnection* _tmp0_;
	GVirStoragePool* _tmp1_;
	GVirStoragePool* _tmp2_;
	GVirConfigStoragePool* config;
	GVirConfigStoragePool* _tmp3_;
	GVirStoragePool* _tmp4_;
	GVirConnection* _tmp5_;
	GVirConfigStoragePool* _tmp6_;
	GVirStoragePool* _tmp7_;
	GVirStoragePool* _tmp8_;
	GVirStoragePool* _tmp9_;
	gchar* pool_path;
	gchar* _tmp10_;
	const gchar* _tmp11_;
	GVirStoragePoolInfo* _tmp12_;
	GVirStoragePool* _tmp13_;
	GVirStoragePoolInfo* _tmp14_;
	GVirStoragePoolInfo* _tmp15_;
	GVirStoragePoolInfo* _tmp16_;
	GVirStoragePoolState _tmp17_;
	gboolean _tmp18_;
	GVirStoragePool* _tmp19_;
	GVirStoragePool* _tmp20_;
	GVirStoragePool* _tmp21_;
	GError * _inner_error_;
};

struct _BoxesGetSystemVirtConnectionData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GVirConnection* result;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GVirConnection* _tmp3_;
	GVirConnection* _tmp4_;
	GVirConnection* _tmp5_;
	GVirConnection* _tmp6_;
	GVirConnection* _tmp7_;
	GVirConnection* _tmp8_;
	GError * _inner_error_;
};

struct _BoxesCheckSelinuxContextDefaultData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError* _error_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GError* _vala1__error_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _BoxesCheckLibvirtKvmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
	gchar* kvm;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	GError* _error_;
	GError* _vala1__error_;
	GError* _tmp10_;
	const gchar* _tmp11_;
	GError * _inner_error_;
};

struct _BoxesCheckCpuVtCapabilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* file;
	GFile* _tmp0_;
	GFileInputStream* _tmp1_;
	GFile* _tmp2_;
	GFileInputStream* _tmp3_;
	GDataInputStream* stream;
	GDataInputStream* _tmp4_;
	gchar* line;
	gchar* _tmp5_;
	GDataInputStream* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	GError* _error_;
	GError* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckModuleKvmLoadedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* file;
	GFile* _tmp0_;
	GFileInputStream* _tmp1_;
	GFile* _tmp2_;
	GFileInputStream* _tmp3_;
	GDataInputStream* stream;
	GDataInputStream* _tmp4_;
	gchar* line;
	gchar* _tmp5_;
	GDataInputStream* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	GError* _error_;
	GError* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* pool_path;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GError* _error_;
	GError* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	gboolean _tmp16_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	gboolean _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	const gchar* _tmp25_;
	gint _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	gchar* _tmp29_;
	GError * _inner_error_;
};

struct _Block85Data {
	int _ref_count_;
	GtkWidget* widget;
};

typedef enum  {
	BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE = -1,
	BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL = 0,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE = 1,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE = 2
} BoxesCPUArchCompatibility;

struct _BoxesFdotimedate1Iface {
	GTypeInterface parent_iface;
	gchar* (*get_timezone) (BoxesFdotimedate1* self);
	void (*set_timezone) (BoxesFdotimedate1* self, const gchar* value);
};


extern gboolean boxes_libvirt_bridge_net_checked;
gboolean boxes_libvirt_bridge_net_checked = FALSE;
extern gboolean boxes_libvirt_bridge_net_available;
gboolean boxes_libvirt_bridge_net_available = FALSE;
extern GVirConnection* boxes_system_virt_connection;
GVirConnection* boxes_system_virt_connection = NULL;

GtkCssProvider* boxes_load_css (const gchar* css);
GdkPixbuf* boxes_load_asset (const gchar* asset, GError** error);
GtkBuilder* boxes_load_ui (const gchar* ui);
void boxes_get_color (const gchar* desc, GdkRGBA* result);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
void boxes_widget_remove (GtkWidget* widget);
OsinfoDevice* boxes_find_device_by_prop (OsinfoDeviceList* devices, const gchar* prop_name, const gchar* prop_value);
GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size);
void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size);
gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1);
static void boxes_ensure_storage_pool_data_free (gpointer _data);
void boxes_ensure_storage_pool (GVirConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirStoragePool* boxes_ensure_storage_pool_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_ensure_storage_pool_co (BoxesEnsureStoragePoolData* _data_);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
GVirConfigStoragePool* boxes_vm_configurator_get_pool_config (GError** error);
static void boxes_ensure_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain);
gboolean boxes_is_libvirt_bridge_net_available (void);
static void boxes_get_system_virt_connection_data_free (gpointer _data);
void boxes_get_system_virt_connection (GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirConnection* boxes_get_system_virt_connection_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_get_system_virt_connection_co (BoxesGetSystemVirtConnectionData* _data_);
static void boxes_get_system_virt_connection_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_selinux_context_default_data_free (gpointer _data);
void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_);
static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_libvirt_kvm_data_free (gpointer _data);
void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_);
static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_);
static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_cpu_vt_capability_data_free (gpointer _data);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_);
static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_module_kvm_loaded_data_free (gpointer _data);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_);
static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_storage_pool_data_free (gpointer _data);
void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_);
static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf);
static guint8* _vala_array_dup5 (guint8* self, int length);
void boxes_draw_as_css_box (GtkWidget* widget);
static Block85Data* block85_data_ref (Block85Data* _data85_);
static void block85_data_unref (void * _userdata_);
static gboolean __lambda206_ (Block85Data* _data85_, cairo_t* cr);
static gboolean ___lambda206__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
GType boxes_cpu_arch_compatibility_get_type (void) G_GNUC_CONST;
BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2);
GType boxes_fdo_timedate1_get_type (void) G_GNUC_CONST;
GType boxes_fdo_timedate1_proxy_get_type (void) G_GNUC_CONST;
guint boxes_fdo_timedate1_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
gchar* boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self);
void boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, const gchar* value);
static void boxes_fdo_timedate1_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static gchar* boxes_fdo_timedate1_dbus_proxy_get_timezone (BoxesFdotimedate1* self);
static void boxes_fdo_timedate1_dbus_proxy_set_timezone (BoxesFdotimedate1* self, const gchar* value);
static void boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init (BoxesFdotimedate1Iface* iface);
static void boxes_fdo_timedate1_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* boxes_fdo_timedate1_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static GVariant* _dbus_boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self);
static gboolean boxes_fdo_timedate1_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, GVariant* _value);
static void _boxes_fdo_timedate1_unregister_object (gpointer user_data);
gchar* boxes_get_timezone (void);
gchar* boxes_get_timezone_from_systemd (GError** error);
gchar* boxes_get_timezone_from_linux (GError** error);
#define BOXES_TZ_FILE "/etc/localtime"
void uuid_generate (guchar* uuid);
void uuid_unparse (guchar* uuid, guchar* output);
gchar* boxes_uuid_generate (void);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
GdkPixbuf* boxes_paint_empty_frame (gint width, gint height, gdouble radius, GdkRGBA* border_color, GdkRGBA* bg_color);
void boxes_paint_frame_background (cairo_t* cr, gint width, gint height, gdouble radius);
void boxes_paint_frame_border (cairo_t* cr, gint width, gint height, gdouble radius);
void boxes_rounded_rectangle (cairo_t* cr, gdouble x, gdouble y, gdouble width, gdouble height, gdouble radius);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static GRegex* _tmp_regex_0 = NULL;
static GRegex* _tmp_regex_1 = NULL;
static const GDBusMethodInfo * const _boxes_fdo_timedate1_dbus_method_info[] = {NULL};
static const GDBusSignalInfo * const _boxes_fdo_timedate1_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _boxes_fdo_timedate1_dbus_property_info_timezone = {-1, "Timezone", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE};
static const GDBusPropertyInfo * const _boxes_fdo_timedate1_dbus_property_info[] = {&_boxes_fdo_timedate1_dbus_property_info_timezone, NULL};
static const GDBusInterfaceInfo _boxes_fdo_timedate1_dbus_interface_info = {-1, "org.freedesktop.timedate1", (GDBusMethodInfo **) (&_boxes_fdo_timedate1_dbus_method_info), (GDBusSignalInfo **) (&_boxes_fdo_timedate1_dbus_signal_info), (GDBusPropertyInfo **) (&_boxes_fdo_timedate1_dbus_property_info)};
static const GDBusInterfaceVTable _boxes_fdo_timedate1_dbus_interface_vtable = {boxes_fdo_timedate1_dbus_interface_method_call, boxes_fdo_timedate1_dbus_interface_get_property, boxes_fdo_timedate1_dbus_interface_set_property};

GtkCssProvider* boxes_load_css (const gchar* css) {
	GtkCssProvider* result = NULL;
	GtkCssProvider* provider = NULL;
	GtkCssProvider* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (css != NULL, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = gtk_css_provider_new ();
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	provider = _tmp0_;
#line 443 "util-app.c"
	{
		GFile* file = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GFile* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = css;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = g_strconcat ("resource:///org/gnome/Boxes/", _tmp1_, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = _tmp2_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = g_file_new_for_uri (_tmp3_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = _tmp4_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp3_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp5_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_css_provider_load_from_file (provider, file, &_inner_error_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (file);
#line 471 "util-app.c"
			goto __catch96_g_error;
		}
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 476 "util-app.c"
	}
	goto __finally96;
	__catch96_g_error:
	{
		GError* e = NULL;
		GError* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		e = _inner_error_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = e;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = _tmp6_->message;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:14: loading css: %s", _tmp7_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 496 "util-app.c"
	}
	__finally96:
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (provider);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 509 "util-app.c"
	}
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = provider;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 515 "util-app.c"
}


GdkPixbuf* boxes_load_asset (const gchar* asset, GError** error) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GdkPixbuf* _tmp4_ = NULL;
	GdkPixbuf* _tmp5_ = NULL;
	GdkPixbuf* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (asset != NULL, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = asset;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strconcat ("/org/gnome/Boxes/icons/", _tmp1_, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = gdk_pixbuf_new_from_resource (_tmp3_, &_inner_error_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp3_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _tmp5_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 551 "util-app.c"
	}
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = _tmp0_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp6_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_tmp0_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 563 "util-app.c"
}


GtkBuilder* boxes_load_ui (const gchar* ui) {
	GtkBuilder* result = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (ui != NULL, NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = gtk_builder_new ();
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	builder = _tmp0_;
#line 578 "util-app.c"
	{
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = ui;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = g_strconcat ("/org/gnome/Boxes/ui/", _tmp1_, NULL, NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = _tmp2_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_builder_add_from_resource (builder, _tmp3_, &_inner_error_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp3_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 595 "util-app.c"
			goto __catch97_g_error;
		}
	}
	goto __finally97;
	__catch97_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		e = _inner_error_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = ui;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = e->message;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error ("util-app.vala:28: Failed to load UI file '%s': %s", _tmp4_, _tmp5_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 617 "util-app.c"
	}
	__finally97:
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (builder);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 630 "util-app.c"
	}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = builder;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 636 "util-app.c"
}


void boxes_get_color (const gchar* desc, GdkRGBA* result) {
	GdkRGBA color = {0};
	const gchar* _tmp0_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (desc != NULL);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	memset (&color, 0, sizeof (GdkRGBA));
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = desc;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gdk_rgba_parse (&color, _tmp0_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = color;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 655 "util-app.c"
}


gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error) {
	gchar* result = NULL;
	xmlParserCtxt* parser = NULL;
	xmlParserCtxt* _tmp0_ = NULL;
	xmlDoc* doc = NULL;
	xmlParserCtxt* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	xmlDoc* _tmp3_ = NULL;
	xmlDoc* _tmp4_ = NULL;
	xmlXPathContext* ctxt = NULL;
	xmlDoc* _tmp6_ = NULL;
	xmlXPathContext* _tmp7_ = NULL;
	xmlXPathObject* obj = NULL;
	xmlXPathContext* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	xmlXPathObject* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	xmlXPathObject* _tmp12_ = NULL;
	xmlXPathObject* _tmp21_ = NULL;
	xmlXPathObjectType _tmp22_ = 0;
	xmlXPathObject* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	GError * _inner_error_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xmldoc != NULL, NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xpath != NULL, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = xmlNewParserCtxt ();
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	parser = _tmp0_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = parser;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = xmldoc;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = xmlCtxtReadDoc (_tmp1_, (xmlChar*) _tmp2_, "doc.xml", NULL, 0);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	doc = _tmp3_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = doc;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp4_ == NULL) {
#line 703 "util-app.c"
		GError* _tmp5_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Can't parse XML doc");
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp5_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 717 "util-app.c"
		} else {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 727 "util-app.c"
		}
	}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = doc;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = xmlXPathNewContext (_tmp6_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	ctxt = _tmp7_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = ctxt;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = xpath;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = xmlXPathEval ((xmlChar*) _tmp9_, _tmp8_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	obj = _tmp10_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = obj;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp12_ == NULL) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = TRUE;
#line 750 "util-app.c"
	} else {
		xmlXPathObject* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = obj;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp13_->stringval;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = _tmp14_ == NULL;
#line 760 "util-app.c"
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp11_) {
#line 764 "util-app.c"
		gboolean _tmp15_ = FALSE;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = required;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp15_) {
#line 770 "util-app.c"
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			GError* _tmp19_ = NULL;
			GError* _tmp20_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = xpath;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = g_strconcat ("Failed to extract xpath ", _tmp16_, NULL);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = _tmp17_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp18_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp20_ = _tmp19_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_tmp18_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = _tmp20_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_propagate_error (error, _inner_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 800 "util-app.c"
			} else {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_clear_error (&_inner_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 812 "util-app.c"
			}
		} else {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 823 "util-app.c"
		}
	}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp21_ = obj;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp22_ = _tmp21_->type;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp22_ != XPATH_STRING) {
#line 832 "util-app.c"
		const gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		GError* _tmp26_ = NULL;
		GError* _tmp27_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp23_ = xpath;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp24_ = g_strconcat ("Failed to extract xpath ", _tmp23_, NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = _tmp24_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp25_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = _tmp26_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp25_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp27_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 862 "util-app.c"
		} else {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 874 "util-app.c"
		}
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp28_ = obj;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp29_ = _tmp28_->stringval;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp30_ = g_strdup (_tmp29_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp30_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlXPathFreeContext0 (ctxt);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlFreeParserCtxt0 (parser);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 891 "util-app.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return self ? g_object_ref (self) : NULL;
#line 898 "util-app.c"
}


void boxes_widget_remove (GtkWidget* widget) {
	GtkContainer* container = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkContainer* _tmp1_ = NULL;
	GtkContainer* _tmp2_ = NULL;
	GtkContainer* _tmp3_ = NULL;
	GtkContainer* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (widget != NULL);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = widget;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = (GtkContainer*) gtk_widget_get_parent (_tmp0_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp1_) : NULL);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	container = _tmp2_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = container;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == NULL) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (container);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 928 "util-app.c"
	}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = container;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = widget;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_container_remove (_tmp4_, _tmp5_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (container);
#line 938 "util-app.c"
}


OsinfoDevice* boxes_find_device_by_prop (OsinfoDeviceList* devices, const gchar* prop_name, const gchar* prop_value) {
	OsinfoDevice* result = NULL;
	OsinfoFilter* filter = NULL;
	OsinfoFilter* _tmp0_ = NULL;
	OsinfoFilter* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	OsinfoList* filtered = NULL;
	OsinfoDeviceList* _tmp4_ = NULL;
	OsinfoFilter* _tmp5_ = NULL;
	OsinfoList* _tmp6_ = NULL;
	OsinfoList* _tmp7_ = NULL;
	gint _tmp8_ = 0;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (devices != NULL, NULL);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_name != NULL, NULL);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_value != NULL, NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = osinfo_filter_new ();
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	filter = _tmp0_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = filter;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = prop_name;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = prop_value;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	osinfo_filter_add_constraint (_tmp1_, _tmp2_, _tmp3_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = devices;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = filter;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = osinfo_list_new_filtered (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp4_) : NULL, _tmp5_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	filtered = _tmp6_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = filtered;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = osinfo_list_get_length (_tmp7_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp8_ > 0) {
#line 987 "util-app.c"
		OsinfoList* _tmp9_ = NULL;
		OsinfoEntity* _tmp10_ = NULL;
		OsinfoDevice* _tmp11_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = filtered;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = osinfo_list_get_nth (_tmp9_, 0);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, osinfo_device_get_type ()) ? ((OsinfoDevice*) _tmp10_) : NULL);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp11_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filtered);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filter);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1005 "util-app.c"
	} else {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filtered);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filter);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1015 "util-app.c"
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (filtered);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (filter);
#line 1021 "util-app.c"
}


GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size) {
	GtkImage* result = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp0_ = NULL;
	GtkImage* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	OsinfoOs* _tmp3_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_ref_sink (_tmp0_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	image = _tmp0_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = image;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = size;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_image_set_pixel_size (_tmp1_, _tmp2_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = os;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ != NULL) {
#line 1048 "util-app.c"
		GtkImage* _tmp4_ = NULL;
		OsinfoOs* _tmp5_ = NULL;
		gint _tmp6_ = 0;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = image;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = os;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = size;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_fetch_os_logo (_tmp4_, _tmp5_, _tmp6_);
#line 1060 "util-app.c"
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = image;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1066 "util-app.c"
}


void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size) {
	gchar* path = NULL;
	OsinfoOs* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (image != NULL);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (os != NULL);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = os;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_strdup (".svg");
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup (".png");
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_strdup (".jpg");
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[0] = _tmp1_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[1] = _tmp2_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[2] = _tmp3_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5__length1 = 3;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = boxes_get_logo_path (_tmp0_, _tmp5_, 3);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp7_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = path;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp8_ == NULL) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1123 "util-app.c"
	}
	{
		GdkPixbuf* pixbuf = NULL;
		const gchar* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		GdkPixbuf* _tmp11_ = NULL;
		GtkImage* _tmp12_ = NULL;
		GdkPixbuf* _tmp13_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = path;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = size;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = gdk_pixbuf_new_from_file_at_size (_tmp9_, _tmp10_, -1, &_inner_error_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		pixbuf = _tmp11_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1142 "util-app.c"
			goto __catch98_g_error;
		}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = image;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = pixbuf;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_image_set_from_pixbuf (_tmp12_, _tmp13_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pixbuf);
#line 1153 "util-app.c"
	}
	goto __finally98;
	__catch98_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_error_ = _inner_error_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = path;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = _error_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_->message;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:101: Error loading logo file '%s': %s", _tmp14_, _tmp16_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_error_);
#line 1176 "util-app.c"
	}
	__finally98:
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1189 "util-app.c"
	}
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 1193 "util-app.c"
}


static void boxes_ensure_storage_pool_data_free (gpointer _data) {
	BoxesEnsureStoragePoolData* _data_;
	_data_ = _data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->connection);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->result);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesEnsureStoragePoolData, _data_);
#line 1206 "util-app.c"
}


void boxes_ensure_storage_pool (GVirConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesEnsureStoragePoolData* _data_;
	GVirConnection* _tmp0_ = NULL;
	GVirConnection* _tmp1_ = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesEnsureStoragePoolData);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_ensure_storage_pool);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_ensure_storage_pool_data_free);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = connection;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->connection);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->connection = _tmp1_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_ensure_storage_pool_co (_data_);
#line 1230 "util-app.c"
}


GVirStoragePool* boxes_ensure_storage_pool_finish (GAsyncResult* _res_, GError** error) {
	GVirStoragePool* result;
	BoxesEnsureStoragePoolData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 1241 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 1251 "util-app.c"
}


static void boxes_ensure_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesEnsureStoragePoolData* _data_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_ensure_storage_pool_co (_data_);
#line 1265 "util-app.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 1272 "util-app.c"
}


static gboolean boxes_ensure_storage_pool_co (BoxesEnsureStoragePoolData* _data_) {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 1281 "util-app.c"
		goto _state_0;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 1285 "util-app.c"
		goto _state_1;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 2:
#line 1289 "util-app.c"
		goto _state_2;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 3:
#line 1293 "util-app.c"
		goto _state_3;
		default:
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 1298 "util-app.c"
	}
	_state_0:
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = _data_->connection;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp1_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp1_ = boxes_get_storage_pool (_data_->_tmp0_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->pool = _data_->_tmp1_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp2_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp2_ = _data_->pool;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_tmp2_ == NULL) {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:108: Creating storage pool..");
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = boxes_vm_configurator_get_pool_config (&_data_->_inner_error_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->config = _data_->_tmp3_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_error_free (_data_->_inner_error_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (_data_->pool);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1337 "util-app.c"
			} else {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1341 "util-app.c"
			}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 1347 "util-app.c"
		}
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->connection;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->config;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = gvir_connection_create_storage_pool (_data_->_tmp5_, _data_->_tmp6_, (guint) 0, &_data_->_inner_error_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = _data_->_tmp7_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_error_free (_data_->_inner_error_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (_data_->config);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (_data_->pool);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1377 "util-app.c"
			} else {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1381 "util-app.c"
			}
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 1387 "util-app.c"
		}
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = _data_->_tmp4_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->pool);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->pool = _data_->_tmp8_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->pool;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gvir_storage_pool_build_async (_data_->_tmp9_, (guint) 0, NULL, boxes_ensure_storage_pool_ready, _data_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 1409 "util-app.c"
		_state_1:
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gvir_storage_pool_build_finish (_data_->_tmp9_, _data_->_res_, &_data_->_inner_error_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_error_free (_data_->_inner_error_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (_data_->_tmp4_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (_data_->config);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (_data_->pool);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1429 "util-app.c"
			} else {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1433 "util-app.c"
			}
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 1439 "util-app.c"
		}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:112: Created storage pool.");
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->config);
#line 1447 "util-app.c"
	}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp10_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp10_ = boxes_get_user_pkgdata ("images");
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->pool_path = _data_->_tmp10_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp11_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp11_ = _data_->pool_path;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_ensure_directory (_data_->_tmp11_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp13_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp13_ = _data_->pool;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp14_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp14_ = gvir_storage_pool_get_info (_data_->_tmp13_, &_data_->_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp12_ = _data_->_tmp14_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->pool);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1485 "util-app.c"
		} else {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1489 "util-app.c"
		}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 1495 "util-app.c"
	}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_tmp12_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp12_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = 0;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_->state;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = FALSE;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = _data_->_tmp17_ == GVIR_STORAGE_POOL_STATE_INACTIVE;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	__vala_GVirStoragePoolInfo_free0 (_data_->_tmp16_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_tmp18_) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = _data_->pool;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 2;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gvir_storage_pool_start_async (_data_->_tmp19_, (guint) 0, NULL, boxes_ensure_storage_pool_ready, _data_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 1529 "util-app.c"
		_state_2:
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gvir_storage_pool_start_finish (_data_->_tmp19_, _data_->_res_, &_data_->_inner_error_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_error_free (_data_->_inner_error_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			__vala_GVirStoragePoolInfo_free0 (_data_->_tmp12_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->pool_path);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (_data_->pool);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1549 "util-app.c"
			} else {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1553 "util-app.c"
			}
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 1559 "util-app.c"
		}
	}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = _data_->pool;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_state_ = 3;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_storage_pool_refresh_async (_data_->_tmp20_, NULL, boxes_ensure_storage_pool_ready, _data_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 1572 "util-app.c"
	_state_3:
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_storage_pool_refresh_finish (_data_->_tmp20_, _data_->_res_, &_data_->_inner_error_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		__vala_GVirStoragePoolInfo_free0 (_data_->_tmp12_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->pool);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1592 "util-app.c"
		} else {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1596 "util-app.c"
		}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 1602 "util-app.c"
	}
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp21_ = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp21_ = _data_->pool;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_storage_pool_set_autostart (_data_->_tmp21_, TRUE, &_data_->_inner_error_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		__vala_GVirStoragePoolInfo_free0 (_data_->_tmp12_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->pool);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1626 "util-app.c"
		} else {
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1630 "util-app.c"
		}
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 1636 "util-app.c"
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->pool;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	__vala_GVirStoragePoolInfo_free0 (_data_->_tmp12_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1648 "util-app.c"
	} else {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1652 "util-app.c"
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	__vala_GVirStoragePoolInfo_free0 (_data_->_tmp12_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->pool);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1668 "util-app.c"
	} else {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1672 "util-app.c"
	}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 1678 "util-app.c"
}


GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection) {
	GVirStoragePool* result = NULL;
	GVirConnection* _tmp0_ = NULL;
	GVirStoragePool* _tmp1_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gvir_connection_find_storage_pool_by_name (_tmp0_, PACKAGE_TARNAME);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp1_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1696 "util-app.c"
}


GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain) {
	GVirStorageVol* result = NULL;
	GVirStoragePool* pool = NULL;
	GVirConnection* _tmp0_ = NULL;
	GVirStoragePool* _tmp1_ = NULL;
	GVirStoragePool* _tmp2_ = NULL;
	GVirStoragePool* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = boxes_get_storage_pool (_tmp0_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pool = _tmp1_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pool;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pool);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1730 "util-app.c"
	}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = pool;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = domain;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = gvir_storage_pool_get_volume (_tmp3_, _tmp5_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp6_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (pool);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1746 "util-app.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 996 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 997 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 997 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 997 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 997 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 1764 "util-app.c"
}


gboolean boxes_is_libvirt_bridge_net_available (void) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp37_ = FALSE;
	GError * _inner_error_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = boxes_libvirt_bridge_net_checked;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0_) {
#line 1777 "util-app.c"
		gboolean _tmp1_ = FALSE;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = boxes_libvirt_bridge_net_available;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp1_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1785 "util-app.c"
	}
	{
		gint sock = 0;
		gint _tmp2_ = 0;
		gint _tmp3_ = 0;
		struct ifreq req = {0};
		gchar* if_name = NULL;
		gchar* _tmp7_ = NULL;
		gboolean _tmp19_ = FALSE;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		GFile* file = NULL;
		GFile* _tmp25_ = NULL;
		guint8* contents = NULL;
		gint contents_length1 = 0;
		gint _contents_size_ = 0;
		guint8* _tmp33_ = NULL;
		gint _tmp33__length1 = 0;
		gboolean _tmp34_ = FALSE;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = socket (AF_INET, SOCK_STREAM, 0);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		sock = _tmp2_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = sock;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp3_ < 0) {
#line 1813 "util-app.c"
			gint _tmp4_ = 0;
			gint _tmp5_ = 0;
			GError* _tmp6_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp4_ = errno;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = g_io_error_from_errno (_tmp4_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp6_ = g_error_new ((GQuark) G_IO_ERROR, _tmp5_, "Failed to create a socket");
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = (GError*) _tmp6_;
#line 1825 "util-app.c"
			goto __catch99_g_error;
		}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		memset (&req, 0, sizeof (struct ifreq));
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = g_strdup ("virbr0");
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if_name = _tmp7_;
#line 1834 "util-app.c"
		{
			gint i = 0;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			i = 0;
#line 1839 "util-app.c"
			{
				gboolean _tmp8_ = FALSE;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp8_ = TRUE;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				while (TRUE) {
#line 1846 "util-app.c"
					gint _tmp10_ = 0;
					const gchar* _tmp11_ = NULL;
					gint _tmp12_ = 0;
					gint _tmp13_ = 0;
					gint _tmp14_ = 0;
					const gchar* _tmp15_ = NULL;
					gint _tmp16_ = 0;
					gchar _tmp17_ = '\0';
					gchar _tmp18_ = '\0';
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					if (!_tmp8_) {
#line 1858 "util-app.c"
						gint _tmp9_ = 0;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						_tmp9_ = i;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						i = _tmp9_ + 1;
#line 1864 "util-app.c"
					}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp8_ = FALSE;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp10_ = i;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp11_ = if_name;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp12_ = strlen (_tmp11_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp13_ = _tmp12_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					if (!(_tmp10_ <= _tmp13_)) {
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						break;
#line 1880 "util-app.c"
					}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp14_ = i;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp15_ = if_name;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp16_ = i;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp17_ = string_get (_tmp15_, (glong) _tmp16_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					req.ifr_name[_tmp14_] = (gchar) _tmp17_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp18_ = req.ifr_name[_tmp14_];
#line 1894 "util-app.c"
				}
			}
		}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp20_ = sock;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = ioctl (_tmp20_, SIOCGIFFLAGS, &req);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp21_ < 0) {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = TRUE;
#line 1906 "util-app.c"
		} else {
			struct ifreq _tmp22_ = {0};
			gshort _tmp23_ = 0;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp22_ = req;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp23_ = _tmp22_.ifr_flags;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = !((_tmp23_ & IFF_UP) == IFF_UP);
#line 1916 "util-app.c"
		}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp19_) {
#line 1920 "util-app.c"
			const gchar* _tmp24_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp24_ = if_name;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_debug ("util-app.vala:162: Interface '%s' is either not available or not up.", _tmp24_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = FALSE;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (if_name);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			 (&req);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 1934 "util-app.c"
		}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = g_file_new_for_path ("/etc/qemu/bridge.conf");
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp25_;
#line 1940 "util-app.c"
		{
			GFile* _tmp26_ = NULL;
			guint8* _tmp27_ = NULL;
			gsize _tmp28_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp26_ = file;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_file_load_contents (_tmp26_, NULL, &_tmp27_, &_tmp28_, NULL, &_inner_error_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents = (g_free (contents), NULL);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents = _tmp27_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents_length1 = _tmp28_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_contents_size_ = contents_length1;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
#line 1961 "util-app.c"
					goto __catch100_g_io_error_not_found;
				}
				goto __finally100;
			}
		}
		goto __finally100;
		__catch100_g_io_error_not_found:
		{
			GError* _error_ = NULL;
			GFile* _tmp29_ = NULL;
			GFile* _tmp30_ = NULL;
			guint8* _tmp31_ = NULL;
			gsize _tmp32_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_error_ = _inner_error_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp29_ = g_file_new_for_path ("/etc/qemu-kvm/bridge.conf");
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (file);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			file = _tmp29_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp30_ = file;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_file_load_contents (_tmp30_, NULL, &_tmp31_, &_tmp32_, NULL, &_inner_error_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents = (g_free (contents), NULL);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents = _tmp31_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents_length1 = _tmp32_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_contents_size_ = contents_length1;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_error_free0 (_error_);
#line 2001 "util-app.c"
				goto __finally100;
			}
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (_error_);
#line 2006 "util-app.c"
		}
		__finally100:
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents = (g_free (contents), NULL);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (file);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (if_name);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			 (&req);
#line 2019 "util-app.c"
			goto __catch99_g_error;
		}
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp33_ = contents;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp33__length1 = contents_length1;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp34_ = g_regex_match_simple ("^allow.*virbr0", (const gchar*) _tmp33_, 0, 0);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_libvirt_bridge_net_available = _tmp34_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents = (g_free (contents), NULL);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (if_name);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		 (&req);
#line 2038 "util-app.c"
	}
	goto __finally99;
	__catch99_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_error_ = _inner_error_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp35_ = _error_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp36_ = _tmp35_->message;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:179: %s", _tmp36_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_libvirt_bridge_net_available = FALSE;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_error_);
#line 2060 "util-app.c"
	}
	__finally99:
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2071 "util-app.c"
	}
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_libvirt_bridge_net_checked = TRUE;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp37_ = boxes_libvirt_bridge_net_available;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp37_;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 2081 "util-app.c"
}


static void boxes_get_system_virt_connection_data_free (gpointer _data) {
	BoxesGetSystemVirtConnectionData* _data_;
	_data_ = _data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->result);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesGetSystemVirtConnectionData, _data_);
#line 2092 "util-app.c"
}


void boxes_get_system_virt_connection (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesGetSystemVirtConnectionData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesGetSystemVirtConnectionData);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_get_system_virt_connection);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_get_system_virt_connection_data_free);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_get_system_virt_connection_co (_data_);
#line 2106 "util-app.c"
}


GVirConnection* boxes_get_system_virt_connection_finish (GAsyncResult* _res_, GError** error) {
	GVirConnection* result;
	BoxesGetSystemVirtConnectionData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 2117 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2127 "util-app.c"
}


static void boxes_get_system_virt_connection_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesGetSystemVirtConnectionData* _data_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_get_system_virt_connection_co (_data_);
#line 2141 "util-app.c"
}


static gboolean boxes_get_system_virt_connection_co (BoxesGetSystemVirtConnectionData* _data_) {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2150 "util-app.c"
		goto _state_0;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2154 "util-app.c"
		goto _state_1;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 2:
#line 2158 "util-app.c"
		goto _state_2;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 3:
#line 2162 "util-app.c"
		goto _state_3;
		default:
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2167 "util-app.c"
	}
	_state_0:
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = boxes_system_virt_connection;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_tmp0_ != NULL) {
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = boxes_system_virt_connection;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _g_object_ref0 (_data_->_tmp1_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = _data_->_tmp2_;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2190 "util-app.c"
		} else {
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2194 "util-app.c"
		}
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2200 "util-app.c"
	}
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp3_ = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp3_ = gvir_connection_new ("qemu+unix:///system");
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (boxes_system_virt_connection);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_system_virt_connection = _data_->_tmp3_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp4_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp4_ = boxes_system_virt_connection;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_state_ = 1;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_connection_open_read_only_async (_data_->_tmp4_, NULL, boxes_get_system_virt_connection_ready, _data_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2220 "util-app.c"
	_state_1:
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_connection_open_read_only_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2234 "util-app.c"
		} else {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2238 "util-app.c"
		}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2244 "util-app.c"
	}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:199: Connected to system libvirt, now fetching domains..");
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp5_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp5_ = boxes_system_virt_connection;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_state_ = 2;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_connection_fetch_domains_async (_data_->_tmp5_, NULL, boxes_get_system_virt_connection_ready, _data_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2258 "util-app.c"
	_state_2:
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_connection_fetch_domains_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2272 "util-app.c"
		} else {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2276 "util-app.c"
		}
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2282 "util-app.c"
	}
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp6_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp6_ = boxes_system_virt_connection;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_state_ = 3;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_connection_fetch_networks_async (_data_->_tmp6_, NULL, boxes_get_system_virt_connection_ready, _data_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2294 "util-app.c"
	_state_3:
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gvir_connection_fetch_networks_finish (_data_->_tmp6_, _data_->_res_, &_data_->_inner_error_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2308 "util-app.c"
		} else {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2312 "util-app.c"
		}
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2318 "util-app.c"
	}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp7_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp7_ = boxes_system_virt_connection;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp8_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp8_ = _g_object_ref0 (_data_->_tmp7_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_tmp8_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2334 "util-app.c"
	} else {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2338 "util-app.c"
	}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2348 "util-app.c"
	} else {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2352 "util-app.c"
	}
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2358 "util-app.c"
}


gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1) {
	gchar* result = NULL;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar* path = NULL;
	OsinfoOs* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GFile* file = NULL;
	const gchar* _tmp10_ = NULL;
	GFile* _tmp11_ = NULL;
	GFile* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	GFile* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = extensions;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0__length1 = extensions_length1;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0__length1 == 0) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2396 "util-app.c"
	}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = os;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp1_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = extensions;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4__length1 = extensions_length1;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_[0];
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = g_strconcat (_tmp3_, _tmp5_, NULL);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = boxes_get_pixmap (_tmp7_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp7_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp9_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = path;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = g_file_new_for_path (_tmp10_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	file = _tmp11_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = file;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = g_file_query_exists (_tmp12_, NULL);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_tmp13_) {
#line 2434 "util-app.c"
		OsinfoOs* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		gchar** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		GFile* _tmp23_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = os;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = osinfo_os_get_distro (_tmp14_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17_ = extensions;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17__length1 = extensions_length1;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp18_ = _tmp17_[0];
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp19_ = g_strconcat (_tmp16_, _tmp18_, NULL);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp20_ = _tmp19_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = boxes_get_pixmap (_tmp20_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp21_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp20_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp22_ = path;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp23_ = g_file_new_for_path (_tmp22_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp23_;
#line 2478 "util-app.c"
	}
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp24_ = file;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp25_ = g_file_query_exists (_tmp24_, NULL);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp25_) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = path;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2492 "util-app.c"
	} else {
		OsinfoOs* _tmp26_ = NULL;
		gchar** _tmp27_ = NULL;
		gint _tmp27__length1 = 0;
		gchar** _tmp28_ = NULL;
		gint _tmp28__length1 = 0;
		gchar* _tmp29_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = os;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = extensions;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27__length1 = extensions_length1;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = extensions;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28__length1 = extensions_length1;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp29_ = boxes_get_logo_path (_tmp26_, _tmp27_ + 1, _tmp28__length1 - 1);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp29_;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2520 "util-app.c"
	}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (file);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 2526 "util-app.c"
}


static void boxes_check_selinux_context_default_data_free (gpointer _data) {
	BoxesCheckSelinuxContextDefaultData* _data_;
	_data_ = _data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckSelinuxContextDefaultData, _data_);
#line 2535 "util-app.c"
}


void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckSelinuxContextDefaultData);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_selinux_context_default);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_selinux_context_default_data_free);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 2549 "util-app.c"
}


gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 2562 "util-app.c"
	} else {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 2566 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2574 "util-app.c"
}


static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 2588 "util-app.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 964 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 964 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 965 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		separator = "";
#line 2605 "util-app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 2615 "util-app.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 2625 "util-app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 2631 "util-app.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 2642 "util-app.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 2654 "util-app.c"
		} else {
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 2658 "util-app.c"
		}
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 2662 "util-app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 2666 "util-app.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 969 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 2689 "util-app.c"
		{
			gboolean _tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 2698 "util-app.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 2711 "util-app.c"
					gint _tmp10_ = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 2717 "util-app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 2727 "util-app.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 2739 "util-app.c"
				} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 2743 "util-app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 2749 "util-app.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 2760 "util-app.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 2775 "util-app.c"
					} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 2779 "util-app.c"
					}
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 2783 "util-app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 2789 "util-app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 2801 "util-app.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 2822 "util-app.c"
				} else {
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 2826 "util-app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 971 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 2832 "util-app.c"
			}
		}
#line 973 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 973 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 2839 "util-app.c"
			gchar* _tmp32_ = NULL;
#line 974 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 974 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 974 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			return result;
#line 2847 "util-app.c"
		}
#line 976 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 976 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 976 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 977 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 977 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 977 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 977 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 977 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 977 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 979 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 979 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 979 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 980 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 980 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 980 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 980 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 980 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 980 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 2885 "util-app.c"
		{
			gboolean _tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 2894 "util-app.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 2910 "util-app.c"
					gint _tmp47_ = 0;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 2916 "util-app.c"
				}
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 981 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 2930 "util-app.c"
				}
#line 982 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 982 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 982 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 982 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 2950 "util-app.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 2965 "util-app.c"
				} else {
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 2969 "util-app.c"
				}
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 983 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 2977 "util-app.c"
			}
		}
#line 986 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 986 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		res = NULL;
#line 986 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 986 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 2988 "util-app.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 988 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 988 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 988 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 2997 "util-app.c"
	}
}


static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_) {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3007 "util-app.c"
		goto _state_0;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3011 "util-app.c"
		goto _state_1;
		default:
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3016 "util-app.c"
	}
	_state_0:
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 3027 "util-app.c"
	{
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("restorecon");
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("-nrv");
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = boxes_get_user_pkgconfig (NULL);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = boxes_get_user_pkgdata (NULL);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = boxes_get_user_pkgcache (NULL);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = g_new0 (gchar*, 5 + 1);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[0] = _data_->_tmp1_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[1] = _data_->_tmp2_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[2] = _data_->_tmp3_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[3] = _data_->_tmp4_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[4] = _data_->_tmp5_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp6_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 5;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7__length1 = 0;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->argv;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7__length1 = _data_->argv_length1;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp7_, _data_->_tmp7__length1, NULL, boxes_check_selinux_context_default_ready, _data_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3089 "util-app.c"
		_state_1:
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp8_, NULL, &_data_->_inner_error_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp8_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 3105 "util-app.c"
				goto __catch101_g_spawn_error_noexec;
			}
			goto __catch101_g_error;
		}
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->standard_output;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = 0;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = strlen (_data_->_tmp9_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = 0;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_tmp11_ == 0) {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->result = TRUE;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3134 "util-app.c"
			} else {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3138 "util-app.c"
			}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 3144 "util-app.c"
		}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12__length1 = 0;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->argv;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12__length1 = _data_->argv_length1;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_strdup ("-r");
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp12_[1]);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_[1] = _data_->_tmp13_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp12_[1];
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = _ ("Your SELinux context looks incorrect, you can try to fix it by running" \
":\n" \
"%s");
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16__length1 = 0;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = _data_->argv;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16__length1 = _data_->argv_length1;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = _vala_g_strjoinv (" ", _data_->_tmp16_, _data_->_tmp16__length1);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = _data_->_tmp17_;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = g_strdup_printf (_data_->_tmp15_, _data_->_tmp18_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp19_;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp18_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3206 "util-app.c"
		} else {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3210 "util-app.c"
		}
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3216 "util-app.c"
	}
	goto __finally101;
	__catch101_g_spawn_error_noexec:
	{
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = _ ("SELinux not installed?");
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp21_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = TRUE;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3245 "util-app.c"
		} else {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3249 "util-app.c"
		}
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3255 "util-app.c"
	}
	goto __finally101;
	__catch101_g_error:
	{
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _data_->_vala1__error_;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:250: %s", _data_->_tmp23_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 3276 "util-app.c"
	}
	__finally101:
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3287 "util-app.c"
	}
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3295 "util-app.c"
	} else {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3299 "util-app.c"
	}
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3309 "util-app.c"
	} else {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3313 "util-app.c"
	}
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3319 "util-app.c"
}


static void boxes_check_libvirt_kvm_data_free (gpointer _data) {
	BoxesCheckLibvirtKvmData* _data_;
	_data_ = _data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckLibvirtKvmData, _data_);
#line 3328 "util-app.c"
}


void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckLibvirtKvmData);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_libvirt_kvm);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_libvirt_kvm_data_free);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 3342 "util-app.c"
}


gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckLibvirtKvmData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3355 "util-app.c"
}


static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 3369 "util-app.c"
}


static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_) {
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3378 "util-app.c"
		goto _state_0;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3382 "util-app.c"
		goto _state_1;
		default:
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3387 "util-app.c"
	}
	_state_0:
	{
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = g_strdup ("virsh");
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("capabilities");
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[0] = _data_->_tmp0_;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[1] = _data_->_tmp1_;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp2_;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 2;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3__length1 = 0;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->argv;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3__length1 = _data_->argv_length1;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp3_, _data_->_tmp3__length1, NULL, boxes_check_libvirt_kvm_ready, _data_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3433 "util-app.c"
		_state_1:
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp4_, NULL, &_data_->_inner_error_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp4_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 3449 "util-app.c"
				goto __catch102_g_spawn_error_noexec;
			}
			goto __catch102_g_error;
		}
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->standard_output;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = boxes_extract_xpath (_data_->_tmp5_, "string(/capabilities/guest[os_type='hvm']/arch/domain[@type='kvm']/emu" \
"lator)", FALSE, &_data_->_inner_error_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->kvm = _data_->_tmp6_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 3472 "util-app.c"
				goto __catch102_g_spawn_error_noexec;
			}
			goto __catch102_g_error;
		}
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->kvm;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = 0;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = strlen (_data_->_tmp7_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = 0;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = _data_->_tmp9_ != 0;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->kvm);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3501 "util-app.c"
		} else {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3505 "util-app.c"
		}
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3511 "util-app.c"
	}
	goto __finally102;
	__catch102_g_spawn_error_noexec:
	{
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("util-app.vala:268: libvirt is not installed correctly");
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3524 "util-app.c"
	}
	goto __finally102;
	__catch102_g_error:
	{
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_vala1__error_;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_->message;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:270: %s", _data_->_tmp11_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 3545 "util-app.c"
	}
	__finally102:
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3556 "util-app.c"
	}
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3564 "util-app.c"
	} else {
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3568 "util-app.c"
	}
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3578 "util-app.c"
	} else {
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3582 "util-app.c"
	}
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3588 "util-app.c"
}


static void boxes_check_cpu_vt_capability_data_free (gpointer _data) {
	BoxesCheckCpuVtCapabilityData* _data_;
	_data_ = _data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckCpuVtCapabilityData, _data_);
#line 3597 "util-app.c"
}


void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckCpuVtCapabilityData);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_cpu_vt_capability);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_cpu_vt_capability_data_free);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 3611 "util-app.c"
}


gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckCpuVtCapabilityData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3624 "util-app.c"
}


static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 3638 "util-app.c"
}


static inline GRegex* _thread_safe_regex_init (GRegex** re, const gchar * pattern, GRegexMatchFlags match_options) {
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_once_init_enter ((volatile gsize*) re)) {
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		GRegex* val = g_regex_new (pattern, match_options, 0, NULL);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_once_init_leave ((volatile gsize*) re, (gsize) val);
#line 3649 "util-app.c"
	}
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return *re;
#line 3653 "util-app.c"
}


static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_) {
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3662 "util-app.c"
		goto _state_0;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3666 "util-app.c"
		goto _state_1;
		default:
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3671 "util-app.c"
	}
	_state_0:
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/cpuinfo");
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 3682 "util-app.c"
	{
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->file;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_file_read (_data_->_tmp2_, NULL, &_data_->_inner_error_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->_tmp3_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 3696 "util-app.c"
			goto __catch103_g_error;
		}
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp1_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp4_;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = _data_->stream;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp6_, G_PRIORITY_DEFAULT, NULL, boxes_check_cpu_vt_capability_ready, _data_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 3719 "util-app.c"
			_state_1:
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = g_data_input_stream_read_line_finish (_data_->_tmp6_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = _data_->_tmp7_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->_tmp1_);
#line 3735 "util-app.c"
				goto __catch103_g_error;
			}
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = _data_->_tmp5_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp8_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = _data_->line;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp9_ != NULL)) {
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3758 "util-app.c"
			}
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = NULL;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = FALSE;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_0, "^flags.*(vmx|svm)", 0), _data_->_tmp10_, 0, NULL);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp11_;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = _data_->_result_;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp12_) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3780 "util-app.c"
			}
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->_tmp5_);
#line 3784 "util-app.c"
		}
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp1_);
#line 3792 "util-app.c"
	}
	goto __finally103;
	__catch103_g_error:
	{
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = _data_->_error_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp13_->message;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:289: Failed to read file /proc/cpuinfo: %s", _data_->_tmp14_);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3813 "util-app.c"
	}
	__finally103:
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3826 "util-app.c"
	}
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_cpu_vt_capability: ", _data_->_tmp17_, NULL);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:292: %s", _data_->_tmp19_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3862 "util-app.c"
	} else {
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3866 "util-app.c"
	}
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3878 "util-app.c"
	} else {
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3882 "util-app.c"
	}
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3888 "util-app.c"
}


static void boxes_check_module_kvm_loaded_data_free (gpointer _data) {
	BoxesCheckModuleKvmLoadedData* _data_;
	_data_ = _data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckModuleKvmLoadedData, _data_);
#line 3897 "util-app.c"
}


void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckModuleKvmLoadedData);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_module_kvm_loaded);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_module_kvm_loaded_data_free);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3911 "util-app.c"
}


gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckModuleKvmLoadedData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3924 "util-app.c"
}


static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3938 "util-app.c"
}


static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_) {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3947 "util-app.c"
		goto _state_0;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3951 "util-app.c"
		goto _state_1;
		default:
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3956 "util-app.c"
	}
	_state_0:
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/modules");
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 3967 "util-app.c"
	{
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->file;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_file_read (_data_->_tmp2_, NULL, &_data_->_inner_error_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->_tmp3_;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 3981 "util-app.c"
			goto __catch104_g_error;
		}
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp1_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp4_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = _data_->stream;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp6_, G_PRIORITY_DEFAULT, NULL, boxes_check_module_kvm_loaded_ready, _data_);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 4004 "util-app.c"
			_state_1:
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = g_data_input_stream_read_line_finish (_data_->_tmp6_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = _data_->_tmp7_;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->_tmp1_);
#line 4020 "util-app.c"
				goto __catch104_g_error;
			}
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = _data_->_tmp5_;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp8_;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = _data_->line;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp9_ != NULL)) {
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 4043 "util-app.c"
			}
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = NULL;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = FALSE;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_1, "^(kvm_intel|kvm_amd)", 0), _data_->_tmp10_, 0, NULL);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp11_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = _data_->_result_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp12_) {
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 4065 "util-app.c"
			}
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->_tmp5_);
#line 4069 "util-app.c"
		}
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp1_);
#line 4077 "util-app.c"
	}
	goto __finally104;
	__catch104_g_error:
	{
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = _data_->_error_;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp13_->message;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:309: Failed to read file /proc/modules: %s", _data_->_tmp14_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 4098 "util-app.c"
	}
	__finally104:
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4111 "util-app.c"
	}
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_module_kvm_loaded: ", _data_->_tmp17_, NULL);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:312: %s", _data_->_tmp19_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4147 "util-app.c"
	} else {
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4151 "util-app.c"
	}
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4163 "util-app.c"
	} else {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4167 "util-app.c"
	}
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 4173 "util-app.c"
}


static void boxes_check_storage_pool_data_free (gpointer _data) {
	BoxesCheckStoragePoolData* _data_;
	_data_ = _data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckStoragePoolData, _data_);
#line 4182 "util-app.c"
}


void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckStoragePoolData);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_storage_pool);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_storage_pool_data_free);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_storage_pool_co (_data_);
#line 4196 "util-app.c"
}


gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckStoragePoolData* _data_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 4209 "util-app.c"
	} else {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 4213 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 4221 "util-app.c"
}


static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_storage_pool_co (_data_);
#line 4235 "util-app.c"
}


static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 4244 "util-app.c"
		goto _state_0;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 4248 "util-app.c"
		goto _state_1;
		default:
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 4253 "util-app.c"
	}
	_state_0:
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 4264 "util-app.c"
	{
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("virsh");
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("pool-dumpxml");
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_strdup (PACKAGE_TARNAME);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[0] = _data_->_tmp1_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[1] = _data_->_tmp2_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[2] = _data_->_tmp3_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp4_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 3;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5__length1 = 0;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->argv;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5__length1 = _data_->argv_length1;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp5_, _data_->_tmp5__length1, NULL, boxes_check_storage_pool_ready, _data_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4314 "util-app.c"
		_state_1:
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp6_, NULL, &_data_->_inner_error_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp6_;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 4328 "util-app.c"
			goto __catch105_g_error;
		}
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = _data_->standard_output;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = boxes_extract_xpath (_data_->_tmp8_, "string(/pool[@type='dir']/target/path)", FALSE, &_data_->_inner_error_);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->_tmp9_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 4347 "util-app.c"
			goto __catch105_g_error;
		}
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_tmp7_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->pool_path = _data_->_tmp10_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp7_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 4366 "util-app.c"
	}
	goto __finally105;
	__catch105_g_error:
	{
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_error_;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->_tmp11_->message;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:327: %s", _data_->_tmp12_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = _ ("Could not get 'gnome-boxes' storage pool information from libvirt. Mak" \
"e sure 'virsh -c qemu:///session pool-dumpxml gnome-boxes' is working.");
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = g_strdup (_data_->_tmp13_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp14_;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4407 "util-app.c"
		} else {
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4411 "util-app.c"
		}
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4417 "util-app.c"
	}
	__finally105:
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4430 "util-app.c"
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = NULL;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->pool_path;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = FALSE;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = g_file_test (_data_->_tmp15_, G_FILE_TEST_EXISTS);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp16_) {
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but this director" \
"y does not exist");
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = _data_->pool_path;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = g_strdup_printf (_data_->_tmp17_, _data_->_tmp18_);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp19_;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4466 "util-app.c"
		} else {
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4470 "util-app.c"
		}
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4476 "util-app.c"
	}
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = _data_->pool_path;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp21_ = FALSE;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp21_ = g_file_test (_data_->_tmp20_, G_FILE_TEST_IS_DIR);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp21_) {
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not a dire" \
"ctory");
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = _data_->pool_path;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp24_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp24_ = g_strdup_printf (_data_->_tmp22_, _data_->_tmp23_);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp24_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4512 "util-app.c"
		} else {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4516 "util-app.c"
		}
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4522 "util-app.c"
	}
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = _data_->pool_path;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp26_ = 0;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp26_ = access (_data_->_tmp25_, (R_OK | W_OK) | X_OK);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_tmp26_ != 0) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp27_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp27_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not user-r" \
"eadable/writable");
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = _data_->pool_path;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp29_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp29_ = g_strdup_printf (_data_->_tmp27_, _data_->_tmp28_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp29_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4558 "util-app.c"
		} else {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4562 "util-app.c"
		}
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4568 "util-app.c"
	}
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = TRUE;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4578 "util-app.c"
	} else {
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4582 "util-app.c"
	}
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4594 "util-app.c"
	} else {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4598 "util-app.c"
	}
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 4604 "util-app.c"
}


static guint8* _vala_array_dup5 (guint8* self, int length) {
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return g_memdup (self, length * sizeof (guint8));
#line 4611 "util-app.c"
}


GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf) {
	GdkPixbuf* result = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const guint8 ALPHA_TRESHOLD = (guint8) 50;
#line 4619 "util-app.c"
	gboolean _tmp0_ = FALSE;
	GdkPixbuf* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	GdkPixbuf* _tmp5_ = NULL;
	gint width = 0;
	GdkPixbuf* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint height = 0;
	GdkPixbuf* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint rowstride = 0;
	GdkPixbuf* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	guint8* orig_pixels = NULL;
	GdkPixbuf* _tmp12_ = NULL;
	guint8* _tmp13_ = NULL;
	gint orig_pixels_length1 = 0;
	gint _orig_pixels_size_ = 0;
	guint8* pixels = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	guint8* _tmp16_ = NULL;
	gint pixels_length1 = 0;
	gint _pixels_size_ = 0;
	guint8* _tmp62_ = NULL;
	gint _tmp62__length1 = 0;
	guint8* _tmp63_ = NULL;
	gint _tmp63__length1 = 0;
	GdkPixbuf* _tmp64_ = NULL;
	GdkColorspace _tmp65_ = 0;
	gint _tmp66_ = 0;
	gint _tmp67_ = 0;
	gint _tmp68_ = 0;
	GdkPixbuf* _tmp69_ = NULL;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = pixbuf;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = gdk_pixbuf_get_n_channels (_tmp1_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == 4) {
#line 4662 "util-app.c"
		GdkPixbuf* _tmp3_ = NULL;
		gint _tmp4_ = 0;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = pixbuf;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = gdk_pixbuf_get_bits_per_sample (_tmp3_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp4_ == 8;
#line 4671 "util-app.c"
	} else {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = FALSE;
#line 4675 "util-app.c"
	}
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = pixbuf;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (_tmp0_, _tmp5_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = pixbuf;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = gdk_pixbuf_get_width (_tmp6_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	width = _tmp7_;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = pixbuf;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = gdk_pixbuf_get_height (_tmp8_);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	height = _tmp9_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = pixbuf;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = gdk_pixbuf_get_rowstride (_tmp10_);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	rowstride = _tmp11_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = pixbuf;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = gdk_pixbuf_get_pixels (_tmp12_);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels = _tmp13_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels_length1 = -1;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_orig_pixels_size_ = orig_pixels_length1;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = rowstride;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = height;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp16_ = g_new0 (guint8, _tmp14_ * _tmp15_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = _tmp16_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels_length1 = _tmp14_ * _tmp15_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_pixels_size_ = pixels_length1;
#line 4721 "util-app.c"
	{
		gint i = 0;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		i = 0;
#line 4726 "util-app.c"
		{
			gboolean _tmp17_ = FALSE;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = TRUE;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			while (TRUE) {
#line 4733 "util-app.c"
				gint _tmp19_ = 0;
				gint _tmp20_ = 0;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!_tmp17_) {
#line 4738 "util-app.c"
					gint _tmp18_ = 0;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp18_ = i;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					i = _tmp18_ + 1;
#line 4744 "util-app.c"
				}
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp17_ = FALSE;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = i;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp20_ = height;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!(_tmp19_ < _tmp20_)) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					break;
#line 4756 "util-app.c"
				}
				{
					gint j = 0;
					gint k = 0;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					j = 0;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					k = 0;
#line 4765 "util-app.c"
					{
						gboolean _tmp21_ = FALSE;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						_tmp21_ = TRUE;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						while (TRUE) {
#line 4772 "util-app.c"
							gint _tmp24_ = 0;
							gint _tmp25_ = 0;
							gint orig_index = 0;
							gint _tmp26_ = 0;
							gint _tmp27_ = 0;
							gint _tmp28_ = 0;
							gint index = 0;
							gint _tmp29_ = 0;
							gint _tmp30_ = 0;
							gint _tmp31_ = 0;
							guint8* _tmp32_ = NULL;
							gint _tmp32__length1 = 0;
							gint _tmp33_ = 0;
							guint8 _tmp34_ = 0U;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!_tmp21_) {
#line 4789 "util-app.c"
								gint _tmp22_ = 0;
								gint _tmp23_ = 0;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp22_ = j;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								j = _tmp22_ + 4;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp23_ = k;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								k = _tmp23_ + 3;
#line 4800 "util-app.c"
							}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp21_ = FALSE;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp24_ = j;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp25_ = width;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!(_tmp24_ < (_tmp25_ * 4))) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								break;
#line 4812 "util-app.c"
							}
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp26_ = rowstride;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp27_ = i;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp28_ = j;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							orig_index = (_tmp26_ * _tmp27_) + _tmp28_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp29_ = rowstride;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp30_ = i;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp31_ = k;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							index = (_tmp29_ * _tmp30_) + _tmp31_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp32_ = orig_pixels;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp32__length1 = orig_pixels_length1;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp33_ = orig_index;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp34_ = _tmp32_[_tmp33_ + 3];
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (_tmp34_ < ALPHA_TRESHOLD) {
#line 4840 "util-app.c"
								guint8* _tmp35_ = NULL;
								gint _tmp35__length1 = 0;
								gint _tmp36_ = 0;
								guint8 _tmp37_ = 0U;
								guint8* _tmp38_ = NULL;
								gint _tmp38__length1 = 0;
								gint _tmp39_ = 0;
								guint8 _tmp40_ = 0U;
								guint8* _tmp41_ = NULL;
								gint _tmp41__length1 = 0;
								gint _tmp42_ = 0;
								guint8 _tmp43_ = 0U;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp35_ = pixels;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp35__length1 = pixels_length1;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp36_ = index;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp35_[_tmp36_] = (guint8) 0xFF;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp37_ = _tmp35_[_tmp36_];
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_ = pixels;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38__length1 = pixels_length1;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp39_ = index;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_[_tmp39_ + 1] = (guint8) 0xFF;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp40_ = _tmp38_[_tmp39_ + 1];
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_ = pixels;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41__length1 = pixels_length1;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp42_ = index;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_[_tmp42_ + 2] = (guint8) 0xFF;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp43_ = _tmp41_[_tmp42_ + 2];
#line 4883 "util-app.c"
							} else {
								guint8* _tmp44_ = NULL;
								gint _tmp44__length1 = 0;
								gint _tmp45_ = 0;
								guint8* _tmp46_ = NULL;
								gint _tmp46__length1 = 0;
								gint _tmp47_ = 0;
								guint8 _tmp48_ = 0U;
								guint8 _tmp49_ = 0U;
								guint8* _tmp50_ = NULL;
								gint _tmp50__length1 = 0;
								gint _tmp51_ = 0;
								guint8* _tmp52_ = NULL;
								gint _tmp52__length1 = 0;
								gint _tmp53_ = 0;
								guint8 _tmp54_ = 0U;
								guint8 _tmp55_ = 0U;
								guint8* _tmp56_ = NULL;
								gint _tmp56__length1 = 0;
								gint _tmp57_ = 0;
								guint8* _tmp58_ = NULL;
								gint _tmp58__length1 = 0;
								gint _tmp59_ = 0;
								guint8 _tmp60_ = 0U;
								guint8 _tmp61_ = 0U;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_ = pixels;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44__length1 = pixels_length1;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp45_ = index;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp46_ = orig_pixels;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp46__length1 = orig_pixels_length1;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47_ = orig_index;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp48_ = _tmp46_[_tmp47_];
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_[_tmp45_] = _tmp48_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp49_ = _tmp44_[_tmp45_];
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50_ = pixels;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50__length1 = pixels_length1;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp51_ = index;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp52_ = orig_pixels;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp52__length1 = orig_pixels_length1;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53_ = orig_index;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp54_ = _tmp52_[_tmp53_ + 1];
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50_[_tmp51_ + 1] = _tmp54_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp55_ = _tmp50_[_tmp51_ + 1];
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56_ = pixels;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56__length1 = pixels_length1;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp57_ = index;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp58_ = orig_pixels;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp58__length1 = orig_pixels_length1;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59_ = orig_index;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp60_ = _tmp58_[_tmp59_ + 2];
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56_[_tmp57_ + 2] = _tmp60_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp61_ = _tmp56_[_tmp57_ + 2];
#line 4963 "util-app.c"
							}
						}
					}
				}
			}
		}
	}
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp62_ = pixels;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp62__length1 = pixels_length1;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp63_ = (_tmp62_ != NULL) ? _vala_array_dup5 (_tmp62_, _tmp62__length1) : ((gpointer) _tmp62_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp63__length1 = _tmp62__length1;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp64_ = pixbuf;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp65_ = gdk_pixbuf_get_colorspace (_tmp64_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp66_ = width;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp67_ = height;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp68_ = rowstride;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp69_ = gdk_pixbuf_new_from_data (_tmp63_, _tmp65_, FALSE, 8, _tmp66_, _tmp67_, _tmp68_, (GdkPixbufDestroyNotify) NULL, NULL);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp69_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = (g_free (pixels), NULL);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4997 "util-app.c"
}


static Block85Data* block85_data_ref (Block85Data* _data85_) {
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data85_->_ref_count_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data85_;
#line 5006 "util-app.c"
}


static void block85_data_unref (void * _userdata_) {
	Block85Data* _data85_;
	_data85_ = (Block85Data*) _userdata_;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data85_->_ref_count_)) {
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data85_->widget);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block85Data, _data85_);
#line 5019 "util-app.c"
	}
}


static gboolean __lambda206_ (Block85Data* _data85_, cairo_t* cr) {
	gboolean result = FALSE;
	GtkStyleContext* context = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkStyleContext* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkAllocation allocation = {0};
	GtkWidget* _tmp3_ = NULL;
	GtkAllocation _tmp4_ = {0};
	cairo_t* _tmp5_ = NULL;
	GtkAllocation _tmp6_ = {0};
	gint _tmp7_ = 0;
	GtkAllocation _tmp8_ = {0};
	gint _tmp9_ = 0;
	cairo_t* _tmp10_ = NULL;
	GtkAllocation _tmp11_ = {0};
	gint _tmp12_ = 0;
	GtkAllocation _tmp13_ = {0};
	gint _tmp14_ = 0;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _data85_->widget;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_get_style_context (_tmp0_);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	context = _tmp2_;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _data85_->widget;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_widget_get_allocation (_tmp3_, &_tmp4_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	allocation = _tmp4_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = cr;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = allocation;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_.width;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = allocation;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_.height;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_background (context, _tmp5_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp7_, (gdouble) _tmp9_);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = cr;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = allocation;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = _tmp11_.width;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = allocation;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = _tmp13_.height;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_frame (context, _tmp10_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp12_, (gdouble) _tmp14_);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (context);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 5089 "util-app.c"
}


static gboolean ___lambda206__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda206_ (self, cr);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 5098 "util-app.c"
}


void boxes_draw_as_css_box (GtkWidget* widget) {
	Block85Data* _data85_;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (widget != NULL);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data85_ = g_slice_new0 (Block85Data);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data85_->_ref_count_ = 1;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = widget;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data85_->widget);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data85_->widget = _tmp1_;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data85_->widget;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_signal_connect_data (_tmp2_, "draw", (GCallback) ___lambda206__gtk_widget_draw, block85_data_ref (_data85_), (GClosureNotify) block85_data_unref, 0);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	block85_data_unref (_data85_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data85_ = NULL;
#line 5129 "util-app.c"
}


GType boxes_cpu_arch_compatibility_get_type (void) {
	static volatile gsize boxes_cpu_arch_compatibility_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_cpu_arch_compatibility_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE, "BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE", "incompatible"}, {BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL, "BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL", "identical"}, {BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE, "BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE", "compatible"}, {BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE, "BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE", "compatible-diff-wordsize"}, {0, NULL, NULL}};
		GType boxes_cpu_arch_compatibility_type_id;
		boxes_cpu_arch_compatibility_type_id = g_enum_register_static ("BoxesCPUArchCompatibility", values);
		g_once_init_leave (&boxes_cpu_arch_compatibility_type_id__volatile, boxes_cpu_arch_compatibility_type_id);
	}
	return boxes_cpu_arch_compatibility_type_id__volatile;
}


BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2) {
	BoxesCPUArchCompatibility result = 0;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GQuark _tmp3_ = 0U;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label0 = 0;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label1 = 0;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label2 = 0;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label3 = 0;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label4 = 0;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch1 != NULL, 0);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch2 != NULL, 0);
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = arch2;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("i386")))) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5174 "util-app.c"
			default:
			{
				const gchar* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
				GQuark _tmp7_ = 0U;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label0 = 0;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label1 = 0;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label2 = 0;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label3 = 0;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label4 = 0;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp4_ = arch1;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp5_ = _tmp4_;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp7_ = (NULL == _tmp5_) ? 0 : g_quark_from_string (_tmp5_);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp7_ == ((0 != _tmp6_label0) ? _tmp6_label0 : (_tmp6_label0 = g_quark_from_static_string ("i386")))) {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5200 "util-app.c"
						default:
						{
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5207 "util-app.c"
						}
					}
				} else if (((_tmp7_ == ((0 != _tmp6_label1) ? _tmp6_label1 : (_tmp6_label1 = g_quark_from_static_string ("i486")))) || (_tmp7_ == ((0 != _tmp6_label2) ? _tmp6_label2 : (_tmp6_label2 = g_quark_from_static_string ("i586"))))) || (_tmp7_ == ((0 != _tmp6_label3) ? _tmp6_label3 : (_tmp6_label3 = g_quark_from_static_string ("i686"))))) {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5213 "util-app.c"
						default:
						{
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5220 "util-app.c"
						}
					}
				} else if (_tmp7_ == ((0 != _tmp6_label4) ? _tmp6_label4 : (_tmp6_label4 = g_quark_from_static_string ("x86_64")))) {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5226 "util-app.c"
						default:
						{
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5233 "util-app.c"
						}
					}
				} else {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5239 "util-app.c"
						default:
						{
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5246 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("i486")))) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5255 "util-app.c"
			default:
			{
				const gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
				GQuark _tmp11_ = 0U;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label0 = 0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label1 = 0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label2 = 0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label3 = 0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp8_ = arch1;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp9_ = _tmp8_;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp11_ = (NULL == _tmp9_) ? 0 : g_quark_from_string (_tmp9_);
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp11_ == ((0 != _tmp10_label0) ? _tmp10_label0 : (_tmp10_label0 = g_quark_from_static_string ("i486")))) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5279 "util-app.c"
						default:
						{
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5286 "util-app.c"
						}
					}
				} else if ((_tmp11_ == ((0 != _tmp10_label1) ? _tmp10_label1 : (_tmp10_label1 = g_quark_from_static_string ("i586")))) || (_tmp11_ == ((0 != _tmp10_label2) ? _tmp10_label2 : (_tmp10_label2 = g_quark_from_static_string ("i686"))))) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5292 "util-app.c"
						default:
						{
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5299 "util-app.c"
						}
					}
				} else if (_tmp11_ == ((0 != _tmp10_label3) ? _tmp10_label3 : (_tmp10_label3 = g_quark_from_static_string ("x86_64")))) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5305 "util-app.c"
						default:
						{
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5312 "util-app.c"
						}
					}
				} else {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5318 "util-app.c"
						default:
						{
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5325 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("i586")))) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5334 "util-app.c"
			default:
			{
				const gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				GQuark _tmp15_ = 0U;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label0 = 0;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label1 = 0;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label2 = 0;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp12_ = arch1;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp13_ = _tmp12_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp15_ = (NULL == _tmp13_) ? 0 : g_quark_from_string (_tmp13_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp15_ == ((0 != _tmp14_label0) ? _tmp14_label0 : (_tmp14_label0 = g_quark_from_static_string ("i586")))) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5356 "util-app.c"
						default:
						{
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5363 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label1) ? _tmp14_label1 : (_tmp14_label1 = g_quark_from_static_string ("i686")))) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5369 "util-app.c"
						default:
						{
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5376 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label2) ? _tmp14_label2 : (_tmp14_label2 = g_quark_from_static_string ("x86_64")))) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5382 "util-app.c"
						default:
						{
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5389 "util-app.c"
						}
					}
				} else {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5395 "util-app.c"
						default:
						{
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5402 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("i686")))) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5411 "util-app.c"
			default:
			{
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				GQuark _tmp19_ = 0U;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label0 = 0;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label1 = 0;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp16_ = arch1;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp17_ = _tmp16_;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = (NULL == _tmp17_) ? 0 : g_quark_from_string (_tmp17_);
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp19_ == ((0 != _tmp18_label0) ? _tmp18_label0 : (_tmp18_label0 = g_quark_from_static_string ("i686")))) {
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5431 "util-app.c"
						default:
						{
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5438 "util-app.c"
						}
					}
				} else if (_tmp19_ == ((0 != _tmp18_label1) ? _tmp18_label1 : (_tmp18_label1 = g_quark_from_static_string ("x86_64")))) {
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5444 "util-app.c"
						default:
						{
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5451 "util-app.c"
						}
					}
				} else {
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5457 "util-app.c"
						default:
						{
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5464 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string ("x86_64")))) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5473 "util-app.c"
			default:
			{
				const gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				GQuark _tmp23_ = 0U;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp22_label0 = 0;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp20_ = arch1;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp21_ = _tmp20_;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp23_ = (NULL == _tmp21_) ? 0 : g_quark_from_string (_tmp21_);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp23_ == ((0 != _tmp22_label0) ? _tmp22_label0 : (_tmp22_label0 = g_quark_from_static_string ("x86_64")))) {
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5491 "util-app.c"
						default:
						{
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5498 "util-app.c"
						}
					}
				} else {
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5504 "util-app.c"
						default:
						{
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5511 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5520 "util-app.c"
			default:
			{
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return result;
#line 5527 "util-app.c"
			}
		}
	} else {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5533 "util-app.c"
			default:
			{
				const gchar* _tmp24_ = NULL;
				const gchar* _tmp25_ = NULL;
				GQuark _tmp27_ = 0U;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp24_ = arch1;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp25_ = _tmp24_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp27_ = (NULL == _tmp25_) ? 0 : g_quark_from_string (_tmp25_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp27_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5549 "util-app.c"
						default:
						{
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5556 "util-app.c"
						}
					}
				} else {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5562 "util-app.c"
						default:
						{
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5569 "util-app.c"
						}
					}
				}
			}
		}
	}
}


gchar* boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self) {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return BOXES_FDO_TIMEDATE1_GET_INTERFACE (self)->get_timezone (self);
#line 5584 "util-app.c"
}


void boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, const gchar* value) {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (self != NULL);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	BOXES_FDO_TIMEDATE1_GET_INTERFACE (self)->set_timezone (self, value);
#line 5593 "util-app.c"
}


static void boxes_fdo_timedate1_base_init (BoxesFdotimedate1Iface * iface) {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static gboolean initialized = FALSE;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!initialized) {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		initialized = TRUE;
#line 5604 "util-app.c"
	}
}


GType boxes_fdo_timedate1_get_type (void) {
	static volatile gsize boxes_fdo_timedate1_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_fdo_timedate1_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesFdotimedate1Iface), (GBaseInitFunc) boxes_fdo_timedate1_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_fdo_timedate1_type_id;
		boxes_fdo_timedate1_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesFdotimedate1", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_fdo_timedate1_type_id, G_TYPE_OBJECT);
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) boxes_fdo_timedate1_proxy_get_type);
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.timedate1");
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_boxes_fdo_timedate1_dbus_interface_info));
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) boxes_fdo_timedate1_register_object);
		g_once_init_leave (&boxes_fdo_timedate1_type_id__volatile, boxes_fdo_timedate1_type_id);
	}
	return boxes_fdo_timedate1_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (BoxesFdotimedate1Proxy, boxes_fdo_timedate1_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BOXES_FDO_TYPE_TIMEDATE1, boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init) )
static void boxes_fdo_timedate1_proxy_class_init (BoxesFdotimedate1ProxyClass* klass) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_DBUS_PROXY_CLASS (klass)->g_signal = boxes_fdo_timedate1_proxy_g_signal;
#line 5630 "util-app.c"
}


static void boxes_fdo_timedate1_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
}


static void boxes_fdo_timedate1_proxy_init (BoxesFdotimedate1Proxy* self) {
}


static gchar* boxes_fdo_timedate1_dbus_proxy_get_timezone (BoxesFdotimedate1* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Timezone");
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 5649 "util-app.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.timedate1"));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Timezone"));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 5667 "util-app.c"
		}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 5673 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 5681 "util-app.c"
}


static void boxes_fdo_timedate1_dbus_proxy_set_timezone (BoxesFdotimedate1* self, const gchar* value) {
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.timedate1"));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Timezone"));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_close (&_arguments_builder);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_arguments = g_variant_builder_end (&_arguments_builder);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_reply) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5709 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_reply);
#line 5713 "util-app.c"
}


static void boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init (BoxesFdotimedate1Iface* iface) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	iface->get_timezone = boxes_fdo_timedate1_dbus_proxy_get_timezone;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	iface->set_timezone = boxes_fdo_timedate1_dbus_proxy_set_timezone;
#line 5722 "util-app.c"
}


static void boxes_fdo_timedate1_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (invocation);
#line 5733 "util-app.c"
}


static GVariant* _dbus_boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self) {
	gchar* result;
	GVariant* _reply;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_timedate1_get_timezone (self);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5748 "util-app.c"
}


static GVariant* boxes_fdo_timedate1_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (property_name, "Timezone") == 0) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_timedate1_get_timezone (object);
#line 5761 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return NULL;
#line 5765 "util-app.c"
}


static void _dbus_boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, GVariant* _value) {
	gchar* value = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	value = g_variant_dup_string (_value, NULL);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_fdo_timedate1_set_timezone (self, value);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (value);
#line 5777 "util-app.c"
}


static gboolean boxes_fdo_timedate1_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (property_name, "Timezone") == 0) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_dbus_boxes_fdo_timedate1_set_timezone (object, value);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return TRUE;
#line 5792 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5796 "util-app.c"
}


guint boxes_fdo_timedate1_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data = g_new (gpointer, 3);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[0] = g_object_ref (object);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[1] = g_object_ref (connection);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[2] = g_strdup (path);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_boxes_fdo_timedate1_dbus_interface_info), &_boxes_fdo_timedate1_dbus_interface_vtable, data, _boxes_fdo_timedate1_unregister_object, error);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!result) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return 0;
#line 5817 "util-app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5821 "util-app.c"
}


static void _boxes_fdo_timedate1_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[0]);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[1]);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (data[2]);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (data);
#line 5836 "util-app.c"
}


gchar* boxes_get_timezone (void) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
	{
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = boxes_get_timezone_from_systemd (&_inner_error_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp1_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5853 "util-app.c"
			goto __catch106_g_error;
		}
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = _tmp0_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = NULL;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp2_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp0_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 5866 "util-app.c"
	}
	goto __finally106;
	__catch106_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		e = _inner_error_;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = e;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp3_->message;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:489: Failed to get timezone from systemd: %s", _tmp4_);
#line 5884 "util-app.c"
		{
			gchar* _tmp5_ = NULL;
			gchar* _tmp6_ = NULL;
			gchar* _tmp7_ = NULL;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp6_ = boxes_get_timezone_from_linux (&_inner_error_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = _tmp6_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5895 "util-app.c"
				goto __catch107_g_error;
			}
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp7_ = _tmp5_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = NULL;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = _tmp7_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_tmp5_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 5910 "util-app.c"
		}
		goto __finally107;
		__catch107_g_error:
		{
			GError* e = NULL;
			GError* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			e = _inner_error_;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp8_ = e;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp9_ = _tmp8_->message;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_warning ("util-app.vala:493: Failed to find system timezone: %s", _tmp9_);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = NULL;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 5936 "util-app.c"
		}
		__finally107:
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5949 "util-app.c"
	}
	__finally106:
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_clear_error (&_inner_error_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return NULL;
#line 5958 "util-app.c"
}


gchar* boxes_get_timezone_from_systemd (GError** error) {
	gchar* result = NULL;
	BoxesFdotimedate1* timedate = NULL;
	BoxesFdotimedate1* _tmp0_ = NULL;
	BoxesFdotimedate1* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	BoxesFdotimedate1* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GError * _inner_error_ = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_initable_new (BOXES_FDO_TYPE_TIMEDATE1_PROXY, NULL, &_inner_error_, "g-flags", 0, "g-name", "org.freedesktop.timedate1", "g-bus-type", G_BUS_TYPE_SYSTEM, "g-object-path", "/org/freedesktop/timedate1", "g-interface-name", "org.freedesktop.timedate1", "g-interface-info", g_type_get_qdata (BOXES_FDO_TYPE_TIMEDATE1, g_quark_from_static_string ("vala-dbus-interface-info")), NULL);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	timedate = (BoxesFdotimedate1*) _tmp0_;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5985 "util-app.c"
	}
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = timedate;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = boxes_fdo_timedate1_get_timezone (_tmp1_);
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _tmp3_;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_ == NULL;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp4_);
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_) {
#line 6001 "util-app.c"
		GError* _tmp6_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Failed to get timezone from systemd");
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp6_;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (timedate);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6013 "util-app.c"
	}
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = timedate;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = boxes_fdo_timedate1_get_timezone (_tmp7_);
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp9_;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (timedate);
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6027 "util-app.c"
}


gchar* boxes_get_timezone_from_linux (GError** error) {
	gchar* result = NULL;
	GFile* file = NULL;
	GFile* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GFileInfo* info = NULL;
	GFileInfo* _tmp3_ = NULL;
	gchar* target = NULL;
	GFileInfo* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar** tokens = NULL;
	const gchar* _tmp9_ = NULL;
	gchar** _tmp10_ = NULL;
	gchar** _tmp11_ = NULL;
	gint tokens_length1 = 0;
	gint _tokens_size_ = 0;
	gboolean _tmp12_ = FALSE;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp17_ = NULL;
	gint _tmp17__length1 = 0;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	GError * _inner_error_ = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_file_new_for_path (BOXES_TZ_FILE);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	file = _tmp0_;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_file_query_exists (file, NULL);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_tmp1_) {
#line 6065 "util-app.c"
		GError* _tmp2_ = NULL;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file not found in expected location '%s'", BOXES_TZ_FILE);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp2_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6077 "util-app.c"
	}
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error_);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	info = _tmp3_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6091 "util-app.c"
	}
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = info;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = g_file_info_get_symlink_target (_tmp4_);
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	target = _tmp6_;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = target;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_ == NULL) {
#line 6105 "util-app.c"
		GError* _tmp8_ = NULL;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file '%s' is expected to be a symlink", BOXES_TZ_FILE);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp8_;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (target);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (info);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6121 "util-app.c"
	}
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = target;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = _tmp10_ = g_strsplit (_tmp9_, "zoneinfo/", 0);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens = _tmp11_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens_length1 = _vala_array_length (_tmp10_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tokens_size_ = tokens_length1;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = tokens;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13__length1 = tokens_length1;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp13_ == NULL) {
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = TRUE;
#line 6141 "util-app.c"
	} else {
		gchar** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = tokens;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14__length1 = tokens_length1;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = _tmp14__length1 < 2;
#line 6151 "util-app.c"
	}
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp12_) {
#line 6155 "util-app.c"
		const gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = target;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file in unexpected location '%s'", _tmp15_);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp16_;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (target);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (info);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6176 "util-app.c"
	}
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17_ = tokens;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17__length1 = tokens_length1;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp18_ = _tmp17_[1];
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp19_ = g_strdup (_tmp18_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp19_;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (target);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (info);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (file);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6198 "util-app.c"
}


gchar* boxes_uuid_generate (void) {
	gchar* result = NULL;
	guchar* udn = NULL;
	guchar* _tmp0_ = NULL;
	gint udn_length1 = 0;
	gint _udn_size_ = 0;
	guchar* id = NULL;
	guchar* _tmp1_ = NULL;
	gint id_length1 = 0;
	gint _id_size_ = 0;
	gchar* _tmp2_ = NULL;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_new0 (guchar, 50);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = _tmp0_;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn_length1 = 50;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_udn_size_ = udn_length1;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_new0 (guchar, 16);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = _tmp1_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id_length1 = 16;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_id_size_ = id_length1;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_generate (id);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_unparse (id, udn);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup ((const gchar*) udn);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp2_;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (g_free (id), NULL);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = (g_free (udn), NULL);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6243 "util-app.c"
}


GIcon* boxes_create_symbolic_emblem (const gchar* name) {
	GIcon* result = NULL;
	GIcon* pix = NULL;
	const gchar* _tmp0_ = NULL;
	GIcon* _tmp1_ = NULL;
	GIcon* _tmp2_ = NULL;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = name;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gd_create_symbolic_icon (_tmp0_, 128);
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pix = _tmp1_;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pix;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 6265 "util-app.c"
		const gchar* _tmp3_ = NULL;
		GThemedIcon* _tmp4_ = NULL;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = name;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = (GThemedIcon*) g_themed_icon_new (_tmp3_);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pix);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		pix = (GIcon*) _tmp4_;
#line 6276 "util-app.c"
	}
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = pix;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6282 "util-app.c"
}


GdkPixbuf* boxes_paint_empty_frame (gint width, gint height, gdouble radius, GdkRGBA* border_color, GdkRGBA* bg_color) {
	GdkPixbuf* result = NULL;
	cairo_surface_t* surface = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	cairo_surface_t* _tmp2_ = NULL;
	cairo_t* cr = NULL;
	cairo_surface_t* _tmp3_ = NULL;
	cairo_t* _tmp4_ = NULL;
	GdkRGBA* _tmp5_ = NULL;
	cairo_t* _tmp19_ = NULL;
	GdkRGBA _tmp20_ = {0};
	gdouble _tmp21_ = 0.0;
	GdkRGBA _tmp22_ = {0};
	gdouble _tmp23_ = 0.0;
	GdkRGBA _tmp24_ = {0};
	gdouble _tmp25_ = 0.0;
	GdkRGBA _tmp26_ = {0};
	gdouble _tmp27_ = 0.0;
	cairo_t* _tmp28_ = NULL;
	gint _tmp29_ = 0;
	gint _tmp30_ = 0;
	gdouble _tmp31_ = 0.0;
	cairo_surface_t* _tmp32_ = NULL;
	gint _tmp33_ = 0;
	gint _tmp34_ = 0;
	GdkPixbuf* _tmp35_ = NULL;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (border_color != NULL, NULL);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = width;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = height;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp0_, _tmp1_);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	surface = _tmp2_;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = surface;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = cairo_create (_tmp3_);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cr = _tmp4_;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = bg_color;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_ != NULL) {
#line 6333 "util-app.c"
		cairo_t* _tmp6_ = NULL;
		GdkRGBA* _tmp7_ = NULL;
		gdouble _tmp8_ = 0.0;
		GdkRGBA* _tmp9_ = NULL;
		gdouble _tmp10_ = 0.0;
		GdkRGBA* _tmp11_ = NULL;
		gdouble _tmp12_ = 0.0;
		GdkRGBA* _tmp13_ = NULL;
		gdouble _tmp14_ = 0.0;
		cairo_t* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		gdouble _tmp18_ = 0.0;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = cr;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = bg_color;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = (*_tmp7_).red;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = bg_color;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = (*_tmp9_).green;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = bg_color;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = (*_tmp11_).blue;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = bg_color;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = (*_tmp13_).alpha;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		cairo_set_source_rgba (_tmp6_, _tmp8_, _tmp10_, _tmp12_, _tmp14_);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = cr;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = width;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17_ = height;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp18_ = radius;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_paint_frame_background (_tmp15_, _tmp16_, _tmp17_, _tmp18_);
#line 6377 "util-app.c"
	}
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp19_ = cr;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp20_ = *border_color;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp21_ = _tmp20_.red;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp22_ = *border_color;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp23_ = _tmp22_.green;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp24_ = *border_color;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp25_ = _tmp24_.blue;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp26_ = *border_color;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp27_ = _tmp26_.alpha;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_set_source_rgba (_tmp19_, _tmp21_, _tmp23_, _tmp25_, _tmp27_);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp28_ = cr;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp29_ = width;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp30_ = height;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp31_ = radius;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_paint_frame_border (_tmp28_, _tmp29_, _tmp30_, _tmp31_);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp32_ = surface;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp33_ = width;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp34_ = height;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp35_ = gdk_pixbuf_get_from_surface (_tmp32_, 0, 0, _tmp33_, _tmp34_);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp35_;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_cairo_destroy0 (cr);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_cairo_surface_destroy0 (surface);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6425 "util-app.c"
}


void boxes_paint_frame_background (cairo_t* cr, gint width, gint height, gdouble radius) {
	cairo_t* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gdouble _tmp3_ = 0.0;
	cairo_t* _tmp4_ = NULL;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (cr != NULL);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = cr;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = width;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = height;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = radius;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_rounded_rectangle (_tmp0_, 0.5, 0.5, (gdouble) (_tmp1_ - 1), (gdouble) (_tmp2_ - 1), _tmp3_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = cr;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_fill (_tmp4_);
#line 6451 "util-app.c"
}


void boxes_paint_frame_border (cairo_t* cr, gint width, gint height, gdouble radius) {
	cairo_t* _tmp0_ = NULL;
	cairo_t* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	gdouble _tmp4_ = 0.0;
	cairo_t* _tmp5_ = NULL;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (cr != NULL);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = cr;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_set_line_width (_tmp0_, 1.0);
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = cr;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = width;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = height;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = radius;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_rounded_rectangle (_tmp1_, 0.5, 0.5, (gdouble) (_tmp2_ - 1), (gdouble) (_tmp3_ - 1), _tmp4_);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = cr;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_stroke (_tmp5_);
#line 6482 "util-app.c"
}


void boxes_rounded_rectangle (cairo_t* cr, gdouble x, gdouble y, gdouble width, gdouble height, gdouble radius) {
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const gdouble ARC_0 = (gdouble) 0;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const gdouble ARC_1 = G_PI * 0.5;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const gdouble ARC_2 = G_PI;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const gdouble ARC_3 = G_PI * 1.5;
#line 6495 "util-app.c"
	cairo_t* _tmp0_ = NULL;
	cairo_t* _tmp1_ = NULL;
	gdouble _tmp2_ = 0.0;
	gdouble _tmp3_ = 0.0;
	gdouble _tmp4_ = 0.0;
	gdouble _tmp5_ = 0.0;
	gdouble _tmp6_ = 0.0;
	gdouble _tmp7_ = 0.0;
	cairo_t* _tmp8_ = NULL;
	gdouble _tmp9_ = 0.0;
	gdouble _tmp10_ = 0.0;
	gdouble _tmp11_ = 0.0;
	gdouble _tmp12_ = 0.0;
	gdouble _tmp13_ = 0.0;
	gdouble _tmp14_ = 0.0;
	gdouble _tmp15_ = 0.0;
	cairo_t* _tmp16_ = NULL;
	gdouble _tmp17_ = 0.0;
	gdouble _tmp18_ = 0.0;
	gdouble _tmp19_ = 0.0;
	gdouble _tmp20_ = 0.0;
	gdouble _tmp21_ = 0.0;
	gdouble _tmp22_ = 0.0;
	cairo_t* _tmp23_ = NULL;
	gdouble _tmp24_ = 0.0;
	gdouble _tmp25_ = 0.0;
	gdouble _tmp26_ = 0.0;
	gdouble _tmp27_ = 0.0;
	gdouble _tmp28_ = 0.0;
	cairo_t* _tmp29_ = NULL;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (cr != NULL);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = cr;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_new_sub_path (_tmp0_);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = cr;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = x;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = width;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = radius;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = y;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = radius;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = radius;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_arc (_tmp1_, (_tmp2_ + _tmp3_) - _tmp4_, _tmp5_ + _tmp6_, _tmp7_, ARC_3, ARC_0);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = cr;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = x;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = width;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = radius;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = y;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = height;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = radius;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = radius;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_arc (_tmp8_, (_tmp9_ + _tmp10_) - _tmp11_, (_tmp12_ + _tmp13_) - _tmp14_, _tmp15_, ARC_0, ARC_1);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp16_ = cr;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17_ = x;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp18_ = radius;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp19_ = y;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp20_ = height;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp21_ = radius;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp22_ = radius;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_arc (_tmp16_, _tmp17_ + _tmp18_, (_tmp19_ + _tmp20_) - _tmp21_, _tmp22_, ARC_1, ARC_2);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp23_ = cr;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp24_ = x;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp25_ = radius;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp26_ = y;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp27_ = radius;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp28_ = radius;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_arc (_tmp23_, _tmp24_ + _tmp25_, _tmp26_ + _tmp27_, _tmp28_, ARC_2, ARC_3);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp29_ = cr;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	cairo_close_path (_tmp29_);
#line 6600 "util-app.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 6607 "util-app.c"
		int i;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 6615 "util-app.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 6627 "util-app.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 6640 "util-app.c"
		}
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 6645 "util-app.c"
}



