/* unattended-installer.c generated by valac 0.30.0.37-86f3c, the Vala compiler
 * generated from unattended-installer.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <osinfo/osinfo.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>
#include <glib/gstdio.h>
#include <float.h>
#include <math.h>


#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;

#define BOXES_TYPE_UNATTENDED_FILE (boxes_unattended_file_get_type ())
#define BOXES_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFile))
#define BOXES_IS_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_FILE))
#define BOXES_UNATTENDED_FILE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFileIface))

typedef struct _BoxesUnattendedFile BoxesUnattendedFile;
typedef struct _BoxesUnattendedFileIface BoxesUnattendedFileIface;

#define BOXES_TYPE_UNATTENDED_AVATAR_FILE (boxes_unattended_avatar_file_get_type ())
#define BOXES_UNATTENDED_AVATAR_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFile))
#define BOXES_UNATTENDED_AVATAR_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFileClass))
#define BOXES_IS_UNATTENDED_AVATAR_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE))
#define BOXES_IS_UNATTENDED_AVATAR_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_AVATAR_FILE))
#define BOXES_UNATTENDED_AVATAR_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFileClass))

typedef struct _BoxesUnattendedAvatarFile BoxesUnattendedAvatarFile;
typedef struct _BoxesUnattendedAvatarFileClass BoxesUnattendedAvatarFileClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_UNATTENDED_SCRIPT_FILE (boxes_unattended_script_file_get_type ())
#define BOXES_UNATTENDED_SCRIPT_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFile))
#define BOXES_UNATTENDED_SCRIPT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFileClass))
#define BOXES_IS_UNATTENDED_SCRIPT_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE))
#define BOXES_IS_UNATTENDED_SCRIPT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SCRIPT_FILE))
#define BOXES_UNATTENDED_SCRIPT_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFileClass))

typedef struct _BoxesUnattendedScriptFile BoxesUnattendedScriptFile;
typedef struct _BoxesUnattendedScriptFileClass BoxesUnattendedScriptFileClass;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_ISO_EXTRACTOR (boxes_iso_extractor_get_type ())
#define BOXES_ISO_EXTRACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractor))
#define BOXES_ISO_EXTRACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractorClass))
#define BOXES_IS_ISO_EXTRACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ISO_EXTRACTOR))
#define BOXES_IS_ISO_EXTRACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ISO_EXTRACTOR))
#define BOXES_ISO_EXTRACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ISO_EXTRACTOR, BoxesISOExtractorClass))

typedef struct _BoxesISOExtractor BoxesISOExtractor;
typedef struct _BoxesISOExtractorClass BoxesISOExtractorClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
typedef struct _BoxesUnattendedInstallerPrepareForInstallationData BoxesUnattendedInstallerPrepareForInstallationData;
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _BoxesUnattendedInstallerPrepareData BoxesUnattendedInstallerPrepareData;
typedef struct _BoxesUnattendedInstallerCreateDiskImageData BoxesUnattendedInstallerCreateDiskImageData;
typedef struct _BoxesUnattendedInstallerFetchUserAvatarData BoxesUnattendedInstallerFetchUserAvatarData;
typedef struct _BoxesUnattendedInstallerExtractBootFilesData BoxesUnattendedInstallerExtractBootFilesData;
typedef struct _BoxesUnattendedInstallerSetupDriversData BoxesUnattendedInstallerSetupDriversData;
typedef struct _BoxesUnattendedInstallerSetupDriversFromListData BoxesUnattendedInstallerSetupDriversFromListData;

#define BOXES_TYPE_DOWNLOADER (boxes_downloader_get_type ())
#define BOXES_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloader))
#define BOXES_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))
#define BOXES_IS_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOADER))
#define BOXES_IS_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOADER))
#define BOXES_DOWNLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))

typedef struct _BoxesDownloader BoxesDownloader;
typedef struct _BoxesDownloaderClass BoxesDownloaderClass;

#define BOXES_TYPE_UNATTENDED_RAW_FILE (boxes_unattended_raw_file_get_type ())
#define BOXES_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFile))
#define BOXES_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))
#define BOXES_IS_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_IS_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_UNATTENDED_RAW_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))

typedef struct _BoxesUnattendedRawFile BoxesUnattendedRawFile;
typedef struct _BoxesUnattendedRawFileClass BoxesUnattendedRawFileClass;
typedef struct _BoxesUnattendedInstallerSetupDriverData BoxesUnattendedInstallerSetupDriverData;
typedef struct _Block83Data Block83Data;

#define BOXES_TYPE_CPU_ARCH_COMPATIBILITY (boxes_cpu_arch_compatibility_get_type ())
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	BoxesUnattendedSetupBox* setup_box;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _BoxesUnattendedFileIface {
	GTypeInterface parent_iface;
	void (*get_source_file) (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GFile* (*get_source_file_finish) (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
	const gchar* (*get_src_path) (BoxesUnattendedFile* self);
	void (*set_src_path) (BoxesUnattendedFile* self, const gchar* value);
	const gchar* (*get_dest_name) (BoxesUnattendedFile* self);
	void (*set_dest_name) (BoxesUnattendedFile* self, const gchar* value);
	gchar* (*get_disk_file) (BoxesUnattendedFile* self);
	BoxesUnattendedInstaller* (*get_installer) (BoxesUnattendedFile* self);
	void (*set_installer) (BoxesUnattendedFile* self, BoxesUnattendedInstaller* value);
};

struct _BoxesUnattendedInstallerPrivate {
	GList* unattended_files;
	GList* secondary_unattended_files;
	BoxesUnattendedAvatarFile* avatar_file;
	gchar* timezone;
	gchar* lang;
	gchar* hostname;
	gchar* kbd;
	gboolean driver_signing;
	OsinfoDeviceList* additional_devices;
};

struct _BoxesUnattendedInstallerPrepareForInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	gchar* vm_name;
	GCancellable* cancellable;
	BoxesUnattendedSetupBox* _tmp0_;
	BoxesUnattendedSetupBox* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	const gchar* _tmp4_;
	GCancellable* _tmp5_;
	gboolean _tmp6_;
	OsinfoMedia* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gboolean _tmp11_;
	OsinfoMedia* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	BoxesISOExtractor* extractor;
	const gchar* _tmp16_;
	BoxesISOExtractor* _tmp17_;
	BoxesISOExtractor* _tmp18_;
	GCancellable* _tmp19_;
	GList* _tmp20_;
	GList* unattended_file_collection;
	GList* unattended_file_it;
	BoxesUnattendedFile* _tmp21_;
	BoxesUnattendedFile* unattended_file;
	BoxesUnattendedFile* _tmp22_;
	GCancellable* _tmp23_;
	GFile* _tmp24_;
	gchar* secondary_disk_path;
	GFile* _tmp25_;
	gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar** argv;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	const gchar* _tmp33_;
	gchar* _tmp34_;
	gchar** _tmp35_;
	gint argv_length1;
	gint _argv_size_;
	GList* _tmp36_;
	GList* _vala1_unattended_file_collection;
	GList* _vala1_unattended_file_it;
	BoxesUnattendedFile* _tmp37_;
	BoxesUnattendedFile* _vala1_unattended_file;
	gchar* dest_path;
	BoxesUnattendedFile* _tmp38_;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	gchar* _tmp41_;
	gchar* src_path;
	BoxesUnattendedFile* _tmp42_;
	const gchar* _tmp43_;
	const gchar* _tmp44_;
	gchar* _tmp45_;
	gchar** _tmp46_;
	gint _tmp46__length1;
	const gchar* _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	const gchar* _tmp50_;
	gchar* _tmp51_;
	gchar** _tmp52_;
	gint _tmp52__length1;
	GCancellable* _tmp53_;
	const gchar* _tmp54_;
	GError* _error_;
	BoxesUnattendedSetupBox* _tmp55_;
	gchar* msg;
	const gchar* _tmp56_;
	gchar* _tmp57_;
	BoxesApp* _tmp58_;
	BoxesAppWindow* _tmp59_;
	BoxesAppWindow* _tmp60_;
	BoxesNotificationbar* _tmp61_;
	BoxesNotificationbar* _tmp62_;
	const gchar* _tmp63_;
	GdNotification* _tmp64_;
	GdNotification* _tmp65_;
	GError* _tmp66_;
	const gchar* _tmp67_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerPrepareData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	gboolean result;
	BoxesActivityProgress* _tmp0_;
	GCancellable* _tmp1_;
	gboolean _tmp2_;
};

struct _BoxesUnattendedInstallerCreateDiskImageData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	GCancellable* cancellable;
	gchar* template_path;
	gchar* _tmp0_;
	GFile* template_file;
	GFile* _tmp1_;
	GFile* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GFile* _tmp5_;
	GCancellable* _tmp6_;
	GFile* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerFetchUserAvatarData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	BoxesFdoAccounts* _tmp0_;
	gchar* username;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* avatar_path;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* path;
	BoxesFdoAccounts* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	BoxesFdoAccountsUser* user;
	const gchar* _tmp8_;
	BoxesFdoAccountsUser* _tmp9_;
	BoxesFdoAccountsUser* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GError* _error_;
	const gchar* _tmp13_;
	GError* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	gboolean _tmp17_;
	BoxesUnattendedSetupBox* _tmp18_;
	const gchar* _tmp19_;
	OsinfoAvatarFormat* avatar_format;
	OsinfoInstallScriptList* _tmp20_;
	GList* _tmp21_;
	GList* s_collection;
	GList* s_it;
	OsinfoEntity* s;
	OsinfoInstallScript* script;
	OsinfoEntity* _tmp22_;
	OsinfoInstallScript* _tmp23_;
	OsinfoInstallScript* _tmp24_;
	OsinfoAvatarFormat* _tmp25_;
	OsinfoAvatarFormat* _tmp26_;
	OsinfoAvatarFormat* _tmp27_;
	OsinfoAvatarFormat* _tmp28_;
	BoxesUnattendedAvatarFile* _tmp29_;
	const gchar* _tmp30_;
	OsinfoAvatarFormat* _tmp31_;
	BoxesUnattendedAvatarFile* _tmp32_;
	BoxesUnattendedAvatarFile* _tmp33_;
	BoxesUnattendedAvatarFile* _tmp34_;
	GError* _vala1__error_;
	const gchar* _tmp35_;
	GError* _tmp36_;
	const gchar* _tmp37_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerExtractBootFilesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	BoxesISOExtractor* extractor;
	GCancellable* cancellable;
	BoxesISOExtractor* _tmp0_;
	OsinfoMedia* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GFile* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	GCancellable* _tmp8_;
	BoxesISOExtractor* _tmp9_;
	OsinfoMedia* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	GFile* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GCancellable* _tmp17_;
	GError * _inner_error_;
};

typedef void (*BoxesUnattendedInstallerAddUnattendedFileFunc) (BoxesUnattendedFile* file, void* user_data);
struct _BoxesUnattendedInstallerSetupDriversData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	gboolean result;
	BoxesActivityProgress* _tmp0_;
	const gchar* _tmp1_;
	GList* scripts;
	GList* _tmp2_;
	GList* drivers;
	GList* _tmp3_;
	GList* _tmp4_;
	gboolean _tmp5_;
	GList* _tmp6_;
	guint _tmp7_;
	GList* _tmp8_;
	guint _tmp9_;
	BoxesActivityProgress* drivers_progress;
	BoxesActivityProgress* _tmp10_;
	BoxesActivityProgress* _tmp11_;
	GList* _tmp12_;
	BoxesActivityProgress* _tmp13_;
	GCancellable* _tmp14_;
	gboolean _tmp15_;
	BoxesActivityProgress* _tmp16_;
	GList* _tmp17_;
	GList* _tmp18_;
	GList* _tmp19_;
	gboolean _tmp20_;
	GList* _tmp21_;
	guint _tmp22_;
	GList* _tmp23_;
	guint _tmp24_;
	BoxesActivityProgress* _vala1_drivers_progress;
	BoxesActivityProgress* _tmp25_;
	BoxesActivityProgress* _tmp26_;
	GList* _tmp27_;
	BoxesActivityProgress* _tmp28_;
	GCancellable* _tmp29_;
	gboolean _tmp30_;
	BoxesActivityProgress* _tmp31_;
};

struct _BoxesUnattendedInstallerSetupDriversFromListData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	GList* drivers;
	BoxesActivityProgress* progress;
	BoxesUnattendedInstallerAddUnattendedFileFunc add_func;
	gpointer add_func_target;
	GCancellable* cancellable;
	gboolean result;
	gdouble driver_progress_scale;
	GList* _tmp0_;
	guint _tmp1_;
	GList* _tmp2_;
	GList* driver_collection;
	GList* driver_it;
	OsinfoDeviceDriver* _tmp3_;
	OsinfoDeviceDriver* driver;
	BoxesActivityProgress* driver_progress;
	BoxesActivityProgress* _tmp4_;
	gdouble _tmp5_;
	BoxesActivityProgress* _tmp6_;
	OsinfoDeviceDriver* _tmp7_;
	BoxesActivityProgress* _tmp8_;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp9_;
	void* _tmp9__target;
	GCancellable* _tmp10_;
	OsinfoDeviceList* _tmp11_;
	OsinfoDeviceDriver* _tmp12_;
	OsinfoDeviceList* _tmp13_;
	GError* e;
	BoxesActivityProgress* _tmp14_;
	GError* _vala1_e;
	OsinfoDeviceDriver* _tmp15_;
	const gchar* _tmp16_;
	GError* _tmp17_;
	const gchar* _tmp18_;
	BoxesActivityProgress* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstallerSetupDriverData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedInstaller* self;
	OsinfoDeviceDriver* driver;
	BoxesActivityProgress* progress;
	BoxesUnattendedInstallerAddUnattendedFileFunc add_func;
	gpointer add_func_target;
	GCancellable* cancellable;
	BoxesDownloader* downloader;
	BoxesDownloader* _tmp0_;
	GList* driver_files;
	gchar* location;
	OsinfoDeviceDriver* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* location_checksum;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	GList* files;
	OsinfoDeviceDriver* _tmp6_;
	GList* _tmp7_;
	gdouble file_progress_scale;
	GList* _tmp8_;
	guint _tmp9_;
	GList* _tmp10_;
	GList* filename_collection;
	GList* filename_it;
	const gchar* filename;
	gchar* file_uri;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GFile* file;
	const gchar* _tmp17_;
	GFile* _tmp18_;
	gchar* driver_file_name;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	GFile* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* cached_path;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* system_cached_path;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	gchar** cached_paths;
	const gchar* _tmp31_;
	gchar* _tmp32_;
	gchar** _tmp33_;
	gint cached_paths_length1;
	gint _cached_paths_size_;
	const gchar* _tmp34_;
	gchar** _tmp35_;
	gint _tmp35__length1;
	const gchar* _tmp36_;
	gchar* _tmp37_;
	BoxesActivityProgress* file_progress;
	BoxesActivityProgress* _tmp38_;
	gdouble _tmp39_;
	BoxesActivityProgress* _tmp40_;
	GFile* _tmp41_;
	BoxesDownloader* _tmp42_;
	GFile* _tmp43_;
	gchar** _tmp44_;
	gint _tmp44__length1;
	BoxesActivityProgress* _tmp45_;
	GCancellable* _tmp46_;
	GFile* _tmp47_;
	GFile* _tmp48_;
	BoxesActivityProgress* _tmp49_;
	GFile* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	const gchar* _tmp53_;
	BoxesUnattendedRawFile* _tmp54_;
	GList* _tmp55_;
	GList* driver_file_collection;
	GList* driver_file_it;
	BoxesUnattendedFile* _tmp56_;
	BoxesUnattendedFile* driver_file;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp57_;
	void* _tmp57__target;
	BoxesUnattendedFile* _tmp58_;
	GError * _inner_error_;
};

typedef gboolean (*BoxesUnattendedInstallerDriverInstallableFunc) (OsinfoDeviceDriver* driver, void* user_data);
typedef OsinfoDeviceDriverSigningReq (*BoxesUnattendedInstallerScriptDriverSigningReqFunc) (OsinfoInstallScript* script, void* user_data);
struct _Block83Data {
	int _ref_count_;
	BoxesUnattendedInstaller* self;
	gboolean signing_required;
	gboolean driver_signing_mutable;
	BoxesUnattendedInstallerDriverInstallableFunc installable_func;
	gpointer installable_func_target;
};

typedef gboolean (*BoxesUnattendedInstallerDriverTestFunction) (OsinfoDeviceDriver* driver, void* user_data);
typedef enum  {
	BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE = -1,
	BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL = 0,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE = 1,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE = 2
} BoxesCPUArchCompatibility;

typedef gboolean (*BoxesUnattendedInstallerScriptTestFunction) (OsinfoInstallScript* script, void* user_data);

static gpointer boxes_unattended_installer_parent_class = NULL;
static BoxesFdoAccounts* boxes_unattended_installer_accounts;
static BoxesFdoAccounts* boxes_unattended_installer_accounts = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_installer_media_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
GType boxes_unattended_file_get_type (void) G_GNUC_CONST;
GType boxes_unattended_avatar_file_get_type (void) G_GNUC_CONST;
#define BOXES_UNATTENDED_INSTALLER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerPrivate))
enum  {
	BOXES_UNATTENDED_INSTALLER_DUMMY_PROPERTY,
	BOXES_UNATTENDED_INSTALLER_NEED_USER_INPUT_FOR_VM_CREATION,
	BOXES_UNATTENDED_INSTALLER_READY_TO_CREATE,
	BOXES_UNATTENDED_INSTALLER_SUPPORTED_DEVICES
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static gchar* boxes_unattended_installer_escape_mkisofs_path (const gchar* path);
BoxesUnattendedInstaller* boxes_unattended_installer_new_from_media (BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
BoxesInstallerMedia* boxes_installer_media_new (void);
BoxesInstallerMedia* boxes_installer_media_construct (GType object_type);
GType boxes_unattended_script_file_get_type (void) G_GNUC_CONST;
BoxesUnattendedScriptFile* boxes_unattended_script_file_new (BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name, GError** error);
BoxesUnattendedScriptFile* boxes_unattended_script_file_construct (GType object_type, BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name, GError** error);
static void boxes_unattended_installer_add_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file);
gchar* boxes_get_timezone (void);
static gchar* boxes_unattended_installer_get_preferred_language (BoxesUnattendedInstaller* self);
static gchar* boxes_unattended_installer_get_product_key_format (BoxesUnattendedInstaller* self);
BoxesUnattendedSetupBox* boxes_unattended_setup_box_new (BoxesInstallerMedia* media, const gchar* product_key_format, gboolean needs_internet);
BoxesUnattendedSetupBox* boxes_unattended_setup_box_construct (GType object_type, BoxesInstallerMedia* media, const gchar* product_key_format, gboolean needs_internet);
static void __lambda133_ (BoxesUnattendedInstaller* self);
static void ___lambda133__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda134_ (BoxesUnattendedInstaller* self);
static void ___lambda134__boxes_unattended_setup_box_user_wants_to_create (BoxesUnattendedSetupBox* _sender, gpointer self);
static void boxes_unattended_installer_fetch_user_avatar (BoxesUnattendedInstaller* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_fetch_user_avatar_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_);
static void boxes_unattended_installer_real_prepare_to_continue_installation (BoxesInstallerMedia* base, const gchar* vm_name);
gchar* boxes_unattended_installer_get_user_unattended (BoxesUnattendedInstaller* self, const gchar* suffix);
static void boxes_unattended_installer_real_prepare_for_installation_data_free (gpointer _data);
static void boxes_unattended_installer_real_prepare_for_installation (BoxesInstallerMedia* base, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_installer_real_prepare_for_installation_co (BoxesUnattendedInstallerPrepareForInstallationData* _data_);
void boxes_unattended_setup_box_save_settings (BoxesUnattendedSetupBox* self);
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
static void boxes_unattended_installer_create_disk_image (BoxesUnattendedInstaller* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_create_disk_image_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_prepare_for_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_iso_extractor_get_type (void) G_GNUC_CONST;
BoxesISOExtractor* boxes_iso_extractor_new (const gchar* iso_path);
BoxesISOExtractor* boxes_iso_extractor_construct (GType object_type, const gchar* iso_path);
static void boxes_unattended_installer_extract_boot_files (BoxesUnattendedInstaller* self, BoxesISOExtractor* extractor, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_extract_boot_files_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error);
void boxes_unattended_file_copy (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_unattended_file_copy_finish (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
const gchar* boxes_unattended_file_get_dest_name (BoxesUnattendedFile* self);
const gchar* boxes_unattended_file_get_src_path (BoxesUnattendedFile* self);
static void _vala_array_add9 (gchar*** array, int* length, int* size, gchar* value);
void boxes_installer_media_clean_up (BoxesInstallerMedia* self);
void boxes_unattended_setup_box_set_express_install (BoxesUnattendedSetupBox* self, gboolean value);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void boxes_unattended_installer_real_setup_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain);
void boxes_installer_media_setup_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
static GVirConfigDomainDisk* boxes_unattended_installer_get_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format);
static GVirConfigDomainDisk* boxes_unattended_installer_get_secondary_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format);
void boxes_unattended_installer_configure_install_script (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
gchar* boxes_unattended_setup_box_get_password (BoxesUnattendedSetupBox* self);
const gchar* boxes_unattended_setup_box_get_username (BoxesUnattendedSetupBox* self);
gchar* boxes_unattended_setup_box_get_product_key (BoxesUnattendedSetupBox* self);
gboolean boxes_installer_media_get_supports_virtio_disk (BoxesInstallerMedia* self);
static gchar* boxes_unattended_installer_device_name_to_path (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format, const gchar* name);
static void boxes_unattended_installer_real_setup_post_install_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain);
static void boxes_unattended_installer_remove_disk_from_domain_config (BoxesUnattendedInstaller* self, GVirConfigDomain* domain, const gchar* disk_path);
void boxes_installer_media_setup_post_install_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
static void boxes_unattended_installer_real_populate_setup_box (BoxesInstallerMedia* base, GtkBox* setup_box);
static GList* boxes_unattended_installer_real_get_vm_properties (BoxesInstallerMedia* base);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
gchar* boxes_unattended_setup_box_get_hidden_password (BoxesUnattendedSetupBox* self);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
static void boxes_unattended_installer_real_set_direct_boot_params (BoxesInstallerMedia* base, GVirConfigDomainOs* domain_os);
static void boxes_unattended_installer_real_clean_up (BoxesInstallerMedia* base);
void boxes_unattended_setup_box_clean_up (BoxesUnattendedSetupBox* self);
static void boxes_unattended_installer_real_clean_up_preparation_cache (BoxesInstallerMedia* base);
void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self);
static void boxes_unattended_installer_real_prepare_data_free (gpointer _data);
static void boxes_unattended_installer_real_prepare (BoxesInstallerMedia* base, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_installer_real_prepare_co (BoxesUnattendedInstallerPrepareData* _data_);
static void boxes_unattended_installer_setup_drivers (BoxesUnattendedInstaller* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_installer_setup_drivers_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_);
static void boxes_unattended_installer_prepare_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static OsinfoInstallScriptInjectionMethod boxes_unattended_installer_get_injection_method (BoxesUnattendedInstaller* self);
static void boxes_unattended_installer_add_secondary_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file);
static void boxes_unattended_installer_create_disk_image_data_free (gpointer _data);
static gboolean boxes_unattended_installer_create_disk_image_co (BoxesUnattendedInstallerCreateDiskImageData* _data_);
static void boxes_unattended_installer_create_disk_image_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_unattended_installer_fetch_user_avatar_data_free (gpointer _data);
static gboolean boxes_unattended_installer_fetch_user_avatar_co (BoxesUnattendedInstallerFetchUserAvatarData* _data_);
static void boxes_unattended_installer_fetch_user_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_unattended_setup_box_set_avatar_path (BoxesUnattendedSetupBox* self, const gchar* value);
BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error);
BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error);
static void boxes_unattended_installer_extract_boot_files_data_free (gpointer _data);
static gboolean boxes_unattended_installer_extract_boot_files_co (BoxesUnattendedInstallerExtractBootFilesData* _data_);
void boxes_iso_extractor_extract (BoxesISOExtractor* self, const gchar* path, const gchar* output_path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_iso_extractor_extract_finish (BoxesISOExtractor* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_extract_boot_files_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_unattended_installer_setup_drivers_data_free (gpointer _data);
static gboolean boxes_unattended_installer_setup_drivers_co (BoxesUnattendedInstallerSetupDriversData* _data_);
static GList* boxes_unattended_installer_get_pre_installer_scripts (BoxesUnattendedInstaller* self);
static GList* boxes_unattended_installer_get_pre_installable_drivers (BoxesUnattendedInstaller* self, GList* preinst_scripts);
static void boxes_unattended_installer_setup_drivers_from_list (BoxesUnattendedInstaller* self, GList* drivers, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_installer_setup_drivers_from_list_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_);
static void _boxes_unattended_installer_add_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self);
static void boxes_unattended_installer_setup_drivers_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static GList* boxes_unattended_installer_get_post_installer_scripts (BoxesUnattendedInstaller* self);
static GList* boxes_unattended_installer_get_post_installable_drivers (BoxesUnattendedInstaller* self, GList* postinst_scripts);
static void _boxes_unattended_installer_add_secondary_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self);
static void boxes_unattended_installer_setup_drivers_from_list_data_free (gpointer _data);
static gboolean boxes_unattended_installer_setup_drivers_from_list_co (BoxesUnattendedInstallerSetupDriversFromListData* _data_);
static void boxes_unattended_installer_setup_driver (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_unattended_installer_setup_driver_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_setup_drivers_from_list_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_unattended_installer_setup_driver_data_free (gpointer _data);
static gboolean boxes_unattended_installer_setup_driver_co (BoxesUnattendedInstallerSetupDriverData* _data_);
GType boxes_downloader_get_type (void) G_GNUC_CONST;
BoxesDownloader* boxes_downloader_get_instance (void);
static void _vala_array_add10 (gchar*** array, int* length, int* size, gchar* value);
void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_installer_setup_driver_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesUnattendedRawFile* boxes_unattended_raw_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
BoxesUnattendedRawFile* boxes_unattended_raw_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
GType boxes_unattended_raw_file_get_type (void) G_GNUC_CONST;
static GList* boxes_unattended_installer_get_installable_drivers (BoxesUnattendedInstaller* self, GList* scripts, BoxesUnattendedInstallerDriverInstallableFunc installable_func, void* installable_func_target, BoxesUnattendedInstallerScriptDriverSigningReqFunc signing_req_func, void* signing_req_func_target);
static gboolean __lambda137_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver);
static gboolean ___lambda137__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self);
static OsinfoDeviceDriverSigningReq __lambda138_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static OsinfoDeviceDriverSigningReq ___lambda138__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self);
static gboolean __lambda147_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver);
static gboolean ___lambda147__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self);
static OsinfoDeviceDriverSigningReq __lambda148_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static OsinfoDeviceDriverSigningReq ___lambda148__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self);
static Block83Data* block83_data_ref (Block83Data* _data83_);
static void block83_data_unref (void * _userdata_);
static GList* boxes_unattended_installer_get_drivers (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerDriverTestFunction test_func, void* test_func_target);
static gboolean __lambda136_ (Block83Data* _data83_, OsinfoDeviceDriver* driver);
static gboolean ___lambda136__boxes_unattended_installer_driver_test_function (OsinfoDeviceDriver* driver, gpointer self);
static void _g_free0_ (gpointer var);
GType boxes_cpu_arch_compatibility_get_type (void) G_GNUC_CONST;
BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2);
static GList* boxes_unattended_installer_get_scripts (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerScriptTestFunction test_func, void* test_func_target);
static gboolean __lambda135_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static gboolean ___lambda135__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self);
static gboolean __lambda146_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
static gboolean ___lambda146__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self);
static gchar** _vala_array_dup4 (gchar** self, int length);
static void _vala_array_add11 (gchar*** array, int* length, int* size, gchar* value);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
BoxesUnattendedInstaller* boxes_unattended_installer_new (void);
BoxesUnattendedInstaller* boxes_unattended_installer_construct (GType object_type);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
gboolean boxes_unattended_setup_box_get_ready_to_create (BoxesUnattendedSetupBox* self);
OsinfoDeviceList* boxes_installer_media_get_supported_devices (BoxesInstallerMedia* self);
OsinfoInstallScriptInjectionMethod boxes_unattended_script_file_get_injection_method (BoxesUnattendedScriptFile* self);
static GObject * boxes_unattended_installer_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_unattended_installer_finalize (GObject* obj);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self);
static void _vala_boxes_unattended_installer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void _g_object_unref0_ (gpointer var) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 869 "unattended-installer.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_free (self);
#line 878 "unattended-installer.c"
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 1282 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1282 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1282 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 891 "unattended-installer.c"
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = old;
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp1_;
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp2_);
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		regex = _tmp4_;
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 922 "unattended-installer.c"
				goto __catch81_g_regex_error;
			}
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1284 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 931 "unattended-installer.c"
		}
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = regex;
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = replacement;
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) -1, 0, _tmp7_, 0, &_inner_error_);
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = _tmp8_;
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 947 "unattended-installer.c"
				goto __catch81_g_regex_error;
			}
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 958 "unattended-installer.c"
		}
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = _tmp5_;
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = NULL;
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp9_;
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp5_);
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1285 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 972 "unattended-installer.c"
	}
	goto __finally81;
	__catch81_g_regex_error:
	{
		GError* e = NULL;
#line 1283 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1283 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1287 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1283 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 986 "unattended-installer.c"
	}
	__finally81:
#line 1283 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1283 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1283 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1283 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
		return NULL;
#line 997 "unattended-installer.c"
	}
}


static gchar* boxes_unattended_installer_escape_mkisofs_path (const gchar* path) {
	gchar* result = NULL;
	gchar* str = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = path;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = string_replace (_tmp0_, "\\", "\\\\");
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	str = _tmp1_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = string_replace (str, "=", "\\=");
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp2_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (str);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 1024 "unattended-installer.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return self ? g_object_ref (self) : NULL;
#line 1031 "unattended-installer.c"
}


static void __lambda133_ (BoxesUnattendedInstaller* self) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_notify ((GObject*) self, "ready-to-create");
#line 1038 "unattended-installer.c"
}


static void ___lambda133__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__lambda133_ ((BoxesUnattendedInstaller*) self);
#line 1045 "unattended-installer.c"
}


static void __lambda134_ (BoxesUnattendedInstaller* self) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_emit_by_name ((BoxesInstallerMedia*) self, "user-wants-to-create");
#line 1052 "unattended-installer.c"
}


static void ___lambda134__boxes_unattended_setup_box_user_wants_to_create (BoxesUnattendedSetupBox* _sender, gpointer self) {
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__lambda134_ ((BoxesUnattendedInstaller*) self);
#line 1059 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error) {
	BoxesUnattendedInstaller * self = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	OsinfoOs* _tmp1_ = NULL;
	OsinfoOs* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	OsinfoMedia* _tmp4_ = NULL;
	OsinfoMedia* _tmp5_ = NULL;
	BoxesInstallerMedia* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	BoxesInstallerMedia* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	BoxesInstallerMedia* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	BoxesInstallerMedia* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	BoxesInstallerMedia* _tmp17_ = NULL;
	OsinfoResources* _tmp18_ = NULL;
	OsinfoResources* _tmp19_ = NULL;
	OsinfoInstallScriptList* _tmp20_ = NULL;
	OsinfoInstallScriptList* _tmp21_ = NULL;
	OsinfoInstallConfig* _tmp22_ = NULL;
	gboolean needs_internet = FALSE;
	OsinfoInstallScriptList* _tmp23_ = NULL;
	GList* _tmp24_ = NULL;
	OsinfoDeviceList* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	const gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gchar* product_key_format = NULL;
	gchar* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	gboolean _tmp45_ = FALSE;
	BoxesUnattendedSetupBox* _tmp46_ = NULL;
	BoxesUnattendedSetupBox* _tmp47_ = NULL;
	BoxesUnattendedSetupBox* _tmp48_ = NULL;
	GError * _inner_error_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (scripts != NULL, NULL);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) boxes_installer_media_construct (object_type);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = media;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_->os;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (((BoxesInstallerMedia*) self)->os);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->os = _tmp2_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = media;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _tmp3_->os_media;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (((BoxesInstallerMedia*) self)->os_media);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->os_media = _tmp5_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = media;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _tmp6_->label;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (((BoxesInstallerMedia*) self)->label);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->label = _tmp8_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = media;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = _tmp9_->device_file;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (((BoxesInstallerMedia*) self)->device_file);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->device_file = _tmp11_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = media;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = _tmp12_->from_image;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->from_image = _tmp13_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp14_ = media;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = _tmp14_->mount_point;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (((BoxesInstallerMedia*) self)->mount_point);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->mount_point = _tmp16_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp17_ = media;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp18_ = _tmp17_->resources;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp19_ = _g_object_ref0 (_tmp18_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (((BoxesInstallerMedia*) self)->resources);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMedia*) self)->resources = _tmp19_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp20_ = scripts;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp21_ = _g_object_ref0 (_tmp20_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->scripts);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->scripts = _tmp21_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp22_ = osinfo_install_config_new ("https://wiki.gnome.org/Boxes/unattended");
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->config);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->config = _tmp22_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->unattended_files);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->unattended_files = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->secondary_unattended_files);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->secondary_unattended_files = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	needs_internet = FALSE;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp23_ = scripts;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp24_ = osinfo_list_get_elements ((OsinfoList*) _tmp23_);
#line 1204 "unattended-installer.c"
	{
		GList* s_collection = NULL;
		GList* s_it = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		s_collection = _tmp24_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 1212 "unattended-installer.c"
			OsinfoEntity* s = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s = (OsinfoEntity*) s_it->data;
#line 1216 "unattended-installer.c"
			{
				OsinfoInstallScript* script = NULL;
				OsinfoEntity* _tmp25_ = NULL;
				OsinfoInstallScript* _tmp26_ = NULL;
				gchar* filename = NULL;
				OsinfoInstallScript* _tmp27_ = NULL;
				const gchar* _tmp28_ = NULL;
				gchar* _tmp29_ = NULL;
				BoxesUnattendedScriptFile* _tmp30_ = NULL;
				OsinfoInstallScript* _tmp31_ = NULL;
				const gchar* _tmp32_ = NULL;
				BoxesUnattendedScriptFile* _tmp33_ = NULL;
				gboolean _tmp34_ = FALSE;
				gboolean _tmp35_ = FALSE;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp25_ = s;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp25_) : NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				script = _tmp26_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp27_ = script;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp28_ = osinfo_install_script_get_expected_filename (_tmp27_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp29_ = g_strdup (_tmp28_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				filename = _tmp29_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp31_ = script;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp32_ = filename;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp33_ = boxes_unattended_script_file_new (self, _tmp31_, _tmp32_, &_inner_error_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp30_ = _tmp33_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_propagate_error (error, _inner_error_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (filename);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_list_free0 (s_collection);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (self);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return NULL;
#line 1267 "unattended-installer.c"
				}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				boxes_unattended_installer_add_unattended_file (self, (BoxesUnattendedFile*) _tmp30_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp35_ = needs_internet;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp35_) {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp34_ = TRUE;
#line 1277 "unattended-installer.c"
				} else {
					OsinfoInstallScript* _tmp36_ = NULL;
					gboolean _tmp37_ = FALSE;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp36_ = script;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp37_ = osinfo_install_script_get_needs_internet (_tmp36_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp34_ = _tmp37_;
#line 1287 "unattended-installer.c"
				}
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				needs_internet = _tmp34_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_tmp30_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (filename);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 1297 "unattended-installer.c"
			}
		}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (s_collection);
#line 1302 "unattended-installer.c"
	}
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp38_ = osinfo_devicelist_new ();
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->additional_devices);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->additional_devices = _tmp38_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp39_ = boxes_get_timezone ();
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->timezone);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->timezone = _tmp39_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp40_ = boxes_unattended_installer_get_preferred_language (self);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->lang);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->lang = _tmp40_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp41_ = self->priv->lang;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp42_ = g_strdup (_tmp41_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->kbd);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->kbd = _tmp42_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp43_ = boxes_unattended_installer_get_product_key_format (self);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	product_key_format = _tmp43_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp44_ = product_key_format;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp45_ = needs_internet;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp46_ = boxes_unattended_setup_box_new ((BoxesInstallerMedia*) self, _tmp44_, _tmp45_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_ref_sink (_tmp46_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->setup_box);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->setup_box = _tmp46_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp47_ = self->setup_box;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_object ((GObject*) _tmp47_, "notify::ready-to-create", (GCallback) ___lambda133__g_object_notify, self, 0);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp48_ = self->setup_box;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_signal_connect_object (_tmp48_, "user-wants-to-create", (GCallback) ___lambda134__boxes_unattended_setup_box_user_wants_to_create, self, 0);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_fetch_user_avatar (self, NULL, NULL);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (product_key_format);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return self;
#line 1360 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_new_from_media (BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return boxes_unattended_installer_construct_from_media (BOXES_TYPE_UNATTENDED_INSTALLER, media, scripts, error);
#line 1367 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_to_continue_installation (BoxesInstallerMedia* base, const gchar* vm_name) {
	BoxesUnattendedInstaller * self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* path = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GFile* _tmp4_ = NULL;
	GList* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	gboolean _tmp10_ = FALSE;
	OsinfoMedia* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (vm_name != NULL);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = vm_name;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = string_replace (_tmp0_, " ", "-");
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->hostname);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->hostname = _tmp1_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = boxes_unattended_installer_get_user_unattended (self, "unattended.img");
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	path = _tmp2_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = path;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = g_file_new_for_path (_tmp3_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->disk_file);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->disk_file = _tmp4_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->priv->secondary_unattended_files;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = g_list_length (_tmp5_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp6_ > ((guint) 0)) {
#line 1417 "unattended-installer.c"
		gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		GFile* _tmp9_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = boxes_unattended_installer_get_user_unattended (self, "unattended.iso");
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp7_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = path;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = g_file_new_for_path (_tmp8_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self->secondary_disk_file);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self->secondary_disk_file = _tmp9_;
#line 1435 "unattended-installer.c"
	}
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = ((BoxesInstallerMedia*) self)->os_media;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_tmp11_, "kernel-path", &_tmp12_, NULL);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = _tmp12_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp14_ = _tmp13_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = _tmp14_ != NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp14_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp15_) {
#line 1451 "unattended-installer.c"
		OsinfoMedia* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp16_ = ((BoxesInstallerMedia*) self)->os_media;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_get (_tmp16_, "initrd-path", &_tmp17_, NULL);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp18_ = _tmp17_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp19_ = _tmp18_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = _tmp19_ != NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp19_);
#line 1468 "unattended-installer.c"
	} else {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = FALSE;
#line 1472 "unattended-installer.c"
	}
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp10_) {
#line 1476 "unattended-installer.c"
		gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		GFile* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		GFile* _tmp25_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp20_ = boxes_unattended_installer_get_user_unattended (self, "kernel");
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp20_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp21_ = path;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp22_ = g_file_new_for_path (_tmp21_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self->kernel_file);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self->kernel_file = _tmp22_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp23_ = boxes_unattended_installer_get_user_unattended (self, "initrd");
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp23_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp24_ = path;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp25_ = g_file_new_for_path (_tmp24_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self->initrd_file);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self->initrd_file = _tmp25_;
#line 1511 "unattended-installer.c"
	}
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (path);
#line 1515 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_for_installation_data_free (gpointer _data) {
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->vm_name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerPrepareForInstallationData, _data_);
#line 1530 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_for_installation (BoxesInstallerMedia* base, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstaller * self;
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerPrepareForInstallationData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_real_prepare_for_installation);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_real_prepare_for_installation_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = vm_name;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->vm_name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->vm_name = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_for_installation_co (_data_);
#line 1572 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_for_installation_finish (BoxesInstallerMedia* base, GAsyncResult* _res_) {
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1580 "unattended-installer.c"
}


static void boxes_unattended_installer_prepare_for_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerPrepareForInstallationData* _data_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_for_installation_co (_data_);
#line 1594 "unattended-installer.c"
}


static void _vala_array_add9 (gchar*** array, int* length, int* size, gchar* value) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if ((*length) == (*size)) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 1605 "unattended-installer.c"
	}
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[(*length)++] = value;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[*length] = NULL;
#line 1611 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_prepare_for_installation_co (BoxesUnattendedInstallerPrepareForInstallationData* _data_) {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 1620 "unattended-installer.c"
		goto _state_0;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 1624 "unattended-installer.c"
		goto _state_1;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 1628 "unattended-installer.c"
		goto _state_2;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 3:
#line 1632 "unattended-installer.c"
		goto _state_3;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 4:
#line 1636 "unattended-installer.c"
		goto _state_4;
		default:
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 1641 "unattended-installer.c"
	}
	_state_0:
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->self->setup_box;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_setup_box_save_settings (_data_->_tmp0_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = _data_->self->setup_box;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = FALSE;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = boxes_unattended_setup_box_get_express_install (_data_->_tmp1_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = FALSE;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_data_->_tmp3_) {
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:147: Unattended installation disabled.");
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1670 "unattended-installer.c"
		} else {
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1674 "unattended-installer.c"
		}
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 1680 "unattended-installer.c"
	}
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = _data_->vm_name;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_installer_media_prepare_to_continue_installation ((BoxesInstallerMedia*) _data_->self, _data_->_tmp4_);
#line 1688 "unattended-installer.c"
	{
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = _data_->cancellable;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 1;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_create_disk_image (_data_->self, _data_->_tmp5_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 1700 "unattended-installer.c"
		_state_1:
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_create_disk_image_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1706 "unattended-installer.c"
			goto __catch82_g_error;
		}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp7_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp7_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_get (_data_->_tmp7_, "kernel-path", &_data_->_tmp8_, NULL);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = FALSE;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = _data_->_tmp10_ != NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->_tmp10_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_tmp11_) {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp12_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp12_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp13_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_object_get (_data_->_tmp12_, "initrd-path", &_data_->_tmp13_, NULL);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp14_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp14_ = _data_->_tmp13_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp15_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp15_ = _data_->_tmp14_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp6_ = _data_->_tmp15_ != NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->_tmp15_);
#line 1753 "unattended-installer.c"
		} else {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp6_ = FALSE;
#line 1757 "unattended-installer.c"
		}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_tmp6_) {
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp16_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp16_ = ((BoxesInstallerMedia*) _data_->self)->device_file;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp17_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp17_ = boxes_iso_extractor_new (_data_->_tmp16_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->extractor = _data_->_tmp17_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp18_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp18_ = _data_->extractor;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp19_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp19_ = _data_->cancellable;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_state_ = 2;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_unattended_installer_extract_boot_files (_data_->self, _data_->_tmp18_, _data_->_tmp19_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 1785 "unattended-installer.c"
			_state_2:
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_unattended_installer_extract_boot_files_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->extractor);
#line 1793 "unattended-installer.c"
				goto __catch82_g_error;
			}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_data_->extractor);
#line 1798 "unattended-installer.c"
		}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = NULL;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = _data_->self->priv->unattended_files;
#line 1804 "unattended-installer.c"
		{
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->unattended_file_collection = _data_->_tmp20_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			for (_data_->unattended_file_it = _data_->unattended_file_collection; _data_->unattended_file_it != NULL; _data_->unattended_file_it = _data_->unattended_file_it->next) {
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp21_ = NULL;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp21_ = _g_object_ref0 ((BoxesUnattendedFile*) _data_->unattended_file_it->data);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->unattended_file = _data_->_tmp21_;
#line 1816 "unattended-installer.c"
				{
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = _data_->unattended_file;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp23_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp23_ = _data_->cancellable;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_state_ = 3;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_file_copy (_data_->_tmp22_, _data_->_tmp23_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 1832 "unattended-installer.c"
					_state_3:
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_file_copy_finish (_data_->_tmp22_, _data_->_res_, &_data_->_inner_error_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (_data_->unattended_file);
#line 1840 "unattended-installer.c"
						goto __catch82_g_error;
					}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->unattended_file);
#line 1845 "unattended-installer.c"
				}
			}
		}
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp24_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp24_ = _data_->self->secondary_disk_file;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_tmp24_ != NULL) {
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp25_ = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp25_ = _data_->self->secondary_disk_file;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp26_ = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp26_ = g_file_get_path (_data_->_tmp25_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->secondary_disk_path = _data_->_tmp26_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp27_ = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp27_ = _data_->secondary_disk_path;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_debug ("unattended-installer.vala:170: Creating secondary disk image '%s'...", _data_->_tmp27_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp28_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp28_ = g_strdup ("mkisofs");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp29_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp29_ = g_strdup ("-graft-points");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp30_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp30_ = g_strdup ("-J");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp31_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp31_ = g_strdup ("-rock");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp32_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp32_ = g_strdup ("-o");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp33_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp33_ = _data_->secondary_disk_path;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp34_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp34_ = g_strdup (_data_->_tmp33_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_ = g_new0 (gchar*, 6 + 1);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_[0] = _data_->_tmp28_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_[1] = _data_->_tmp29_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_[2] = _data_->_tmp30_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_[3] = _data_->_tmp31_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_[4] = _data_->_tmp32_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp35_[5] = _data_->_tmp34_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv_length1 = 0;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_argv_size_ = 0;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv = _data_->_tmp35_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv_length1 = 6;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_argv_size_ = _data_->argv_length1;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp36_ = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp36_ = _data_->self->priv->secondary_unattended_files;
#line 1929 "unattended-installer.c"
			{
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_vala1_unattended_file_collection = _data_->_tmp36_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				for (_data_->_vala1_unattended_file_it = _data_->_vala1_unattended_file_collection; _data_->_vala1_unattended_file_it != NULL; _data_->_vala1_unattended_file_it = _data_->_vala1_unattended_file_it->next) {
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp37_ = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp37_ = _g_object_ref0 ((BoxesUnattendedFile*) _data_->_vala1_unattended_file_it->data);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_vala1_unattended_file = _data_->_tmp37_;
#line 1941 "unattended-installer.c"
					{
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp38_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp38_ = _data_->_vala1_unattended_file;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp39_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp39_ = boxes_unattended_file_get_dest_name (_data_->_tmp38_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp40_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp40_ = _data_->_tmp39_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp41_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp41_ = boxes_unattended_installer_escape_mkisofs_path (_data_->_tmp40_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->dest_path = _data_->_tmp41_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp42_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp42_ = _data_->_vala1_unattended_file;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp43_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp43_ = boxes_unattended_file_get_src_path (_data_->_tmp42_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp44_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp44_ = _data_->_tmp43_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp45_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp45_ = boxes_unattended_installer_escape_mkisofs_path (_data_->_tmp44_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->src_path = _data_->_tmp45_;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp46_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp46__length1 = 0;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp46_ = _data_->argv;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp46__length1 = _data_->argv_length1;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp47_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp47_ = _data_->dest_path;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp48_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp48_ = g_strconcat (_data_->_tmp47_, "=", NULL);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp49_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp49_ = _data_->_tmp48_;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp50_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp50_ = _data_->src_path;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp51_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp51_ = g_strconcat (_data_->_tmp49_, _data_->_tmp50_, NULL);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_vala_array_add9 (&_data_->argv, &_data_->argv_length1, &_data_->_argv_size_, _data_->_tmp51_);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_data_->_tmp49_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_data_->src_path);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_data_->dest_path);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (_data_->_vala1_unattended_file);
#line 2017 "unattended-installer.c"
					}
				}
			}
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp52_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp52__length1 = 0;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp52_ = _data_->argv;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp52__length1 = _data_->argv_length1;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp53_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp53_ = _data_->cancellable;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_state_ = 4;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_exec (_data_->_tmp52_, _data_->_tmp52__length1, _data_->_tmp53_, boxes_unattended_installer_prepare_for_installation_ready, _data_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 2039 "unattended-installer.c"
			_state_4:
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_exec_finish (_data_->_res_, NULL, NULL, &_data_->_inner_error_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->secondary_disk_path);
#line 2049 "unattended-installer.c"
				goto __catch82_g_error;
			}
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp54_ = NULL;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp54_ = _data_->secondary_disk_path;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_debug ("unattended-installer.vala:180: Created secondary disk image '%s'...", _data_->_tmp54_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->secondary_disk_path);
#line 2062 "unattended-installer.c"
		}
	}
	goto __finally82;
	__catch82_g_error:
	{
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_inner_error_ = NULL;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_installer_media_clean_up ((BoxesInstallerMedia*) _data_->self);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp55_ = NULL;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp55_ = _data_->self->setup_box;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_setup_box_set_express_install (_data_->_tmp55_, FALSE);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp56_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp56_ = _ ("An error occurred during installation preparation. Express Install dis" \
"abled.");
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp57_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp57_ = g_strdup (_data_->_tmp56_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->msg = _data_->_tmp57_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp58_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp58_ = boxes_app_app;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp59_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp59_ = boxes_app_get_main_window (_data_->_tmp58_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp60_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp60_ = _data_->_tmp59_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp61_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp61_ = boxes_app_window_get_notificationbar (_data_->_tmp60_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp62_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp62_ = _data_->_tmp61_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp63_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp63_ = _data_->msg;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp64_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp64_ = boxes_notificationbar_display_error (_data_->_tmp62_, _data_->_tmp63_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp65_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp65_ = _data_->_tmp64_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->_tmp65_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp66_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp66_ = _data_->_error_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp67_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp67_ = _data_->_tmp66_->message;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:190: Disabling unattended installation: %s", _data_->_tmp67_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->msg);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_data_->_error_);
#line 2138 "unattended-installer.c"
	}
	__finally82:
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_clear_error (&_data_->_inner_error_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 2149 "unattended-installer.c"
	}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2155 "unattended-installer.c"
	} else {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2159 "unattended-installer.c"
	}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 2165 "unattended-installer.c"
}


static void boxes_unattended_installer_real_setup_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain) {
	BoxesUnattendedInstaller * self;
	GVirConfigDomain* _tmp0_ = NULL;
	BoxesUnattendedSetupBox* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GFile* _tmp4_ = NULL;
	GVirConfigDomainDisk* disk = NULL;
	GVirConfigDomainDisk* _tmp5_ = NULL;
	GVirConfigDomain* _tmp6_ = NULL;
	GVirConfigDomainDisk* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain != NULL);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = domain;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->setup_domain_config (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia), _tmp0_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->setup_box;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = boxes_unattended_setup_box_get_express_install (_tmp1_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp2_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_tmp3_) {
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 2199 "unattended-installer.c"
	}
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = self->disk_file;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (_tmp4_ != NULL);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = boxes_unattended_installer_get_unattended_disk_config (self, OSINFO_PATH_FORMAT_UNIX);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk = _tmp5_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = domain;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = disk;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_add_device (_tmp6_, (GVirConfigDomainDevice*) _tmp7_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = self->secondary_disk_file;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp8_ != NULL) {
#line 2219 "unattended-installer.c"
		GVirConfigDomainDisk* _tmp9_ = NULL;
		GVirConfigDomain* _tmp10_ = NULL;
		GVirConfigDomainDisk* _tmp11_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = boxes_unattended_installer_get_secondary_unattended_disk_config (self, OSINFO_PATH_FORMAT_UNIX);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (disk);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		disk = _tmp9_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = domain;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = disk;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_add_device (_tmp10_, (GVirConfigDomainDevice*) _tmp11_);
#line 2235 "unattended-installer.c"
	}
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (disk);
#line 2239 "unattended-installer.c"
}


void boxes_unattended_installer_configure_install_script (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	BoxesUnattendedSetupBox* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	BoxesUnattendedSetupBox* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	BoxesUnattendedSetupBox* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gboolean _tmp30_ = FALSE;
	const gchar* _tmp36_ = NULL;
	OsinfoInstallConfig* _tmp39_ = NULL;
	const gchar* _tmp40_ = NULL;
	OsinfoInstallConfig* _tmp41_ = NULL;
	const gchar* _tmp42_ = NULL;
	OsinfoInstallConfig* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	OsinfoInstallConfig* _tmp45_ = NULL;
	OsinfoMedia* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	OsinfoOs* _tmp50_ = NULL;
	const gchar* _tmp51_ = NULL;
	const gchar* _tmp52_ = NULL;
	GVirConfigDomainDisk* disk_config = NULL;
	OsinfoInstallScript* _tmp58_ = NULL;
	OsinfoPathFormat _tmp59_ = 0;
	OsinfoPathFormat _tmp60_ = 0;
	GVirConfigDomainDisk* _tmp61_ = NULL;
	gchar* device_path = NULL;
	OsinfoInstallScript* _tmp62_ = NULL;
	OsinfoPathFormat _tmp63_ = 0;
	OsinfoPathFormat _tmp64_ = 0;
	GVirConfigDomainDisk* _tmp65_ = NULL;
	const gchar* _tmp66_ = NULL;
	gchar* _tmp67_ = NULL;
	OsinfoInstallConfig* _tmp68_ = NULL;
	const gchar* _tmp69_ = NULL;
	BoxesUnattendedAvatarFile* _tmp70_ = NULL;
	OsinfoInstallConfig* _tmp84_ = NULL;
	OsinfoInstallConfig* _tmp85_ = NULL;
	const gchar* _tmp86_ = NULL;
	GFile* _tmp87_ = NULL;
	OsinfoInstallConfig* _tmp100_ = NULL;
	gboolean _tmp101_ = FALSE;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (script != NULL);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->setup_box;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_setup_box_get_password (_tmp0_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp2_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _tmp3_ != NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp3_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp4_) {
#line 2311 "unattended-installer.c"
		OsinfoInstallConfig* _tmp5_ = NULL;
		BoxesUnattendedSetupBox* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		OsinfoInstallConfig* _tmp10_ = NULL;
		BoxesUnattendedSetupBox* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = self->config;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = self->setup_box;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = boxes_unattended_setup_box_get_password (_tmp6_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = _tmp7_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = _tmp8_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_user_password (_tmp5_, _tmp9_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp9_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = self->config;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = self->setup_box;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp12_ = boxes_unattended_setup_box_get_password (_tmp11_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp13_ = _tmp12_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp14_ = _tmp13_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_admin_password (_tmp10_, _tmp14_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp14_);
#line 2350 "unattended-installer.c"
	}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = self->setup_box;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp16_ = boxes_unattended_setup_box_get_username (_tmp15_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp17_ = _tmp16_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp17_ != NULL) {
#line 2360 "unattended-installer.c"
		OsinfoInstallConfig* _tmp18_ = NULL;
		BoxesUnattendedSetupBox* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		OsinfoInstallConfig* _tmp22_ = NULL;
		BoxesUnattendedSetupBox* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp18_ = self->config;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp19_ = self->setup_box;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp20_ = boxes_unattended_setup_box_get_username (_tmp19_);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp21_ = _tmp20_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_user_login (_tmp18_, _tmp21_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp22_ = self->config;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp23_ = self->setup_box;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp24_ = boxes_unattended_setup_box_get_username (_tmp23_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp25_ = _tmp24_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_user_realname (_tmp22_, _tmp25_);
#line 2389 "unattended-installer.c"
	}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp26_ = self->setup_box;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp27_ = boxes_unattended_setup_box_get_product_key (_tmp26_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp28_ = _tmp27_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp29_ = _tmp28_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp30_ = _tmp29_ != NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp29_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp30_) {
#line 2405 "unattended-installer.c"
		OsinfoInstallConfig* _tmp31_ = NULL;
		BoxesUnattendedSetupBox* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp31_ = self->config;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp32_ = self->setup_box;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp33_ = boxes_unattended_setup_box_get_product_key (_tmp32_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp34_ = _tmp33_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp35_ = _tmp34_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_reg_product_key (_tmp31_, _tmp35_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp35_);
#line 2425 "unattended-installer.c"
	}
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp36_ = self->priv->timezone;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp36_ != NULL) {
#line 2431 "unattended-installer.c"
		OsinfoInstallConfig* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp37_ = self->config;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp38_ = self->priv->timezone;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_l10n_timezone (_tmp37_, _tmp38_);
#line 2440 "unattended-installer.c"
	}
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp39_ = self->config;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp40_ = self->priv->lang;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_l10n_language (_tmp39_, _tmp40_);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp41_ = self->config;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp42_ = self->priv->kbd;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_l10n_keyboard (_tmp41_, _tmp42_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp43_ = self->config;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp44_ = self->priv->hostname;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_hostname (_tmp43_, _tmp44_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp45_ = self->config;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp46_ = ((BoxesInstallerMedia*) self)->os_media;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_tmp46_, "architecture", &_tmp47_, NULL);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp48_ = _tmp47_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp49_ = _tmp48_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_hardware_arch (_tmp45_, _tmp49_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp49_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp50_ = ((BoxesInstallerMedia*) self)->os;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp51_ = osinfo_os_get_distro (_tmp50_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp52_ = _tmp51_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_strcmp0 (_tmp52_, "win") == 0) {
#line 2482 "unattended-installer.c"
		OsinfoInstallConfig* _tmp53_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp53_ = self->config;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_target_disk (_tmp53_, "C");
#line 2488 "unattended-installer.c"
	} else {
		const gchar* _tmp54_ = NULL;
		gboolean _tmp55_ = FALSE;
		gboolean _tmp56_ = FALSE;
		OsinfoInstallConfig* _tmp57_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp55_ = boxes_installer_media_get_supports_virtio_disk ((BoxesInstallerMedia*) self);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp56_ = _tmp55_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp56_) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp54_ = "/dev/vda";
#line 2502 "unattended-installer.c"
		} else {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp54_ = "/dev/sda";
#line 2506 "unattended-installer.c"
		}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp57_ = self->config;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_target_disk (_tmp57_, _tmp54_);
#line 2512 "unattended-installer.c"
	}
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp58_ = script;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp59_ = osinfo_install_script_get_path_format (_tmp58_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp60_ = _tmp59_;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp61_ = boxes_unattended_installer_get_unattended_disk_config (self, _tmp60_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk_config = _tmp61_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp62_ = script;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp63_ = osinfo_install_script_get_path_format (_tmp62_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp64_ = _tmp63_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp65_ = disk_config;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp66_ = gvir_config_domain_disk_get_target_dev (_tmp65_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp67_ = boxes_unattended_installer_device_name_to_path (self, _tmp64_, _tmp66_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	device_path = _tmp67_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp68_ = self->config;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp69_ = device_path;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_script_disk (_tmp68_, _tmp69_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp70_ = self->priv->avatar_file;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp70_ != NULL) {
#line 2548 "unattended-installer.c"
		const gchar* _tmp71_ = NULL;
		OsinfoInstallScript* _tmp72_ = NULL;
		OsinfoPathFormat _tmp73_ = 0;
		OsinfoPathFormat _tmp74_ = 0;
		gchar* location = NULL;
		BoxesUnattendedAvatarFile* _tmp75_ = NULL;
		const gchar* _tmp76_ = NULL;
		const gchar* _tmp77_ = NULL;
		gchar* _tmp78_ = NULL;
		OsinfoInstallConfig* _tmp79_ = NULL;
		const gchar* _tmp80_ = NULL;
		OsinfoInstallConfig* _tmp81_ = NULL;
		OsinfoInstallConfig* _tmp82_ = NULL;
		const gchar* _tmp83_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp72_ = script;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp73_ = osinfo_install_script_get_path_format (_tmp72_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp74_ = _tmp73_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp74_ == OSINFO_PATH_FORMAT_UNIX) {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp71_ = "/";
#line 2573 "unattended-installer.c"
		} else {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp71_ = "\\";
#line 2577 "unattended-installer.c"
		}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp75_ = self->priv->avatar_file;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp76_ = boxes_unattended_file_get_dest_name ((BoxesUnattendedFile*) _tmp75_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp77_ = _tmp76_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp78_ = g_strconcat (_tmp71_, _tmp77_, NULL);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		location = _tmp78_;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp79_ = self->config;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp80_ = location;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_avatar_location (_tmp79_, _tmp80_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp81_ = self->config;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp82_ = self->config;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp83_ = osinfo_install_config_get_script_disk (_tmp82_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_avatar_disk (_tmp81_, _tmp83_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (location);
#line 2605 "unattended-installer.c"
	}
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp84_ = self->config;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp85_ = self->config;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp86_ = osinfo_install_config_get_script_disk (_tmp85_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_pre_install_drivers_disk (_tmp84_, _tmp86_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp87_ = self->secondary_disk_file;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp87_ != NULL) {
#line 2619 "unattended-installer.c"
		OsinfoInstallScript* _tmp88_ = NULL;
		OsinfoPathFormat _tmp89_ = 0;
		OsinfoPathFormat _tmp90_ = 0;
		GVirConfigDomainDisk* _tmp91_ = NULL;
		OsinfoInstallScript* _tmp92_ = NULL;
		OsinfoPathFormat _tmp93_ = 0;
		OsinfoPathFormat _tmp94_ = 0;
		GVirConfigDomainDisk* _tmp95_ = NULL;
		const gchar* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		OsinfoInstallConfig* _tmp98_ = NULL;
		const gchar* _tmp99_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp88_ = script;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp89_ = osinfo_install_script_get_path_format (_tmp88_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp90_ = _tmp89_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp91_ = boxes_unattended_installer_get_secondary_unattended_disk_config (self, _tmp90_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (disk_config);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		disk_config = _tmp91_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp92_ = script;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp93_ = osinfo_install_script_get_path_format (_tmp92_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp94_ = _tmp93_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp95_ = disk_config;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp96_ = gvir_config_domain_disk_get_target_dev (_tmp95_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp97_ = boxes_unattended_installer_device_name_to_path (self, _tmp94_, _tmp96_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (device_path);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		device_path = _tmp97_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp98_ = self->config;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp99_ = device_path;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		osinfo_install_config_set_post_install_drivers_disk (_tmp98_, _tmp99_);
#line 2666 "unattended-installer.c"
	}
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp100_ = self->config;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp101_ = self->priv->driver_signing;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	osinfo_install_config_set_driver_signing (_tmp100_, _tmp101_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (device_path);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (disk_config);
#line 2678 "unattended-installer.c"
}


static void boxes_unattended_installer_real_setup_post_install_domain_config (BoxesInstallerMedia* base, GVirConfigDomain* domain) {
	BoxesUnattendedInstaller * self;
	GFile* _tmp0_ = NULL;
	GFile* _tmp5_ = NULL;
	GVirConfigDomain* _tmp10_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain != NULL);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->disk_file;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp0_ != NULL) {
#line 2695 "unattended-installer.c"
		gchar* path = NULL;
		GFile* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GVirConfigDomain* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp1_ = self->disk_file;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = g_file_get_path (_tmp1_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp2_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = domain;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = path;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_remove_disk_from_domain_config (self, _tmp3_, _tmp4_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 2715 "unattended-installer.c"
	}
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->secondary_disk_file;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp5_ != NULL) {
#line 2721 "unattended-installer.c"
		gchar* path = NULL;
		GFile* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GVirConfigDomain* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = self->secondary_disk_file;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = g_file_get_path (_tmp6_);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		path = _tmp7_;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = domain;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = path;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_remove_disk_from_domain_config (self, _tmp8_, _tmp9_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (path);
#line 2741 "unattended-installer.c"
	}
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = domain;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->setup_post_install_domain_config (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia), _tmp10_);
#line 2747 "unattended-installer.c"
}


static void boxes_unattended_installer_real_populate_setup_box (BoxesInstallerMedia* base, GtkBox* setup_box) {
	BoxesUnattendedInstaller * self;
	GtkBox* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GtkBox* _tmp4_ = NULL;
	BoxesUnattendedSetupBox* _tmp5_ = NULL;
	GtkBox* _tmp6_ = NULL;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (setup_box != NULL);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = setup_box;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 2766 "unattended-installer.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		child_collection = _tmp1_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 2774 "unattended-installer.c"
			GtkWidget* child = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			child = (GtkWidget*) child_it->data;
#line 2778 "unattended-installer.c"
			{
				GtkBox* _tmp2_ = NULL;
				GtkWidget* _tmp3_ = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = setup_box;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = child;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				gtk_container_remove ((GtkContainer*) _tmp2_, _tmp3_);
#line 2788 "unattended-installer.c"
			}
		}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (child_collection);
#line 2793 "unattended-installer.c"
	}
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = setup_box;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->setup_box;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_container_add ((GtkContainer*) _tmp4_, (GtkWidget*) _tmp5_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = setup_box;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gtk_widget_show ((GtkWidget*) _tmp6_);
#line 2805 "unattended-installer.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 2812 "unattended-installer.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_list_free (self);
#line 2821 "unattended-installer.c"
}


static GList* boxes_unattended_installer_real_get_vm_properties (BoxesInstallerMedia* base) {
	BoxesUnattendedInstaller * self;
	GList* result = NULL;
	GList* properties = NULL;
	GList* _tmp0_ = NULL;
	BoxesUnattendedSetupBox* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->get_vm_properties (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	properties = _tmp0_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->setup_box;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = boxes_unattended_setup_box_get_express_install (_tmp1_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp2_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp3_) {
#line 2847 "unattended-installer.c"
		const gchar* _tmp4_ = NULL;
		BoxesUnattendedSetupBox* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		BoxesPair* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		BoxesUnattendedSetupBox* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		BoxesPair* _tmp14_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = _ ("Username");
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = self->setup_box;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = boxes_unattended_setup_box_get_username (_tmp5_);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = _tmp6_;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = boxes_pair_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp4_, _tmp7_);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		properties = g_list_append (properties, _tmp8_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = _ ("Password");
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = self->setup_box;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = boxes_unattended_setup_box_get_hidden_password (_tmp10_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp12_ = _tmp11_;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp13_ = _tmp12_;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp14_ = boxes_pair_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp9_, _tmp13_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		properties = g_list_append (properties, _tmp14_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp13_);
#line 2887 "unattended-installer.c"
	}
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = properties;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 2893 "unattended-installer.c"
}


static void boxes_unattended_installer_real_set_direct_boot_params (BoxesInstallerMedia* base, GVirConfigDomainOs* domain_os) {
	BoxesUnattendedInstaller * self;
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_ = NULL;
	OsinfoInstallScript* script = NULL;
	OsinfoInstallScriptList* _tmp3_ = NULL;
	OsinfoEntity* _tmp4_ = NULL;
	OsinfoInstallScript* _tmp5_ = NULL;
	GVirConfigDomainOs* _tmp6_ = NULL;
	GFile* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GVirConfigDomainOs* _tmp10_ = NULL;
	GFile* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	GVirConfigDomainOs* _tmp14_ = NULL;
	OsinfoInstallScript* _tmp15_ = NULL;
	OsinfoMedia* _tmp16_ = NULL;
	OsinfoInstallConfig* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain_os != NULL);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->kernel_file;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp1_ == NULL) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = TRUE;
#line 2929 "unattended-installer.c"
	} else {
		GFile* _tmp2_ = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = self->initrd_file;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp2_ == NULL;
#line 2936 "unattended-installer.c"
	}
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp0_) {
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 2942 "unattended-installer.c"
	}
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = self->scripts;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = osinfo_list_get_nth ((OsinfoList*) _tmp3_, 0);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp4_) : NULL);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	script = _tmp5_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = domain_os;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = self->kernel_file;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = g_file_get_path (_tmp7_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = _tmp8_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_os_set_kernel (_tmp6_, _tmp9_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp9_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = domain_os;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = self->initrd_file;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = g_file_get_path (_tmp11_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp13_ = _tmp12_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_os_set_ramdisk (_tmp10_, _tmp13_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp13_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp14_ = domain_os;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp15_ = script;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp16_ = ((BoxesInstallerMedia*) self)->os_media;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp17_ = self->config;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp18_ = osinfo_install_script_generate_command_line_for_media (_tmp15_, _tmp16_, _tmp17_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp19_ = _tmp18_;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_os_set_cmdline (_tmp14_, _tmp19_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp19_);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (script);
#line 2994 "unattended-installer.c"
}


static void boxes_unattended_installer_real_clean_up (BoxesInstallerMedia* base) {
	BoxesUnattendedInstaller * self;
	BoxesUnattendedSetupBox* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->clean_up (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->setup_box;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_setup_box_clean_up (_tmp0_);
#line 3010 "unattended-installer.c"
	{
		GFile* _tmp1_ = NULL;
		GFile* _tmp3_ = NULL;
		GFile* _tmp5_ = NULL;
		GFile* _tmp7_ = NULL;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp1_ = self->disk_file;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp1_ != NULL) {
#line 3020 "unattended-installer.c"
			GFile* _tmp2_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = self->disk_file;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp2_, &_inner_error_);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3028 "unattended-installer.c"
				goto __catch83_g_error;
			}
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->disk_file);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->disk_file = NULL;
#line 3035 "unattended-installer.c"
		}
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = self->secondary_disk_file;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp3_ != NULL) {
#line 3041 "unattended-installer.c"
			GFile* _tmp4_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp4_ = self->secondary_disk_file;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp4_, &_inner_error_);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3049 "unattended-installer.c"
				goto __catch83_g_error;
			}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->secondary_disk_file);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->secondary_disk_file = NULL;
#line 3056 "unattended-installer.c"
		}
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = self->kernel_file;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp5_ != NULL) {
#line 3062 "unattended-installer.c"
			GFile* _tmp6_ = NULL;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp6_ = self->kernel_file;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp6_, &_inner_error_);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3070 "unattended-installer.c"
				goto __catch83_g_error;
			}
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->kernel_file);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->kernel_file = NULL;
#line 3077 "unattended-installer.c"
		}
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = self->initrd_file;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp7_ != NULL) {
#line 3083 "unattended-installer.c"
			GFile* _tmp8_ = NULL;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp8_ = self->initrd_file;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_delete_file (_tmp8_, &_inner_error_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3091 "unattended-installer.c"
				goto __catch83_g_error;
			}
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (self->initrd_file);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->initrd_file = NULL;
#line 3098 "unattended-installer.c"
		}
	}
	goto __finally83;
	__catch83_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_error_ = _inner_error_;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_inner_error_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp9_ = _error_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp10_ = _tmp9_->message;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:322: Failed to clean-up: %s", _tmp10_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_error_);
#line 3119 "unattended-installer.c"
	}
	__finally83:
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_clear_error (&_inner_error_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 3130 "unattended-installer.c"
	}
}


static void boxes_unattended_installer_real_clean_up_preparation_cache (BoxesInstallerMedia* base) {
	BoxesUnattendedInstaller * self;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->clean_up_preparation_cache (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->unattended_files);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->unattended_files = NULL;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->secondary_unattended_files);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->secondary_unattended_files = NULL;
#line 3149 "unattended-installer.c"
}


gchar* boxes_unattended_installer_get_user_unattended (BoxesUnattendedInstaller* self, const gchar* suffix) {
	gchar* result = NULL;
	gchar* filename = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->hostname;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	filename = _tmp1_;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = suffix;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp2_ != NULL) {
#line 3173 "unattended-installer.c"
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = filename;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = suffix;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = g_strconcat ("-", _tmp4_, NULL);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = _tmp5_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = g_strconcat (_tmp3_, _tmp6_, NULL);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (filename);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		filename = _tmp7_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp6_);
#line 3195 "unattended-installer.c"
	}
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = filename;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = boxes_get_user_pkgcache (_tmp8_);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp9_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (filename);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3207 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare_data_free (gpointer _data) {
	BoxesUnattendedInstallerPrepareData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerPrepareData, _data_);
#line 3222 "unattended-installer.c"
}


static void boxes_unattended_installer_real_prepare (BoxesInstallerMedia* base, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstaller * self;
	BoxesUnattendedInstallerPrepareData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesActivityProgress* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerPrepareData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_real_prepare);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_real_prepare_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = progress;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_co (_data_);
#line 3264 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_prepare_finish (BoxesInstallerMedia* base, GAsyncResult* _res_) {
	gboolean result;
	BoxesUnattendedInstallerPrepareData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3277 "unattended-installer.c"
}


static void boxes_unattended_installer_prepare_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerPrepareData* _data_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_real_prepare_co (_data_);
#line 3291 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_prepare_co (BoxesUnattendedInstallerPrepareData* _data_) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 3300 "unattended-installer.c"
		goto _state_0;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 3304 "unattended-installer.c"
		goto _state_1;
		default:
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 3309 "unattended-installer.c"
	}
	_state_0:
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->progress;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = _data_->cancellable;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 1;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers (_data_->self, _data_->_tmp0_, _data_->_tmp1_, boxes_unattended_installer_prepare_ready, _data_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 3326 "unattended-installer.c"
	_state_1:
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = FALSE;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = boxes_unattended_installer_setup_drivers_finish (_data_->self, _data_->_res_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->result = _data_->_tmp2_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3338 "unattended-installer.c"
	} else {
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3342 "unattended-installer.c"
	}
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3352 "unattended-installer.c"
	} else {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3356 "unattended-installer.c"
	}
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 3362 "unattended-installer.c"
}


static GVirConfigDomainDisk* boxes_unattended_installer_get_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format) {
	GVirConfigDomainDisk* result = NULL;
	GVirConfigDomainDisk* disk = NULL;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GVirConfigDomainDisk* _tmp2_ = NULL;
	GVirConfigDomainDisk* _tmp3_ = NULL;
	GVirConfigDomainDisk* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	OsinfoInstallScriptInjectionMethod _tmp8_ = 0;
	OsinfoInstallScriptInjectionMethod _tmp9_ = 0;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = gvir_config_domain_disk_new ();
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk = _tmp0_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = disk;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_type (_tmp1_, GVIR_CONFIG_DOMAIN_DISK_FILE);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = disk;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_name (_tmp2_, "qemu");
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = disk;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_format (_tmp3_, GVIR_CONFIG_DOMAIN_DISK_FORMAT_RAW);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = disk;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->disk_file;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = g_file_get_path (_tmp5_);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _tmp6_;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_source (_tmp4_, _tmp7_);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp7_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp8_ = boxes_unattended_installer_get_injection_method (self);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = _tmp8_;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp9_ == OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_FLOPPY) {
#line 3415 "unattended-installer.c"
		const gchar* _tmp10_ = NULL;
		OsinfoPathFormat _tmp11_ = 0;
		GVirConfigDomainDisk* _tmp12_ = NULL;
		GVirConfigDomainDisk* _tmp13_ = NULL;
		GVirConfigDomainDisk* _tmp14_ = NULL;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = path_format;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp11_ == OSINFO_PATH_FORMAT_DOS) {
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp10_ = "A";
#line 3427 "unattended-installer.c"
		} else {
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp10_ = "fd0";
#line 3431 "unattended-installer.c"
		}
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp12_ = disk;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_target_dev (_tmp12_, _tmp10_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp13_ = disk;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_guest_device_type (_tmp13_, GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_FLOPPY);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp14_ = disk;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_target_bus (_tmp14_, GVIR_CONFIG_DOMAIN_DISK_BUS_FDC);
#line 3445 "unattended-installer.c"
	} else {
		gboolean _tmp15_ = FALSE;
		gboolean _tmp16_ = FALSE;
		GVirConfigDomainDisk* _tmp23_ = NULL;
		GVirConfigDomainDisk* _tmp24_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp15_ = boxes_installer_media_get_supports_virtio_disk ((BoxesInstallerMedia*) self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp16_ = _tmp15_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp16_) {
#line 3457 "unattended-installer.c"
			const gchar* _tmp17_ = NULL;
			OsinfoPathFormat _tmp18_ = 0;
			GVirConfigDomainDisk* _tmp19_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp18_ = path_format;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_tmp18_ == OSINFO_PATH_FORMAT_UNIX) {
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp17_ = "sda";
#line 3467 "unattended-installer.c"
			} else {
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp17_ = "E";
#line 3471 "unattended-installer.c"
			}
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp19_ = disk;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			gvir_config_domain_disk_set_target_dev (_tmp19_, _tmp17_);
#line 3477 "unattended-installer.c"
		} else {
			const gchar* _tmp20_ = NULL;
			OsinfoPathFormat _tmp21_ = 0;
			GVirConfigDomainDisk* _tmp22_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp21_ = path_format;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_tmp21_ == OSINFO_PATH_FORMAT_UNIX) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp20_ = "sdb";
#line 3488 "unattended-installer.c"
			} else {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp20_ = "E";
#line 3492 "unattended-installer.c"
			}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp22_ = disk;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			gvir_config_domain_disk_set_target_dev (_tmp22_, _tmp20_);
#line 3498 "unattended-installer.c"
		}
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp23_ = disk;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_guest_device_type (_tmp23_, GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_DISK);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp24_ = disk;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		gvir_config_domain_disk_set_target_bus (_tmp24_, GVIR_CONFIG_DOMAIN_DISK_BUS_USB);
#line 3508 "unattended-installer.c"
	}
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = disk;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3514 "unattended-installer.c"
}


static GVirConfigDomainDisk* boxes_unattended_installer_get_secondary_unattended_disk_config (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format) {
	GVirConfigDomainDisk* result = NULL;
	GVirConfigDomainDisk* disk = NULL;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GVirConfigDomainDisk* _tmp2_ = NULL;
	GVirConfigDomainDisk* _tmp3_ = NULL;
	GVirConfigDomainDisk* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	OsinfoPathFormat _tmp9_ = 0;
	GVirConfigDomainDisk* _tmp10_ = NULL;
	GVirConfigDomainDisk* _tmp11_ = NULL;
	GVirConfigDomainDisk* _tmp12_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = gvir_config_domain_disk_new ();
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	disk = _tmp0_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = disk;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_type (_tmp1_, GVIR_CONFIG_DOMAIN_DISK_FILE);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = disk;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_name (_tmp2_, "qemu");
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = disk;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_driver_format (_tmp3_, GVIR_CONFIG_DOMAIN_DISK_FORMAT_RAW);
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = disk;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = self->secondary_disk_file;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = g_file_get_path (_tmp5_);
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _tmp6_;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_source (_tmp4_, _tmp7_);
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_tmp7_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp9_ = path_format;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp9_ == OSINFO_PATH_FORMAT_DOS) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = "E";
#line 3570 "unattended-installer.c"
	} else {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp8_ = "hdd";
#line 3574 "unattended-installer.c"
	}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = disk;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_target_dev (_tmp10_, _tmp8_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = disk;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_guest_device_type (_tmp11_, GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = disk;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_disk_set_target_bus (_tmp12_, GVIR_CONFIG_DOMAIN_DISK_BUS_IDE);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = disk;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3592 "unattended-installer.c"
}


static gchar* boxes_unattended_installer_device_name_to_path (BoxesUnattendedInstaller* self, OsinfoPathFormat path_format, const gchar* name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	OsinfoPathFormat _tmp1_ = 0;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = path_format;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp1_ == OSINFO_PATH_FORMAT_UNIX) {
#line 3608 "unattended-installer.c"
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp2_ = name;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = g_strconcat ("/dev/", _tmp2_, NULL);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp0_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp3_;
#line 3619 "unattended-installer.c"
	} else {
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = name;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = g_strdup (_tmp4_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_tmp0_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = _tmp5_;
#line 3631 "unattended-installer.c"
	}
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp0_;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 3637 "unattended-installer.c"
}


static void boxes_unattended_installer_add_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file) {
	BoxesUnattendedFile* _tmp0_ = NULL;
	BoxesUnattendedFile* _tmp1_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (file != NULL);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = file;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->unattended_files = g_list_append (self->priv->unattended_files, _tmp1_);
#line 3654 "unattended-installer.c"
}


static void boxes_unattended_installer_add_secondary_unattended_file (BoxesUnattendedInstaller* self, BoxesUnattendedFile* file) {
	BoxesUnattendedFile* _tmp0_ = NULL;
	BoxesUnattendedFile* _tmp1_ = NULL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (file != NULL);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = file;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->secondary_unattended_files = g_list_append (self->priv->secondary_unattended_files, _tmp1_);
#line 3671 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image_data_free (gpointer _data) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerCreateDiskImageData, _data_);
#line 3684 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image (BoxesUnattendedInstaller* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerCreateDiskImageData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_create_disk_image);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_create_disk_image_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_create_disk_image_co (_data_);
#line 3713 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 3723 "unattended-installer.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3727 "unattended-installer.c"
}


static void boxes_unattended_installer_create_disk_image_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerCreateDiskImageData* _data_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_create_disk_image_co (_data_);
#line 3741 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_create_disk_image_co (BoxesUnattendedInstallerCreateDiskImageData* _data_) {
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 3750 "unattended-installer.c"
		goto _state_0;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 3754 "unattended-installer.c"
		goto _state_1;
		default:
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 3759 "unattended-installer.c"
	}
	_state_0:
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = boxes_get_unattended ("disk.img");
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->template_path = _data_->_tmp0_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = g_file_new_for_path (_data_->template_path);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->template_file = _data_->_tmp1_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = _data_->self->disk_file;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = g_file_get_path (_data_->_tmp2_);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_debug ("unattended-installer.vala:399: Creating disk image for unattended inst" \
"allation at '%s'..", _data_->_tmp4_);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp4_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = _data_->self->disk_file;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = _data_->cancellable;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 1;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_file_copy_async (_data_->template_file, _data_->_tmp5_, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, _data_->_tmp6_, NULL, NULL, boxes_unattended_installer_create_disk_image_ready, _data_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 3804 "unattended-installer.c"
	_state_1:
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_file_copy_finish (_data_->template_file, _data_->_res_, &_data_->_inner_error_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->template_file);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->template_path);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3822 "unattended-installer.c"
		} else {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3826 "unattended-installer.c"
		}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 3832 "unattended-installer.c"
	}
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = NULL;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = _data_->self->disk_file;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = NULL;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = g_file_get_path (_data_->_tmp7_);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = NULL;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_debug ("unattended-installer.vala:401: Floppy image for unattended installatio" \
"n created at '%s'", _data_->_tmp9_);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp9_);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->template_file);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->template_path);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3858 "unattended-installer.c"
	} else {
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3862 "unattended-installer.c"
	}
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 3868 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar_data_free (gpointer _data) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerFetchUserAvatarData, _data_);
#line 3879 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar (BoxesUnattendedInstaller* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerFetchUserAvatarData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_fetch_user_avatar);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_fetch_user_avatar_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_fetch_user_avatar_co (_data_);
#line 3898 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3906 "unattended-installer.c"
}


static void boxes_unattended_installer_fetch_user_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerFetchUserAvatarData* _data_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_fetch_user_avatar_co (_data_);
#line 3920 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_fetch_user_avatar_co (BoxesUnattendedInstallerFetchUserAvatarData* _data_) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 3929 "unattended-installer.c"
		goto _state_0;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 3933 "unattended-installer.c"
		goto _state_1;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 3937 "unattended-installer.c"
		goto _state_2;
		default:
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 3942 "unattended-installer.c"
	}
	_state_0:
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = boxes_unattended_installer_accounts;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp0_ == NULL) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3955 "unattended-installer.c"
		} else {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3959 "unattended-installer.c"
		}
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 3965 "unattended-installer.c"
	}
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = g_get_user_name ();
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = g_strdup (_data_->_tmp1_);
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->username = _data_->_tmp2_;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->username;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = g_strconcat ("/var/lib/AccountsService/icons/", _data_->_tmp3_, NULL);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->avatar_path = _data_->_tmp4_;
#line 3987 "unattended-installer.c"
	{
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = boxes_unattended_installer_accounts;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp6_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp6_ = g_get_user_name ();
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 1;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_fdo_accounts_FindUserByName (_data_->_tmp5_, _data_->_tmp6_, boxes_unattended_installer_fetch_user_avatar_ready, _data_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4003 "unattended-installer.c"
		_state_1:
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp7_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp7_ = boxes_fdo_accounts_FindUserByName_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->path = _data_->_tmp7_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_inner_error_->domain == G_IO_ERROR) {
#line 4015 "unattended-installer.c"
				goto __catch84_g_io_error;
			}
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->avatar_path);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->username);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_clear_error (&_data_->_inner_error_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 4028 "unattended-installer.c"
		}
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = _data_->path;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 2;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_async_initable_new_async (BOXES_FDO_TYPE_ACCOUNTS_USER_PROXY, 0, NULL, boxes_unattended_installer_fetch_user_avatar_ready, _data_, "g-flags", 0, "g-name", "org.freedesktop.Accounts", "g-bus-type", G_BUS_TYPE_SYSTEM, "g-object-path", _data_->_tmp8_, "g-interface-name", "org.freedesktop.Accounts.User", "g-interface-info", g_type_get_qdata (BOXES_FDO_TYPE_ACCOUNTS_USER, g_quark_from_static_string ("vala-dbus-interface-info")), NULL);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4040 "unattended-installer.c"
		_state_2:
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = g_async_initable_new_finish (_data_->_source_object_, _data_->_res_, &_data_->_inner_error_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->user = (BoxesFdoAccountsUser*) _data_->_tmp9_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->path);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_inner_error_->domain == G_IO_ERROR) {
#line 4054 "unattended-installer.c"
				goto __catch84_g_io_error;
			}
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->path);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->avatar_path);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_free0 (_data_->username);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_clear_error (&_data_->_inner_error_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 4069 "unattended-installer.c"
		}
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = NULL;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = _data_->user;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = NULL;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = boxes_fdo_accounts_user_get_IconFile (_data_->_tmp10_);
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = NULL;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->avatar_path);
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->avatar_path = _data_->_tmp12_;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->user);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->path);
#line 4091 "unattended-installer.c"
	}
	goto __finally84;
	__catch84_g_io_error:
	{
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_inner_error_ = NULL;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = NULL;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = _data_->username;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = NULL;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = _data_->_error_;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = NULL;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = _data_->_tmp14_->message;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_warning ("unattended-installer.vala:416: Failed to retrieve information about us" \
"er '%s': %s", _data_->_tmp13_, _data_->_tmp15_);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_data_->_error_);
#line 4116 "unattended-installer.c"
	}
	__finally84:
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->avatar_path);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->username);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_clear_error (&_data_->_inner_error_);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4131 "unattended-installer.c"
	}
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp16_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp16_ = _data_->avatar_path;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = FALSE;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = g_file_test (_data_->_tmp16_, G_FILE_TEST_EXISTS);
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_data_->_tmp17_) {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->avatar_path);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->username);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4151 "unattended-installer.c"
		} else {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4155 "unattended-installer.c"
		}
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4161 "unattended-installer.c"
	}
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = NULL;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = _data_->self->setup_box;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = NULL;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = _data_->avatar_path;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_setup_box_set_avatar_path (_data_->_tmp18_, _data_->_tmp19_);
#line 4173 "unattended-installer.c"
	{
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->avatar_format = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = _data_->self->scripts;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp21_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp21_ = osinfo_list_get_elements ((OsinfoList*) _data_->_tmp20_);
#line 4185 "unattended-installer.c"
		{
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->s_collection = _data_->_tmp21_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			for (_data_->s_it = _data_->s_collection; _data_->s_it != NULL; _data_->s_it = _data_->s_it->next) {
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->s = (OsinfoEntity*) _data_->s_it->data;
#line 4193 "unattended-installer.c"
				{
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = NULL;
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp22_ = _data_->s;
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp23_ = NULL;
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp22_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _data_->_tmp22_) : NULL);
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->script = _data_->_tmp23_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp24_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp24_ = _data_->script;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp25_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp25_ = osinfo_install_script_get_avatar_format (_data_->_tmp24_);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp26_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp26_ = _data_->_tmp25_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp27_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp27_ = _g_object_ref0 (_data_->_tmp26_);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->avatar_format);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->avatar_format = _data_->_tmp27_;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp28_ = NULL;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp28_ = _data_->avatar_format;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_data_->_tmp28_ != NULL) {
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (_data_->script);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 4235 "unattended-installer.c"
					}
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->script);
#line 4239 "unattended-installer.c"
				}
			}
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_list_free0 (_data_->s_collection);
#line 4244 "unattended-installer.c"
		}
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = _data_->avatar_path;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = _data_->avatar_format;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp32_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp32_ = boxes_unattended_avatar_file_new (_data_->self, _data_->_tmp30_, _data_->_tmp31_, &_data_->_inner_error_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp29_ = _data_->_tmp32_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_data_->avatar_format);
#line 4264 "unattended-installer.c"
			goto __catch85_g_error;
		}
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp33_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp33_ = _data_->_tmp29_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp29_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->self->priv->avatar_file);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->self->priv->avatar_file = _data_->_tmp33_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp34_ = NULL;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp34_ = _data_->self->priv->avatar_file;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_add_unattended_file (_data_->self, (BoxesUnattendedFile*) _data_->_tmp34_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->_tmp29_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->avatar_format);
#line 4287 "unattended-installer.c"
	}
	goto __finally85;
	__catch85_g_error:
	{
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_inner_error_ = NULL;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp35_ = NULL;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp35_ = _data_->avatar_path;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp36_ = NULL;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp36_ = _data_->_vala1__error_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp37_ = NULL;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp37_ = _data_->_tmp36_->message;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:436: Failed to load user avatar file '%s': %" \
"s", _data_->_tmp35_, _data_->_tmp37_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 4312 "unattended-installer.c"
	}
	__finally85:
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->avatar_path);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_free0 (_data_->username);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_clear_error (&_data_->_inner_error_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4327 "unattended-installer.c"
	}
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->avatar_path);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->username);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4337 "unattended-installer.c"
	} else {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4341 "unattended-installer.c"
	}
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 4347 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files_data_free (gpointer _data) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->extractor);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerExtractBootFilesData, _data_);
#line 4362 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files (BoxesUnattendedInstaller* self, BoxesISOExtractor* extractor, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesISOExtractor* _tmp1_ = NULL;
	BoxesISOExtractor* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerExtractBootFilesData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_extract_boot_files);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_extract_boot_files_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = extractor;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->extractor);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->extractor = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_extract_boot_files_co (_data_);
#line 4401 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 4411 "unattended-installer.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4415 "unattended-installer.c"
}


static void boxes_unattended_installer_extract_boot_files_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerExtractBootFilesData* _data_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_extract_boot_files_co (_data_);
#line 4429 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_extract_boot_files_co (BoxesUnattendedInstallerExtractBootFilesData* _data_) {
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 4438 "unattended-installer.c"
		goto _state_0;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 4442 "unattended-installer.c"
		goto _state_1;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 4446 "unattended-installer.c"
		goto _state_2;
		default:
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 4451 "unattended-installer.c"
	}
	_state_0:
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->extractor;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_data_->_tmp1_, "kernel-path", &_data_->_tmp2_, NULL);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = _data_->self->kernel_file;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = g_file_get_path (_data_->_tmp5_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = _data_->cancellable;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 1;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_iso_extractor_extract (_data_->_tmp0_, _data_->_tmp4_, _data_->_tmp7_, _data_->_tmp8_, boxes_unattended_installer_extract_boot_files_ready, _data_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 4496 "unattended-installer.c"
	_state_1:
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_iso_extractor_extract_finish (_data_->_tmp0_, _data_->_res_, &_data_->_inner_error_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp7_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp4_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4514 "unattended-installer.c"
		} else {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4518 "unattended-installer.c"
		}
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4524 "unattended-installer.c"
	}
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = _data_->extractor;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = ((BoxesInstallerMedia*) _data_->self)->os_media;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp11_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_get (_data_->_tmp10_, "initrd-path", &_data_->_tmp11_, NULL);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp12_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp13_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp14_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp14_ = _data_->self->initrd_file;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp15_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp15_ = g_file_get_path (_data_->_tmp14_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp16_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = _data_->cancellable;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_state_ = 2;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_iso_extractor_extract (_data_->_tmp9_, _data_->_tmp13_, _data_->_tmp16_, _data_->_tmp17_, boxes_unattended_installer_extract_boot_files_ready, _data_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 4568 "unattended-installer.c"
	_state_2:
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_iso_extractor_extract_finish (_data_->_tmp9_, _data_->_res_, &_data_->_inner_error_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp16_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->_tmp13_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_error_free (_data_->_inner_error_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4586 "unattended-installer.c"
		} else {
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4590 "unattended-installer.c"
		}
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4596 "unattended-installer.c"
	}
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4602 "unattended-installer.c"
	} else {
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4606 "unattended-installer.c"
	}
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 4612 "unattended-installer.c"
}


static gchar* boxes_unattended_installer_get_product_key_format (BoxesUnattendedInstaller* self) {
	gchar* result = NULL;
	OsinfoInstallScriptList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->scripts;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_list_get_elements ((OsinfoList*) _tmp0_);
#line 4626 "unattended-installer.c"
	{
		GList* s_collection = NULL;
		GList* s_it = NULL;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		s_collection = _tmp1_;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 4634 "unattended-installer.c"
			OsinfoEntity* s = NULL;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s = (OsinfoEntity*) s_it->data;
#line 4638 "unattended-installer.c"
			{
				OsinfoInstallScript* script = NULL;
				OsinfoEntity* _tmp2_ = NULL;
				OsinfoInstallScript* _tmp3_ = NULL;
				OsinfoInstallConfigParam* param = NULL;
				OsinfoInstallScript* _tmp4_ = NULL;
				OsinfoInstallConfigParam* _tmp5_ = NULL;
				gboolean _tmp6_ = FALSE;
				OsinfoInstallConfigParam* _tmp7_ = NULL;
				gchar* format = NULL;
				OsinfoInstallScript* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = s;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp2_) : NULL);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				script = _tmp3_;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = script;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = osinfo_install_script_get_config_param (_tmp4_, OSINFO_INSTALL_CONFIG_PROP_REG_PRODUCTKEY);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				param = _tmp5_;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp7_ = param;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp7_ == NULL) {
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp6_ = TRUE;
#line 4671 "unattended-installer.c"
				} else {
					OsinfoInstallConfigParam* _tmp8_ = NULL;
					gboolean _tmp9_ = FALSE;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp8_ = param;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp9_ = osinfo_install_config_param_is_optional (_tmp8_);
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp6_ = _tmp9_;
#line 4681 "unattended-installer.c"
				}
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp6_) {
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (param);
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					continue;
#line 4691 "unattended-installer.c"
				}
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp10_ = script;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp11_ = osinfo_install_script_get_product_key_format (_tmp10_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp12_ = g_strdup (_tmp11_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				format = _tmp12_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp13_ = format;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp13_ != NULL) {
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					result = format;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (param);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_list_free0 (s_collection);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return result;
#line 4715 "unattended-installer.c"
				}
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (format);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (param);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 4723 "unattended-installer.c"
			}
		}
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (s_collection);
#line 4728 "unattended-installer.c"
	}
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = NULL;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 4734 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_data_free (gpointer _data) {
	BoxesUnattendedInstallerSetupDriversData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerSetupDriversData, _data_);
#line 4749 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers (BoxesUnattendedInstaller* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesActivityProgress* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerSetupDriversData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_setup_drivers);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_setup_drivers_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = progress;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_co (_data_);
#line 4788 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_drivers_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesUnattendedInstallerSetupDriversData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 4801 "unattended-installer.c"
}


static void _boxes_unattended_installer_add_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self) {
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_add_unattended_file ((BoxesUnattendedInstaller*) self, file);
#line 4808 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversData* _data_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_co (_data_);
#line 4822 "unattended-installer.c"
}


static void _boxes_unattended_installer_add_secondary_unattended_file_boxes_unattended_installer_add_unattended_file_func (BoxesUnattendedFile* file, gpointer self) {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_add_secondary_unattended_file ((BoxesUnattendedInstaller*) self, file);
#line 4829 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_drivers_co (BoxesUnattendedInstallerSetupDriversData* _data_) {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 4838 "unattended-installer.c"
		goto _state_0;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 4842 "unattended-installer.c"
		goto _state_1;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 2:
#line 4846 "unattended-installer.c"
		goto _state_2;
		default:
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 4851 "unattended-installer.c"
	}
	_state_0:
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->progress;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = _ ("Downloading device drivers…");
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_activity_progress_set_info (_data_->_tmp0_, _data_->_tmp1_);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = boxes_unattended_installer_get_pre_installer_scripts (_data_->self);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->scripts = _data_->_tmp2_;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = _data_->scripts;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = boxes_unattended_installer_get_pre_installable_drivers (_data_->self, _data_->_tmp3_);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->drivers = _data_->_tmp4_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = _data_->drivers;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = 0U;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = g_list_length (_data_->_tmp6_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp7_ != ((guint) 0)) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = NULL;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp8_ = _data_->scripts;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = 0U;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp9_ = g_list_length (_data_->_tmp8_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = _data_->_tmp9_ != ((guint) 0);
#line 4900 "unattended-installer.c"
	} else {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp5_ = FALSE;
#line 4904 "unattended-installer.c"
	}
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp5_) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp10_ = _data_->progress;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp11_ = boxes_activity_progress_add_child_activity (_data_->_tmp10_, 0.5);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->drivers_progress = _data_->_tmp11_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp12_ = _data_->drivers;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp13_ = _data_->drivers_progress;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp14_ = _data_->cancellable;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 1;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_setup_drivers_from_list (_data_->self, _data_->_tmp12_, _data_->_tmp13_, _boxes_unattended_installer_add_unattended_file_boxes_unattended_installer_add_unattended_file_func, _data_->self, _data_->_tmp14_, boxes_unattended_installer_setup_drivers_ready, _data_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 4936 "unattended-installer.c"
		_state_1:
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = FALSE;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp15_ = boxes_unattended_installer_setup_drivers_from_list_finish (_data_->self, _data_->_res_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (!_data_->_tmp15_) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->result = FALSE;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_data_->drivers_progress);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			__g_list_free__g_object_unref0_0 (_data_->drivers);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			__g_list_free__g_object_unref0_0 (_data_->scripts);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (_data_->_state_ == 0) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4956 "unattended-installer.c"
			} else {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4960 "unattended-installer.c"
			}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_object_unref (_data_->_async_result);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return FALSE;
#line 4966 "unattended-installer.c"
		}
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->drivers_progress);
#line 4970 "unattended-installer.c"
	} else {
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp16_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp16_ = _data_->progress;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_activity_progress_set_progress (_data_->_tmp16_, 0.5);
#line 4978 "unattended-installer.c"
	}
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp17_ = boxes_unattended_installer_get_post_installer_scripts (_data_->self);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->scripts);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->scripts = _data_->_tmp17_;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = NULL;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp18_ = _data_->scripts;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = NULL;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp19_ = boxes_unattended_installer_get_post_installable_drivers (_data_->self, _data_->_tmp18_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->drivers);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->drivers = _data_->_tmp19_;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp21_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp21_ = _data_->drivers;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp22_ = 0U;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp22_ = g_list_length (_data_->_tmp21_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp22_ != ((guint) 0)) {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp23_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp23_ = _data_->scripts;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp24_ = 0U;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp24_ = g_list_length (_data_->_tmp23_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = _data_->_tmp24_ != ((guint) 0);
#line 5020 "unattended-installer.c"
	} else {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp20_ = FALSE;
#line 5024 "unattended-installer.c"
	}
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_tmp20_) {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp25_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp25_ = _data_->progress;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp26_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp26_ = boxes_activity_progress_add_child_activity (_data_->_tmp25_, 0.5);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_vala1_drivers_progress = _data_->_tmp26_;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp27_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp27_ = _data_->drivers;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp28_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp28_ = _data_->_vala1_drivers_progress;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp29_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp29_ = _data_->cancellable;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_state_ = 2;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_unattended_installer_setup_drivers_from_list (_data_->self, _data_->_tmp27_, _data_->_tmp28_, _boxes_unattended_installer_add_secondary_unattended_file_boxes_unattended_installer_add_unattended_file_func, _data_->self, _data_->_tmp29_, boxes_unattended_installer_setup_drivers_ready, _data_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5056 "unattended-installer.c"
		_state_2:
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = FALSE;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp30_ = boxes_unattended_installer_setup_drivers_from_list_finish (_data_->self, _data_->_res_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->result = _data_->_tmp30_;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (_data_->_vala1_drivers_progress);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		__g_list_free__g_object_unref0_0 (_data_->drivers);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		__g_list_free__g_object_unref0_0 (_data_->scripts);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_data_->_state_ == 0) {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5074 "unattended-installer.c"
		} else {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5078 "unattended-installer.c"
		}
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_object_unref (_data_->_async_result);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return FALSE;
#line 5084 "unattended-installer.c"
	} else {
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->_tmp31_ = _data_->progress;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		boxes_activity_progress_set_progress (_data_->_tmp31_, 1.0);
#line 5092 "unattended-installer.c"
	}
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->result = TRUE;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->drivers);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->scripts);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5104 "unattended-installer.c"
	} else {
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5108 "unattended-installer.c"
	}
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->drivers);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->scripts);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5122 "unattended-installer.c"
	} else {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5126 "unattended-installer.c"
	}
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5132 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_from_list_data_free (gpointer _data) {
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerSetupDriversFromListData, _data_);
#line 5147 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_from_list (BoxesUnattendedInstaller* self, GList* drivers, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	BoxesActivityProgress* _tmp3_ = NULL;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp4_ = NULL;
	void* _tmp4__target = NULL;
	GCancellable* _tmp5_ = NULL;
	GCancellable* _tmp6_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerSetupDriversFromListData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_setup_drivers_from_list);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_setup_drivers_from_list_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = drivers;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->drivers = _tmp1_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = progress;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp3_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = add_func;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4__target = add_func_target;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func_target = _tmp4__target;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp6_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_from_list_co (_data_);
#line 5201 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_drivers_from_list_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 5214 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_drivers_from_list_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriversFromListData* _data_;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_drivers_from_list_co (_data_);
#line 5228 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_drivers_from_list_co (BoxesUnattendedInstallerSetupDriversFromListData* _data_) {
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 5237 "unattended-installer.c"
		goto _state_0;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 5241 "unattended-installer.c"
		goto _state_1;
		default:
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 5246 "unattended-installer.c"
	}
	_state_0:
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = _data_->drivers;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = 0U;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = g_list_length (_data_->_tmp0_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->driver_progress_scale = 1. / _data_->_tmp1_;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = _data_->drivers;
#line 5263 "unattended-installer.c"
	{
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->driver_collection = _data_->_tmp2_;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (_data_->driver_it = _data_->driver_collection; _data_->driver_it != NULL; _data_->driver_it = _data_->driver_it->next) {
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp3_ = NULL;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp3_ = _g_object_ref0 ((OsinfoDeviceDriver*) _data_->driver_it->data);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->driver = _data_->_tmp3_;
#line 5275 "unattended-installer.c"
			{
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp4_ = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp4_ = _data_->progress;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp5_ = 0.0;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp5_ = _data_->driver_progress_scale;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp6_ = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp6_ = boxes_activity_progress_add_child_activity (_data_->_tmp4_, _data_->_tmp5_);
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->driver_progress = _data_->_tmp6_;
#line 5291 "unattended-installer.c"
				{
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp7_ = NULL;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp7_ = _data_->driver;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp8_ = NULL;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp8_ = _data_->driver_progress;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9_ = NULL;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9__target = NULL;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9_ = _data_->add_func;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp9__target = _data_->add_func_target;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp10_ = NULL;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp10_ = _data_->cancellable;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_state_ = 1;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_installer_setup_driver (_data_->self, _data_->_tmp7_, _data_->_tmp8_, _data_->_tmp9_, _data_->_tmp9__target, _data_->_tmp10_, boxes_unattended_installer_setup_drivers_from_list_ready, _data_);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 5319 "unattended-installer.c"
					_state_1:
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_unattended_installer_setup_driver_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 5327 "unattended-installer.c"
							goto __catch86_g_io_error_cancelled;
						}
						goto __catch86_g_error;
					}
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp11_ = NULL;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp11_ = _data_->self->priv->additional_devices;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp12_ = NULL;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp12_ = _data_->driver;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp13_ = NULL;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp13_ = osinfo_device_driver_get_devices (_data_->_tmp12_);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					osinfo_list_add_all ((OsinfoList*) _data_->_tmp11_, (OsinfoList*) _data_->_tmp13_);
#line 5346 "unattended-installer.c"
				}
				goto __finally86;
				__catch86_g_io_error_cancelled:
				{
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->e = _data_->_inner_error_;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_inner_error_ = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_debug ("unattended-installer.vala:501: Media preparation cancelled during driv" \
"er setup.");
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->result = FALSE;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_error_free0 (_data_->e);
#line 5361 "unattended-installer.c"
					{
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp14_ = NULL;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data_->_tmp14_ = _data_->driver_progress;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						boxes_activity_progress_set_progress (_data_->_tmp14_, 1.0);
#line 5369 "unattended-installer.c"
					}
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->driver_progress);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->driver);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_data_->_state_ == 0) {
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5379 "unattended-installer.c"
					} else {
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_simple_async_result_complete (_data_->_async_result);
#line 5383 "unattended-installer.c"
					}
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_object_unref (_data_->_async_result);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 5389 "unattended-installer.c"
				}
				goto __finally86;
				__catch86_g_error:
				{
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_vala1_e = _data_->_inner_error_;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_inner_error_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp15_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp15_ = _data_->driver;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp16_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp16_ = osinfo_device_driver_get_location (_data_->_tmp15_);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp17_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp17_ = _data_->_vala1_e;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp18_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp18_ = _data_->_tmp17_->message;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_debug ("unattended-installer.vala:505: Failed to make use of drivers at '%s': " \
"%s", _data_->_tmp16_, _data_->_tmp18_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_error_free0 (_data_->_vala1_e);
#line 5418 "unattended-installer.c"
				}
				__finally86:
				{
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp19_ = NULL;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp19_ = _data_->driver_progress;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					boxes_activity_progress_set_progress (_data_->_tmp19_, 1.0);
#line 5428 "unattended-installer.c"
				}
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->driver_progress);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->driver);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_clear_error (&_data_->_inner_error_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 5442 "unattended-installer.c"
				}
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->driver_progress);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->driver);
#line 5448 "unattended-installer.c"
			}
		}
	}
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->result = TRUE;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5458 "unattended-installer.c"
	} else {
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5462 "unattended-installer.c"
	}
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5472 "unattended-installer.c"
	} else {
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5476 "unattended-installer.c"
	}
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 5482 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver_data_free (gpointer _data) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->driver);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_slice_free (BoxesUnattendedInstallerSetupDriverData, _data_);
#line 5499 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver, BoxesActivityProgress* progress, BoxesUnattendedInstallerAddUnattendedFileFunc add_func, void* add_func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	OsinfoDeviceDriver* _tmp1_ = NULL;
	OsinfoDeviceDriver* _tmp2_ = NULL;
	BoxesActivityProgress* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
	BoxesUnattendedInstallerAddUnattendedFileFunc _tmp5_ = NULL;
	void* _tmp5__target = NULL;
	GCancellable* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_slice_new0 (BoxesUnattendedInstallerSetupDriverData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_installer_setup_driver);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_installer_setup_driver_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = driver;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->driver);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->driver = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = progress;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->progress = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = add_func;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5__target = add_func_target;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func = _tmp5_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->add_func_target = _tmp5__target;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->cancellable = _tmp7_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_driver_co (_data_);
#line 5558 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver_finish (BoxesUnattendedInstaller* self, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return;
#line 5568 "unattended-installer.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5572 "unattended-installer.c"
}


static void _vala_array_add10 (gchar*** array, int* length, int* size, gchar* value) {
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if ((*length) == (*size)) {
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 5583 "unattended-installer.c"
	}
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[(*length)++] = value;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[*length] = NULL;
#line 5589 "unattended-installer.c"
}


static void boxes_unattended_installer_setup_driver_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedInstallerSetupDriverData* _data_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_ = _user_data_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_source_object_ = source_object;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_res_ = _res_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_setup_driver_co (_data_);
#line 5603 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_setup_driver_co (BoxesUnattendedInstallerSetupDriverData* _data_) {
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (_data_->_state_) {
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 0:
#line 5612 "unattended-installer.c"
		goto _state_0;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case 1:
#line 5616 "unattended-installer.c"
		goto _state_1;
		default:
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_assert_not_reached ();
#line 5621 "unattended-installer.c"
	}
	_state_0:
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = NULL;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp0_ = boxes_downloader_get_instance ();
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->downloader = _data_->_tmp0_;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->driver_files = NULL;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = NULL;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp1_ = _data_->driver;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = NULL;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp2_ = osinfo_device_driver_get_location (_data_->_tmp1_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = NULL;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp3_ = g_strdup (_data_->_tmp2_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->location = _data_->_tmp3_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp4_ = _data_->location;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp5_ = g_compute_checksum_for_string (G_CHECKSUM_MD5, _data_->_tmp4_, (gsize) -1);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->location_checksum = _data_->_tmp5_;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = NULL;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp6_ = _data_->driver;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = NULL;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp7_ = osinfo_device_driver_get_files (_data_->_tmp6_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->files = _data_->_tmp7_;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = NULL;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp8_ = _data_->files;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = 0U;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp9_ = g_list_length (_data_->_tmp8_);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->file_progress_scale = 1. / _data_->_tmp9_;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = NULL;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp10_ = _data_->files;
#line 5680 "unattended-installer.c"
	{
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->filename_collection = _data_->_tmp10_;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (_data_->filename_it = _data_->filename_collection; _data_->filename_it != NULL; _data_->filename_it = _data_->filename_it->next) {
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->filename = (const gchar*) _data_->filename_it->data;
#line 5688 "unattended-installer.c"
			{
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp11_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp11_ = _data_->location;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp12_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp12_ = g_strconcat (_data_->_tmp11_, "/", NULL);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp13_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp13_ = _data_->_tmp12_;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp14_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp14_ = _data_->filename;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp15_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp15_ = g_strconcat (_data_->_tmp13_, _data_->_tmp14_, NULL);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp16_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp16_ = _data_->_tmp15_;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp13_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file_uri = _data_->_tmp16_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp17_ = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp17_ = _data_->file_uri;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp18_ = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp18_ = g_file_new_for_uri (_data_->_tmp17_);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file = _data_->_tmp18_;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp19_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp19_ = _data_->location_checksum;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp20_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp20_ = g_strconcat (_data_->_tmp19_, "-", NULL);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp21_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp21_ = _data_->_tmp20_;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp22_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp22_ = _data_->file;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp23_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp23_ = g_file_get_basename (_data_->_tmp22_);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp24_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp24_ = _data_->_tmp23_;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp25_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp25_ = g_strconcat (_data_->_tmp21_, _data_->_tmp24_, NULL);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp26_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp26_ = _data_->_tmp25_;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp24_);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp21_);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->driver_file_name = _data_->_tmp26_;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp27_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp27_ = _data_->driver_file_name;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp28_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp28_ = boxes_get_drivers_cache (_data_->_tmp27_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->cached_path = _data_->_tmp28_;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp29_ = NULL;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp29_ = _data_->driver_file_name;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp30_ = NULL;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp30_ = boxes_get_system_drivers_cache (_data_->_tmp29_);
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->system_cached_path = _data_->_tmp30_;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp31_ = NULL;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp31_ = _data_->cached_path;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp32_ = NULL;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp32_ = g_strdup (_data_->_tmp31_);
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp33_ = NULL;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp33_ = g_new0 (gchar*, 1 + 1);
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp33_[0] = _data_->_tmp32_;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->cached_paths_length1 = 0;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_cached_paths_size_ = 0;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->cached_paths = _data_->_tmp33_;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->cached_paths_length1 = 1;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_cached_paths_size_ = _data_->cached_paths_length1;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp34_ = NULL;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp34_ = _data_->system_cached_path;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_data_->_tmp34_ != NULL) {
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp35_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp35__length1 = 0;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp35_ = _data_->cached_paths;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp35__length1 = _data_->cached_paths_length1;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp36_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp36_ = _data_->system_cached_path;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp37_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->_tmp37_ = g_strdup (_data_->_tmp36_);
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_vala_array_add10 (&_data_->cached_paths, &_data_->cached_paths_length1, &_data_->_cached_paths_size_, _data_->_tmp37_);
#line 5834 "unattended-installer.c"
				}
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp38_ = NULL;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp38_ = _data_->progress;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp39_ = 0.0;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp39_ = _data_->file_progress_scale;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp40_ = NULL;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp40_ = boxes_activity_progress_add_child_activity (_data_->_tmp38_, _data_->_tmp39_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file_progress = _data_->_tmp40_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp42_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp42_ = _data_->downloader;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp43_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp43_ = _data_->file;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44__length1 = 0;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44_ = _data_->cached_paths;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp44__length1 = _data_->cached_paths_length1;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp45_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp45_ = _data_->file_progress;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp46_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp46_ = _data_->cancellable;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_state_ = 1;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				boxes_downloader_download (_data_->_tmp42_, _data_->_tmp43_, _data_->_tmp44_, _data_->_tmp44__length1, _data_->_tmp45_, _data_->_tmp46_, boxes_unattended_installer_setup_driver_ready, _data_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				return FALSE;
#line 5880 "unattended-installer.c"
				_state_1:
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp47_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp47_ = boxes_downloader_download_finish (_data_->_tmp42_, _data_->_res_, &_data_->_inner_error_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp41_ = _data_->_tmp47_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_error_free (_data_->_inner_error_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->file_progress);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->system_cached_path);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->cached_path);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->driver_file_name);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->file);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->file_uri);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_list_free0 (_data_->files);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->location_checksum);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_data_->location);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					__g_list_free__g_object_unref0_0 (_data_->driver_files);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (_data_->downloader);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_data_->_state_ == 0) {
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5922 "unattended-installer.c"
					} else {
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_simple_async_result_complete (_data_->_async_result);
#line 5926 "unattended-installer.c"
					}
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_object_unref (_data_->_async_result);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return FALSE;
#line 5932 "unattended-installer.c"
				}
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp48_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp48_ = _data_->_tmp41_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp41_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->file);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->file = _data_->_tmp48_;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp49_ = NULL;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp49_ = _data_->file_progress;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				boxes_activity_progress_set_progress (_data_->_tmp49_, 1.0);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp50_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp50_ = _data_->file;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp51_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp51_ = g_file_get_path (_data_->_tmp50_);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp52_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp52_ = _data_->_tmp51_;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp53_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp53_ = _data_->filename;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp54_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp54_ = boxes_unattended_raw_file_new (_data_->self, _data_->_tmp52_, _data_->_tmp53_);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->driver_files = g_list_append (_data_->driver_files, (BoxesUnattendedFile*) _data_->_tmp54_);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->_tmp52_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->_tmp41_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->file_progress);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->system_cached_path);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->cached_path);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->driver_file_name);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->file);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_data_->file_uri);
#line 5990 "unattended-installer.c"
			}
		}
	}
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp55_ = NULL;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data_->_tmp55_ = _data_->driver_files;
#line 5998 "unattended-installer.c"
	{
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_data_->driver_file_collection = _data_->_tmp55_;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (_data_->driver_file_it = _data_->driver_file_collection; _data_->driver_file_it != NULL; _data_->driver_file_it = _data_->driver_file_it->next) {
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp56_ = NULL;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->_tmp56_ = _g_object_ref0 ((BoxesUnattendedFile*) _data_->driver_file_it->data);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_data_->driver_file = _data_->_tmp56_;
#line 6010 "unattended-installer.c"
			{
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp57_ = NULL;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp57__target = NULL;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp57_ = _data_->add_func;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp57__target = _data_->add_func_target;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp58_ = NULL;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp58_ = _data_->driver_file;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_data_->_tmp57_ (_data_->_tmp58_, _data_->_tmp57__target);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (_data_->driver_file);
#line 6028 "unattended-installer.c"
			}
		}
	}
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_list_free0 (_data_->files);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->location_checksum);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (_data_->location);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (_data_->driver_files);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (_data_->downloader);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_data_->_state_ == 0) {
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6046 "unattended-installer.c"
	} else {
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6050 "unattended-installer.c"
	}
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_unref (_data_->_async_result);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 6056 "unattended-installer.c"
}


static gboolean __lambda137_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver) {
	gboolean result = FALSE;
	OsinfoDeviceDriver* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (driver != NULL, FALSE);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = driver;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_device_driver_get_pre_installable (_tmp0_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6074 "unattended-installer.c"
}


static gboolean ___lambda137__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self) {
	gboolean result;
	result = __lambda137_ ((BoxesUnattendedInstaller*) self, driver);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6083 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq __lambda138_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	OsinfoDeviceDriverSigningReq result = 0;
	OsinfoInstallScript* _tmp0_ = NULL;
	OsinfoDeviceDriverSigningReq _tmp1_ = 0;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, 0);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_pre_install_drivers_signing_req (_tmp0_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6101 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq ___lambda138__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self) {
	OsinfoDeviceDriverSigningReq result;
	result = __lambda138_ ((BoxesUnattendedInstaller*) self, script);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6110 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_pre_installable_drivers (BoxesUnattendedInstaller* self, GList* preinst_scripts) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = preinst_scripts;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_installer_get_installable_drivers (self, _tmp0_, ___lambda137__boxes_unattended_installer_driver_installable_func, self, ___lambda138__boxes_unattended_installer_script_driver_signing_req_func, self);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6128 "unattended-installer.c"
}


static gboolean __lambda147_ (BoxesUnattendedInstaller* self, OsinfoDeviceDriver* driver) {
	gboolean result = FALSE;
	OsinfoDeviceDriver* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (driver != NULL, FALSE);
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = driver;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_device_driver_get_pre_installable (_tmp0_);
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = !_tmp1_;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6146 "unattended-installer.c"
}


static gboolean ___lambda147__boxes_unattended_installer_driver_installable_func (OsinfoDeviceDriver* driver, gpointer self) {
	gboolean result;
	result = __lambda147_ ((BoxesUnattendedInstaller*) self, driver);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6155 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq __lambda148_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	OsinfoDeviceDriverSigningReq result = 0;
	OsinfoInstallScript* _tmp0_ = NULL;
	OsinfoDeviceDriverSigningReq _tmp1_ = 0;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, 0);
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_post_install_drivers_signing_req (_tmp0_);
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6173 "unattended-installer.c"
}


static OsinfoDeviceDriverSigningReq ___lambda148__boxes_unattended_installer_script_driver_signing_req_func (OsinfoInstallScript* script, gpointer self) {
	OsinfoDeviceDriverSigningReq result;
	result = __lambda148_ ((BoxesUnattendedInstaller*) self, script);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6182 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_post_installable_drivers (BoxesUnattendedInstaller* self, GList* postinst_scripts) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = postinst_scripts;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_installer_get_installable_drivers (self, _tmp0_, ___lambda147__boxes_unattended_installer_driver_installable_func, self, ___lambda148__boxes_unattended_installer_script_driver_signing_req_func, self);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6200 "unattended-installer.c"
}


static Block83Data* block83_data_ref (Block83Data* _data83_) {
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_atomic_int_inc (&_data83_->_ref_count_);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return _data83_;
#line 6209 "unattended-installer.c"
}


static void block83_data_unref (void * _userdata_) {
	Block83Data* _data83_;
	_data83_ = (Block83Data*) _userdata_;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (g_atomic_int_dec_and_test (&_data83_->_ref_count_)) {
#line 6218 "unattended-installer.c"
		BoxesUnattendedInstaller* self;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		self = _data83_->self;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (self);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_slice_free (Block83Data, _data83_);
#line 6226 "unattended-installer.c"
	}
}


static gboolean __lambda136_ (Block83Data* _data83_, OsinfoDeviceDriver* driver) {
	BoxesUnattendedInstaller* self;
	gboolean result = FALSE;
	BoxesUnattendedInstallerDriverInstallableFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	OsinfoDeviceDriver* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	OsinfoDeviceDriver* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = _data83_->self;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (driver != NULL, FALSE);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = _data83_->installable_func;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0__target = _data83_->installable_func_target;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = driver;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp0_ (_tmp1_, _tmp0__target);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_tmp2_) {
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = FALSE;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 6259 "unattended-installer.c"
	}
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = driver;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = osinfo_device_driver_get_signed (_tmp4_);
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (!_tmp5_) {
#line 6267 "unattended-installer.c"
		gboolean _tmp6_ = FALSE;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = _data83_->signing_required;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = _tmp6_;
#line 6273 "unattended-installer.c"
	} else {
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp3_ = FALSE;
#line 6277 "unattended-installer.c"
	}
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp3_) {
#line 6281 "unattended-installer.c"
		gboolean _tmp7_ = FALSE;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = _data83_->driver_signing_mutable;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp7_) {
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			self->priv->driver_signing = FALSE;
#line 6289 "unattended-installer.c"
		} else {
			OsinfoDeviceDriver* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp8_ = driver;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp9_ = osinfo_device_driver_get_location (_tmp8_);
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_debug ("unattended-installer.vala:602: Driver from location '%s' is not signed" \
". Ignoring..", _tmp9_);
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			result = FALSE;
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return result;
#line 6303 "unattended-installer.c"
		}
	}
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = TRUE;
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6310 "unattended-installer.c"
}


static gboolean ___lambda136__boxes_unattended_installer_driver_test_function (OsinfoDeviceDriver* driver, gpointer self) {
	gboolean result;
	result = __lambda136_ (self, driver);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6319 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_installable_drivers (BoxesUnattendedInstaller* self, GList* scripts, BoxesUnattendedInstallerDriverInstallableFunc installable_func, void* installable_func_target, BoxesUnattendedInstallerScriptDriverSigningReqFunc signing_req_func, void* signing_req_func_target) {
	GList* result = NULL;
	Block83Data* _data83_;
	BoxesUnattendedInstallerDriverInstallableFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GList* _tmp1_ = NULL;
	gboolean _tmp10_ = FALSE;
	GList* _tmp21_ = NULL;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_ = g_slice_new0 (Block83Data);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_->_ref_count_ = 1;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_->self = g_object_ref (self);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = installable_func;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0__target = installable_func_target;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_->installable_func = _tmp0_;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_->installable_func_target = _tmp0__target;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_->signing_required = FALSE;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = scripts;
#line 6351 "unattended-installer.c"
	{
		GList* script_collection = NULL;
		GList* script_it = NULL;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		script_collection = _tmp1_;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (script_it = script_collection; script_it != NULL; script_it = script_it->next) {
#line 6359 "unattended-installer.c"
			OsinfoInstallScript* _tmp2_ = NULL;
			OsinfoInstallScript* script = NULL;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = _g_object_ref0 ((OsinfoInstallScript*) script_it->data);
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			script = _tmp2_;
#line 6366 "unattended-installer.c"
			{
				BoxesUnattendedInstallerScriptDriverSigningReqFunc _tmp3_ = NULL;
				void* _tmp3__target = NULL;
				OsinfoInstallScript* _tmp4_ = NULL;
				OsinfoDeviceDriverSigningReq _tmp5_ = 0;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = signing_req_func;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3__target = signing_req_func_target;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = script;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = _tmp3_ (_tmp4_, _tmp3__target);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp5_ != OSINFO_DEVICE_DRIVER_SIGNING_REQ_NONE) {
#line 6382 "unattended-installer.c"
					OsinfoInstallScript* _tmp6_ = NULL;
					gchar* _tmp7_ = NULL;
					gchar* _tmp8_ = NULL;
					gchar* _tmp9_ = NULL;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp6_ = script;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_object_get ((OsinfoEntity*) _tmp6_, "id", &_tmp7_, NULL);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp8_ = _tmp7_;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp9_ = _tmp8_;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_debug ("unattended-installer.vala:574: Script '%s' requires signed drivers.", _tmp9_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_free0 (_tmp9_);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_data83_->signing_required = TRUE;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					break;
#line 6405 "unattended-installer.c"
				}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 6409 "unattended-installer.c"
			}
		}
	}
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_->driver_signing_mutable = FALSE;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp10_ = _data83_->signing_required;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp10_) {
#line 6419 "unattended-installer.c"
		OsinfoInstallScriptList* _tmp11_ = NULL;
		GList* _tmp12_ = NULL;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp11_ = self->scripts;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp12_ = osinfo_list_get_elements ((OsinfoList*) _tmp11_);
#line 6426 "unattended-installer.c"
		{
			GList* s_collection = NULL;
			GList* s_it = NULL;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s_collection = _tmp12_;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 6434 "unattended-installer.c"
				OsinfoEntity* s = NULL;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				s = (OsinfoEntity*) s_it->data;
#line 6438 "unattended-installer.c"
				{
					OsinfoInstallScript* script = NULL;
					OsinfoEntity* _tmp13_ = NULL;
					OsinfoInstallScript* _tmp14_ = NULL;
					OsinfoInstallScript* _tmp15_ = NULL;
					gboolean _tmp16_ = FALSE;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp13_ = s;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp13_) : NULL);
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					script = _tmp14_;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp15_ = script;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp16_ = osinfo_install_script_has_config_param_name (_tmp15_, OSINFO_INSTALL_CONFIG_PROP_DRIVER_SIGNING);
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_tmp16_) {
#line 6457 "unattended-installer.c"
						OsinfoInstallScript* _tmp17_ = NULL;
						gchar* _tmp18_ = NULL;
						gchar* _tmp19_ = NULL;
						gchar* _tmp20_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp17_ = script;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_object_get ((OsinfoEntity*) _tmp17_, "id", &_tmp18_, NULL);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp19_ = _tmp18_;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp20_ = _tmp19_;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_debug ("unattended-installer.vala:587: Script '%s' allows disabling of driver " \
"signature checks.", _tmp20_);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_free0 (_tmp20_);
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_data83_->driver_signing_mutable = TRUE;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_g_object_unref0 (script);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						break;
#line 6480 "unattended-installer.c"
					}
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (script);
#line 6484 "unattended-installer.c"
				}
			}
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_list_free0 (s_collection);
#line 6489 "unattended-installer.c"
		}
	}
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp21_ = boxes_unattended_installer_get_drivers (self, ___lambda136__boxes_unattended_installer_driver_test_function, _data83_);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp21_;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	block83_data_unref (_data83_);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_data83_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6502 "unattended-installer.c"
}


static void _g_free0_ (gpointer var) {
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	var = (g_free (var), NULL);
#line 6509 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_drivers (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerDriverTestFunction test_func, void* test_func_target) {
	GList* result = NULL;
	GHashTable* drivers = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	OsinfoOs* _tmp3_ = NULL;
	OsinfoDeviceDriverList* _tmp4_ = NULL;
	GList* _tmp5_ = NULL;
	GList* ret = NULL;
	GHashTable* _tmp35_ = NULL;
	GList* _tmp36_ = NULL;
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = g_str_hash;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = g_str_equal;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_object_unref0_);
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	drivers = _tmp2_;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = ((BoxesInstallerMedia*) self)->os;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = osinfo_os_get_device_drivers (_tmp3_);
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = osinfo_list_get_elements ((OsinfoList*) _tmp4_);
#line 6541 "unattended-installer.c"
	{
		GList* d_collection = NULL;
		GList* d_it = NULL;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		d_collection = _tmp5_;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (d_it = d_collection; d_it != NULL; d_it = d_it->next) {
#line 6549 "unattended-installer.c"
			OsinfoEntity* d = NULL;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			d = (OsinfoEntity*) d_it->data;
#line 6553 "unattended-installer.c"
			{
				OsinfoDeviceDriver* driver = NULL;
				OsinfoEntity* _tmp6_ = NULL;
				OsinfoDeviceDriver* _tmp7_ = NULL;
				BoxesCPUArchCompatibility compatibility = 0;
				OsinfoMedia* _tmp8_ = NULL;
				gchar* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
				gchar* _tmp11_ = NULL;
				OsinfoDeviceDriver* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				BoxesCPUArchCompatibility _tmp14_ = 0;
				BoxesCPUArchCompatibility _tmp15_ = 0;
				gchar* location = NULL;
				OsinfoDeviceDriver* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				BoxesCPUArchCompatibility _tmp19_ = 0;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = d;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, osinfo_device_driver_get_type ()) ? ((OsinfoDeviceDriver*) _tmp6_) : NULL);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				driver = _tmp7_;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp8_ = ((BoxesInstallerMedia*) self)->os_media;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				g_object_get (_tmp8_, "architecture", &_tmp9_, NULL);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp10_ = _tmp9_;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp11_ = _tmp10_;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp12_ = driver;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp13_ = osinfo_device_driver_get_architecture (_tmp12_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp14_ = boxes_compare_cpu_architectures (_tmp11_, _tmp13_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp15_ = _tmp14_;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (_tmp11_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				compatibility = _tmp15_;
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp16_ = driver;
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp17_ = osinfo_device_driver_get_location (_tmp16_);
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp18_ = g_strdup (_tmp17_);
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				location = _tmp18_;
#line 620 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp19_ = compatibility;
#line 620 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp19_ == BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL) {
#line 6610 "unattended-installer.c"
					GHashTable* _tmp20_ = NULL;
					const gchar* _tmp21_ = NULL;
					gchar* _tmp22_ = NULL;
					OsinfoDeviceDriver* _tmp23_ = NULL;
					OsinfoDeviceDriver* _tmp24_ = NULL;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp20_ = drivers;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp21_ = location;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp22_ = g_strdup (_tmp21_);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp23_ = driver;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp24_ = _g_object_ref0 (_tmp23_);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_hash_table_replace (_tmp20_, _tmp22_, _tmp24_);
#line 6628 "unattended-installer.c"
				} else {
					gboolean _tmp25_ = FALSE;
					BoxesCPUArchCompatibility _tmp26_ = 0;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp26_ = compatibility;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_tmp26_ == BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE) {
#line 6636 "unattended-installer.c"
						GHashTable* _tmp27_ = NULL;
						const gchar* _tmp28_ = NULL;
						gconstpointer _tmp29_ = NULL;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp27_ = drivers;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp28_ = location;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp29_ = g_hash_table_lookup (_tmp27_, _tmp28_);
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp25_ = ((OsinfoDeviceDriver*) _tmp29_) == NULL;
#line 6648 "unattended-installer.c"
					} else {
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp25_ = FALSE;
#line 6652 "unattended-installer.c"
					}
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					if (_tmp25_) {
#line 6656 "unattended-installer.c"
						GHashTable* _tmp30_ = NULL;
						const gchar* _tmp31_ = NULL;
						gchar* _tmp32_ = NULL;
						OsinfoDeviceDriver* _tmp33_ = NULL;
						OsinfoDeviceDriver* _tmp34_ = NULL;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp30_ = drivers;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp31_ = location;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp32_ = g_strdup (_tmp31_);
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp33_ = driver;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						_tmp34_ = _g_object_ref0 (_tmp33_);
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
						g_hash_table_insert (_tmp30_, _tmp32_, _tmp34_);
#line 6674 "unattended-installer.c"
					}
				}
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (location);
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (driver);
#line 6681 "unattended-installer.c"
			}
		}
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (d_collection);
#line 6686 "unattended-installer.c"
	}
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	ret = NULL;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp35_ = drivers;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp36_ = g_hash_table_get_values (_tmp35_);
#line 6694 "unattended-installer.c"
	{
		GList* driver_collection = NULL;
		GList* driver_it = NULL;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		driver_collection = _tmp36_;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (driver_it = driver_collection; driver_it != NULL; driver_it = driver_it->next) {
#line 6702 "unattended-installer.c"
			OsinfoDeviceDriver* driver = NULL;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			driver = (OsinfoDeviceDriver*) driver_it->data;
#line 6706 "unattended-installer.c"
			{
				BoxesUnattendedInstallerDriverTestFunction _tmp37_ = NULL;
				void* _tmp37__target = NULL;
				OsinfoDeviceDriver* _tmp38_ = NULL;
				gboolean _tmp39_ = FALSE;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp37_ = test_func;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp37__target = test_func_target;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp38_ = driver;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp39_ = _tmp37_ (_tmp38_, _tmp37__target);
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp39_) {
#line 6722 "unattended-installer.c"
					OsinfoDeviceDriver* _tmp40_ = NULL;
					OsinfoDeviceDriver* _tmp41_ = NULL;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp40_ = driver;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp41_ = _g_object_ref0 (_tmp40_);
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					ret = g_list_prepend (ret, _tmp41_);
#line 6731 "unattended-installer.c"
				}
			}
		}
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (driver_collection);
#line 6737 "unattended-installer.c"
	}
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	ret = g_list_reverse (ret);
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = ret;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_hash_table_unref0 (drivers);
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6747 "unattended-installer.c"
}


static gboolean __lambda135_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	gboolean result = FALSE;
	OsinfoInstallScript* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, FALSE);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_can_pre_install_drivers (_tmp0_);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6765 "unattended-installer.c"
}


static gboolean ___lambda135__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self) {
	gboolean result;
	result = __lambda135_ ((BoxesUnattendedInstaller*) self, script);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6774 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_pre_installer_scripts (BoxesUnattendedInstaller* self) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_scripts (self, ___lambda135__boxes_unattended_installer_script_test_function, self);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp0_;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6789 "unattended-installer.c"
}


static gboolean __lambda146_ (BoxesUnattendedInstaller* self, OsinfoInstallScript* script) {
	gboolean result = FALSE;
	OsinfoInstallScript* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (script != NULL, FALSE);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = script;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_install_script_get_can_post_install_drivers (_tmp0_);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp1_;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6807 "unattended-installer.c"
}


static gboolean ___lambda146__boxes_unattended_installer_script_test_function (OsinfoInstallScript* script, gpointer self) {
	gboolean result;
	result = __lambda146_ ((BoxesUnattendedInstaller*) self, script);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6816 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_post_installer_scripts (BoxesUnattendedInstaller* self) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_get_scripts (self, ___lambda146__boxes_unattended_installer_script_test_function, self);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp0_;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6831 "unattended-installer.c"
}


static GList* boxes_unattended_installer_get_scripts (BoxesUnattendedInstaller* self, BoxesUnattendedInstallerScriptTestFunction test_func, void* test_func_target) {
	GList* result = NULL;
	GList* scripts = NULL;
	OsinfoInstallScriptList* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 652 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	scripts = NULL;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->scripts;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = osinfo_list_get_elements ((OsinfoList*) _tmp0_);
#line 6848 "unattended-installer.c"
	{
		GList* s_collection = NULL;
		GList* s_it = NULL;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		s_collection = _tmp1_;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (s_it = s_collection; s_it != NULL; s_it = s_it->next) {
#line 6856 "unattended-installer.c"
			OsinfoEntity* s = NULL;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			s = (OsinfoEntity*) s_it->data;
#line 6860 "unattended-installer.c"
			{
				OsinfoInstallScript* script = NULL;
				OsinfoEntity* _tmp2_ = NULL;
				OsinfoInstallScript* _tmp3_ = NULL;
				BoxesUnattendedInstallerScriptTestFunction _tmp4_ = NULL;
				void* _tmp4__target = NULL;
				OsinfoInstallScript* _tmp5_ = NULL;
				gboolean _tmp6_ = FALSE;
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = s;
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, osinfo_install_script_get_type ()) ? ((OsinfoInstallScript*) _tmp2_) : NULL);
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				script = _tmp3_;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = test_func;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4__target = test_func_target;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = script;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = _tmp4_ (_tmp5_, _tmp4__target);
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_tmp6_) {
#line 6885 "unattended-installer.c"
					OsinfoInstallScript* _tmp7_ = NULL;
					OsinfoInstallScript* _tmp8_ = NULL;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp7_ = script;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp8_ = _g_object_ref0 (_tmp7_);
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					scripts = g_list_append (scripts, _tmp8_);
#line 6894 "unattended-installer.c"
				}
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (script);
#line 6898 "unattended-installer.c"
			}
		}
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (s_collection);
#line 6903 "unattended-installer.c"
	}
#line 661 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = scripts;
#line 661 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6909 "unattended-installer.c"
}


static gchar** _vala_array_dup4 (gchar** self, int length) {
	gchar** result;
	int i;
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = g_new0 (gchar*, length + 1);
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	for (i = 0; i < length; i++) {
#line 6920 "unattended-installer.c"
		gchar* _tmp0_ = NULL;
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp0_ = g_strdup (self[i]);
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result[i] = _tmp0_;
#line 6926 "unattended-installer.c"
	}
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 6930 "unattended-installer.c"
}


static void _vala_array_add11 (gchar*** array, int* length, int* size, gchar* value) {
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if ((*length) == (*size)) {
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 6941 "unattended-installer.c"
	}
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[(*length)++] = value;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	(*array)[*length] = NULL;
#line 6947 "unattended-installer.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	for (i = 0; i < stack_length; i++) {
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			return TRUE;
#line 6959 "unattended-installer.c"
		}
	}
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return FALSE;
#line 6964 "unattended-installer.c"
}


static gchar* boxes_unattended_installer_get_preferred_language (BoxesUnattendedInstaller* self) {
	gchar* result = NULL;
	gchar** system_langs = NULL;
	gchar** _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gint system_langs_length1 = 0;
	gint _system_langs_size_ = 0;
	gchar** media_langs = NULL;
	gchar** _tmp3_ = NULL;
	gint media_langs_length1 = 0;
	gint _media_langs_size_ = 0;
	GList* media_langs_list = NULL;
	OsinfoMedia* _tmp4_ = NULL;
	GList* _tmp5_ = NULL;
	GList* _tmp6_ = NULL;
	GList* _tmp7_ = NULL;
	gchar** _tmp11_ = NULL;
	gint _tmp11__length1 = 0;
	GList* _tmp16_ = NULL;
	gchar* lang = NULL;
	gchar** _tmp22_ = NULL;
	gint _tmp22__length1 = 0;
	const gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
#line 665 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_ = g_get_language_names ();
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = (_tmp1_ != NULL) ? _vala_array_dup4 (_tmp1_, _vala_array_length (_tmp0_)) : ((gpointer) _tmp1_);
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2__length1 = _vala_array_length (_tmp0_);
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	system_langs = _tmp2_;
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	system_langs_length1 = _tmp2__length1;
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_system_langs_size_ = system_langs_length1;
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = g_new0 (gchar*, 0 + 1);
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	media_langs = _tmp3_;
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	media_langs_length1 = 0;
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_media_langs_size_ = media_langs_length1;
#line 668 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp4_ = ((BoxesInstallerMedia*) self)->os_media;
#line 668 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp5_ = osinfo_media_get_languages (_tmp4_);
#line 668 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp6_ = _tmp5_;
#line 668 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	media_langs_list = _tmp6_;
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp7_ = media_langs_list;
#line 7029 "unattended-installer.c"
	{
		GList* lang_collection = NULL;
		GList* lang_it = NULL;
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		lang_collection = _tmp7_;
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (lang_it = lang_collection; lang_it != NULL; lang_it = lang_it->next) {
#line 7037 "unattended-installer.c"
			const gchar* lang = NULL;
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			lang = (const gchar*) lang_it->data;
#line 7041 "unattended-installer.c"
			{
				gchar** _tmp8_ = NULL;
				gint _tmp8__length1 = 0;
				const gchar* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp8_ = media_langs;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp8__length1 = media_langs_length1;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp9_ = lang;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp10_ = g_strdup (_tmp9_);
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_vala_array_add11 (&media_langs, &media_langs_length1, &_media_langs_size_, _tmp10_);
#line 7057 "unattended-installer.c"
			}
		}
	}
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = system_langs;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11__length1 = system_langs_length1;
#line 7065 "unattended-installer.c"
	{
		gchar** lang_collection = NULL;
		gint lang_collection_length1 = 0;
		gint _lang_collection_size_ = 0;
		gint lang_it = 0;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		lang_collection = _tmp11_;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		lang_collection_length1 = _tmp11__length1;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (lang_it = 0; lang_it < _tmp11__length1; lang_it = lang_it + 1) {
#line 7077 "unattended-installer.c"
			gchar* _tmp12_ = NULL;
			gchar* lang = NULL;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp12_ = g_strdup (lang_collection[lang_it]);
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			lang = _tmp12_;
#line 7084 "unattended-installer.c"
			{
				const gchar* _tmp13_ = NULL;
				gchar** _tmp14_ = NULL;
				gint _tmp14__length1 = 0;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp13_ = lang;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp14_ = media_langs;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp14__length1 = media_langs_length1;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (_vala_string_array_contains (_tmp14_, _tmp14__length1, _tmp13_)) {
#line 7097 "unattended-installer.c"
					const gchar* _tmp15_ = NULL;
#line 675 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp15_ = lang;
#line 675 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					g_debug ("unattended-installer.vala:675: matched %s", _tmp15_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					result = lang;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_list_free0 (media_langs_list);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					media_langs = (_vala_array_free (media_langs, media_langs_length1, (GDestroyNotify) g_free), NULL);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					system_langs = (_vala_array_free (system_langs, system_langs_length1, (GDestroyNotify) g_free), NULL);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return result;
#line 7113 "unattended-installer.c"
				}
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_free0 (lang);
#line 7117 "unattended-installer.c"
			}
		}
	}
#line 680 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp16_ = media_langs_list;
#line 680 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp16_ != NULL) {
#line 7125 "unattended-installer.c"
		GList* _tmp17_ = NULL;
		gconstpointer _tmp18_ = NULL;
		GList* _tmp19_ = NULL;
		gconstpointer _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp17_ = media_langs_list;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp18_ = g_list_nth_data (_tmp17_, (guint) 0);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_debug ("unattended-installer.vala:681: Failed to match system locales with med" \
"ia languages, falling back to %s media language", (const gchar*) _tmp18_);
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp19_ = media_langs_list;
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp20_ = g_list_nth_data (_tmp19_, (guint) 0);
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp21_ = g_strdup ((const gchar*) _tmp20_);
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = _tmp21_;
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_list_free0 (media_langs_list);
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		media_langs = (_vala_array_free (media_langs, media_langs_length1, (GDestroyNotify) g_free), NULL);
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		system_langs = (_vala_array_free (system_langs, system_langs_length1, (GDestroyNotify) g_free), NULL);
#line 683 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 7153 "unattended-installer.c"
	}
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp22_ = system_langs;
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp22__length1 = system_langs_length1;
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp23_ = _tmp22_[0];
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp24_ = string_replace (_tmp23_, ".utf8", "");
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	lang = _tmp24_;
#line 687 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp25_ = lang;
#line 687 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp26_ = string_replace (_tmp25_, ".UTF-8", "");
#line 687 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (lang);
#line 687 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	lang = _tmp26_;
#line 688 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp27_ = lang;
#line 688 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_debug ("unattended-installer.vala:688: No media language, using %s locale", _tmp27_);
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = lang;
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_list_free0 (media_langs_list);
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	media_langs = (_vala_array_free (media_langs, media_langs_length1, (GDestroyNotify) g_free), NULL);
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	system_langs = (_vala_array_free (system_langs, system_langs_length1, (GDestroyNotify) g_free), NULL);
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7187 "unattended-installer.c"
}


static void boxes_unattended_installer_remove_disk_from_domain_config (BoxesUnattendedInstaller* self, GVirConfigDomain* domain, const gchar* disk_path) {
	GList* devices = NULL;
	GVirConfigDomain* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GVirConfigDomain* _tmp11_ = NULL;
	GList* _tmp12_ = NULL;
#line 693 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (self != NULL);
#line 693 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (domain != NULL);
#line 693 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_if_fail (disk_path != NULL);
#line 694 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = domain;
#line 694 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = gvir_config_domain_get_devices (_tmp0_);
#line 694 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	devices = _tmp1_;
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = devices;
#line 7212 "unattended-installer.c"
	{
		GList* device_collection = NULL;
		GList* device_it = NULL;
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		device_collection = _tmp2_;
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (device_it = device_collection; device_it != NULL; device_it = device_it->next) {
#line 7220 "unattended-installer.c"
			GVirConfigDomainDevice* _tmp3_ = NULL;
			GVirConfigDomainDevice* device = NULL;
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp3_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_it->data);
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			device = _tmp3_;
#line 7227 "unattended-installer.c"
			{
				GVirConfigDomainDevice* _tmp4_ = NULL;
				GVirConfigDomainDisk* disk = NULL;
				GVirConfigDomainDevice* _tmp5_ = NULL;
				GVirConfigDomainDisk* _tmp6_ = NULL;
				GVirConfigDomainDisk* _tmp7_ = NULL;
				const gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
#line 696 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp4_ = device;
#line 696 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gvir_config_domain_disk_get_type ())) {
#line 697 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (device);
#line 697 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					continue;
#line 7244 "unattended-installer.c"
				}
#line 699 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp5_ = device;
#line 699 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp5_) : NULL);
#line 699 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				disk = _tmp6_;
#line 700 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp7_ = disk;
#line 700 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp8_ = gvir_config_domain_disk_get_source (_tmp7_);
#line 700 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp9_ = disk_path;
#line 700 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 7260 "unattended-installer.c"
					GVirConfigDomainDevice* _tmp10_ = NULL;
#line 701 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp10_ = device;
#line 701 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					devices = g_list_remove (devices, _tmp10_);
#line 703 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (disk);
#line 703 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (device);
#line 703 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					break;
#line 7272 "unattended-installer.c"
				}
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (disk);
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (device);
#line 7278 "unattended-installer.c"
			}
		}
	}
#line 707 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp11_ = domain;
#line 707 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp12_ = devices;
#line 707 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	gvir_config_domain_set_devices (_tmp11_, _tmp12_);
#line 693 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (devices);
#line 7290 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_construct (GType object_type) {
	BoxesUnattendedInstaller * self = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) boxes_installer_media_construct (object_type);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return self;
#line 7300 "unattended-installer.c"
}


BoxesUnattendedInstaller* boxes_unattended_installer_new (void) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return boxes_unattended_installer_construct (BOXES_TYPE_UNATTENDED_INSTALLER);
#line 7307 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_get_need_user_input_for_vm_creation (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesUnattendedInstaller* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_installer_media_get_live ((BoxesInstallerMedia*) self);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = _tmp0_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = !_tmp1_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7326 "unattended-installer.c"
}


static gboolean boxes_unattended_installer_real_get_ready_to_create (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesUnattendedInstaller* self;
	BoxesUnattendedSetupBox* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->setup_box;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = boxes_unattended_setup_box_get_ready_to_create (_tmp0_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = _tmp1_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7348 "unattended-installer.c"
}


static OsinfoDeviceList* boxes_unattended_installer_real_get_supported_devices (BoxesInstallerMedia* base) {
	OsinfoDeviceList* result;
	BoxesUnattendedInstaller* self;
	OsinfoDeviceList* devices = NULL;
	OsinfoDeviceList* _tmp0_ = NULL;
	BoxesUnattendedSetupBox* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = (BoxesUnattendedInstaller*) base;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = BOXES_INSTALLER_MEDIA_CLASS (boxes_unattended_installer_parent_class)->get_supported_devices (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia));
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	devices = _tmp0_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp1_ = self->setup_box;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp2_ = boxes_unattended_setup_box_get_express_install (_tmp1_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp3_ = _tmp2_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp3_) {
#line 7374 "unattended-installer.c"
		OsinfoDeviceList* _tmp4_ = NULL;
		OsinfoDeviceList* _tmp5_ = NULL;
		OsinfoList* _tmp6_ = NULL;
		OsinfoDeviceList* _tmp7_ = NULL;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp4_ = devices;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp5_ = self->priv->additional_devices;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp6_ = osinfo_list_new_union (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp4_) : NULL, (OsinfoList*) _tmp5_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, osinfo_devicelist_get_type ()) ? ((OsinfoDeviceList*) _tmp6_) : NULL;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (_tmp7_ == NULL) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_tmp6_);
#line 7391 "unattended-installer.c"
		}
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = _tmp7_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		_g_object_unref0 (devices);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 7399 "unattended-installer.c"
	} else {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		result = devices;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		return result;
#line 7405 "unattended-installer.c"
	}
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (devices);
#line 7409 "unattended-installer.c"
}


static OsinfoInstallScriptInjectionMethod boxes_unattended_installer_get_injection_method (BoxesUnattendedInstaller* self) {
	OsinfoInstallScriptInjectionMethod result;
	GList* _tmp0_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = self->priv->unattended_files;
#line 7420 "unattended-installer.c"
	{
		GList* unattended_file_collection = NULL;
		GList* unattended_file_it = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		unattended_file_collection = _tmp0_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		for (unattended_file_it = unattended_file_collection; unattended_file_it != NULL; unattended_file_it = unattended_file_it->next) {
#line 7428 "unattended-installer.c"
			BoxesUnattendedFile* _tmp1_ = NULL;
			BoxesUnattendedFile* unattended_file = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp1_ = _g_object_ref0 ((BoxesUnattendedFile*) unattended_file_it->data);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			unattended_file = _tmp1_;
#line 7435 "unattended-installer.c"
			{
				BoxesUnattendedFile* _tmp2_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_tmp2_ = unattended_file;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_UNATTENDED_SCRIPT_FILE)) {
#line 7442 "unattended-installer.c"
					BoxesUnattendedFile* _tmp3_ = NULL;
					OsinfoInstallScriptInjectionMethod _tmp4_ = 0;
					OsinfoInstallScriptInjectionMethod _tmp5_ = 0;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp3_ = unattended_file;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp4_ = boxes_unattended_script_file_get_injection_method (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_UNATTENDED_SCRIPT_FILE) ? ((BoxesUnattendedScriptFile*) _tmp3_) : NULL);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_tmp5_ = _tmp4_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					result = _tmp5_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					_g_object_unref0 (unattended_file);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
					return result;
#line 7458 "unattended-installer.c"
				}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
				_g_object_unref0 (unattended_file);
#line 7462 "unattended-installer.c"
			}
		}
	}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	result = OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_DISK;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return result;
#line 7470 "unattended-installer.c"
}


static GObject * boxes_unattended_installer_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesUnattendedInstaller * self;
	BoxesFdoAccounts* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	parent_class = G_OBJECT_CLASS (boxes_unattended_installer_parent_class);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_tmp0_ = boxes_unattended_installer_accounts;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	if (_tmp0_ == NULL) {
#line 7490 "unattended-installer.c"
		{
			BoxesFdoAccounts* _tmp1_ = NULL;
			BoxesFdoAccounts* _tmp2_ = NULL;
			BoxesFdoAccounts* _tmp3_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp2_ = g_initable_new (BOXES_FDO_TYPE_ACCOUNTS_PROXY, NULL, &_inner_error_, "g-flags", 0, "g-name", "org.freedesktop.Accounts", "g-bus-type", G_BUS_TYPE_SYSTEM, "g-object-path", "/org/freedesktop/Accounts", "g-interface-name", "org.freedesktop.Accounts", "g-interface-info", g_type_get_qdata (BOXES_FDO_TYPE_ACCOUNTS, g_quark_from_static_string ("vala-dbus-interface-info")), NULL);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp1_ = (BoxesFdoAccounts*) _tmp2_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7501 "unattended-installer.c"
				goto __catch87_g_error;
			}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp3_ = _tmp1_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp1_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (boxes_unattended_installer_accounts);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			boxes_unattended_installer_accounts = _tmp3_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_object_unref0 (_tmp1_);
#line 7514 "unattended-installer.c"
		}
		goto __finally87;
		__catch87_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp4_ = NULL;
			const gchar* _tmp5_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_error_ = _inner_error_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_inner_error_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp4_ = _error_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_tmp5_ = _tmp4_->message;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_warning ("unattended-installer.vala:80: Failed to connect to D-Bus service '%s':" \
" %s", "org.freedesktop.Accounts", _tmp5_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			_g_error_free0 (_error_);
#line 7534 "unattended-installer.c"
		}
		__finally87:
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
			g_clear_error (&_inner_error_);
#line 7543 "unattended-installer.c"
		}
	}
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	return obj;
#line 7548 "unattended-installer.c"
}


static void boxes_unattended_installer_class_init (BoxesUnattendedInstallerClass * klass) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	boxes_unattended_installer_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_type_class_add_private (klass, sizeof (BoxesUnattendedInstallerPrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_to_continue_installation = boxes_unattended_installer_real_prepare_to_continue_installation;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_for_installation = boxes_unattended_installer_real_prepare_for_installation;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_for_installation_finish = boxes_unattended_installer_real_prepare_for_installation_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->setup_domain_config = boxes_unattended_installer_real_setup_domain_config;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->setup_post_install_domain_config = boxes_unattended_installer_real_setup_post_install_domain_config;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->populate_setup_box = boxes_unattended_installer_real_populate_setup_box;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->get_vm_properties = boxes_unattended_installer_real_get_vm_properties;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->set_direct_boot_params = boxes_unattended_installer_real_set_direct_boot_params;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->clean_up = boxes_unattended_installer_real_clean_up;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->clean_up_preparation_cache = boxes_unattended_installer_real_clean_up_preparation_cache;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->prepare = boxes_unattended_installer_real_prepare;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_finish = boxes_unattended_installer_real_prepare_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_need_user_input_for_vm_creation = boxes_unattended_installer_real_get_need_user_input_for_vm_creation;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_ready_to_create = boxes_unattended_installer_real_get_ready_to_create;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_supported_devices = boxes_unattended_installer_real_get_supported_devices;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_unattended_installer_get_property;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_unattended_installer_constructor;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_unattended_installer_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_NEED_USER_INPUT_FOR_VM_CREATION, g_param_spec_boolean ("need-user-input-for-vm-creation", "need-user-input-for-vm-creation", "need-user-input-for-vm-creation", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_READY_TO_CREATE, g_param_spec_boolean ("ready-to-create", "ready-to-create", "ready-to-create", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_INSTALLER_SUPPORTED_DEVICES, g_param_spec_object ("supported-devices", "supported-devices", "supported-devices", osinfo_devicelist_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7599 "unattended-installer.c"
}


static void boxes_unattended_installer_instance_init (BoxesUnattendedInstaller * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv = BOXES_UNATTENDED_INSTALLER_GET_PRIVATE (self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self->priv->driver_signing = TRUE;
#line 7608 "unattended-installer.c"
}


static void boxes_unattended_installer_finalize (GObject* obj) {
	BoxesUnattendedInstaller * self;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->setup_box);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->disk_file);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->secondary_disk_file);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->kernel_file);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->initrd_file);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->config);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->scripts);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->unattended_files);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	__g_list_free__g_object_unref0_0 (self->priv->secondary_unattended_files);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->avatar_file);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->timezone);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->lang);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->hostname);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_free0 (self->priv->kbd);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	_g_object_unref0 (self->priv->additional_devices);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	G_OBJECT_CLASS (boxes_unattended_installer_parent_class)->finalize (obj);
#line 7648 "unattended-installer.c"
}


GType boxes_unattended_installer_get_type (void) {
	static volatile gsize boxes_unattended_installer_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_installer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedInstallerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_unattended_installer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesUnattendedInstaller), 0, (GInstanceInitFunc) boxes_unattended_installer_instance_init, NULL };
		GType boxes_unattended_installer_type_id;
		boxes_unattended_installer_type_id = g_type_register_static (BOXES_TYPE_INSTALLER_MEDIA, "BoxesUnattendedInstaller", &g_define_type_info, 0);
		g_once_init_leave (&boxes_unattended_installer_type_id__volatile, boxes_unattended_installer_type_id);
	}
	return boxes_unattended_installer_type_id__volatile;
}


static void _vala_boxes_unattended_installer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesUnattendedInstaller * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
	switch (property_id) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_NEED_USER_INPUT_FOR_VM_CREATION:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_set_boolean (value, boxes_installer_media_get_need_user_input_for_vm_creation ((BoxesInstallerMedia*) self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_READY_TO_CREATE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_set_boolean (value, boxes_installer_media_get_ready_to_create ((BoxesInstallerMedia*) self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		case BOXES_UNATTENDED_INSTALLER_SUPPORTED_DEVICES:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		g_value_take_object (value, boxes_installer_media_get_supported_devices ((BoxesInstallerMedia*) self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 7687 "unattended-installer.c"
		default:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-installer.vala"
		break;
#line 7693 "unattended-installer.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 7701 "unattended-installer.c"
		int i;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 7709 "unattended-installer.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 7721 "unattended-installer.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 7734 "unattended-installer.c"
		}
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 7739 "unattended-installer.c"
}



